@@ -32,8 +32,12 @@
 #include "SvgBitmap.h"
 #include "nanosvg_private.h"
 #include "nanosvgrast_private.h"
+#include "art/menu/Text-questionmark.h"
+#include "art/menu/cell-divide.h"
+#include "art/menu/watchlist.h"
+#include "art/menu/cell-merge.h"
 
-wxBitmap ArtProvider::GetImage(wxWindow *win, wxString name, int width,
+wxBitmap ArtProvider::GetImage(wxWindow *win, const wxString &name, int width,
                                unsigned const char *data, std::size_t dataLen) {
   wxBitmap bmp = wxArtProvider::GetBitmap(name, wxART_TOOLBAR,
                                           wxSize(width * 4, width * 4));
@@ -77,3 +81,21 @@ wxBitmap ArtProvider::GetImage(wxWindow *win, wxString name, int width,
 #endif
   return bmp;
 }
+
+wxBitmap ArtProvider::GetQuestionmarkBitmap(wxWindow *win, wxSize siz)
+{
+  return GetImage(win, wxS("dialog-question"), siz.x,
+                  TEXT_QUESTIONMARK_SVG, TEXT_QUESTIONMARK_SVG_SIZE);
+}
+
+#if wxCHECK_VERSION(3, 2, 0)
+wxBitmapBundle ArtProvider::m_questionmarkBundle =
+  wxBitmapBundle::FromSVG(reinterpret_cast<char *>(TEXT_QUESTIONMARK_SVG), wxSize(16,16));
+wxBitmapBundle ArtProvider::m_dividecellBundle =
+  wxBitmapBundle::FromSVG(reinterpret_cast<char *>(CELL_DIVIDE_SVG), wxSize(16,16));
+wxBitmapBundle ArtProvider::m_addToWatchlistBundle =
+  wxBitmapBundle::FromSVG(reinterpret_cast<char *>(WATCHLIST_SVG), wxSize(16,16));
+wxBitmapBundle ArtProvider::m_cellMergeBundle =
+  wxBitmapBundle::FromSVG(reinterpret_cast<char *>(CELL_MERGE_SVG), wxSize(16,16));
+#endif
+
