@@ -28,6 +28,9 @@
 
 #include <wx/bitmap.h>
 #include <wx/window.h>
+#if wxCHECK_VERSION(3, 2, 0)
+#include <wx/bmpbndl.h>
+#endif
 
 #ifndef _ARTPROVIDER_H
 #define _ARTPROVIDER_H
@@ -36,8 +39,21 @@ class ArtProvider
 {
 public:
   ArtProvider(){}
-  static wxBitmap GetImage(wxWindow *win, wxString name, int width, unsigned const char *data,
+  static wxBitmap GetImage(wxWindow *win, const wxString &name, int width,
+                           unsigned const char *data,
                            std::size_t dataLen);
+  static wxBitmap GetQuestionmarkBitmap(wxWindow *win, wxSize siz);
+#if wxCHECK_VERSION(3, 2, 0)
+  static wxBitmapBundle GetQuestionmarkBundle(){return m_questionmarkBundle;}
+  static wxBitmapBundle GetDivideCellBundle(){return m_dividecellBundle;}
+  static wxBitmapBundle GetAddToWatchlistBundle(){return m_addToWatchlistBundle;}
+  static wxBitmapBundle GetCellMergeBundle(){return m_cellMergeBundle;}
+private:
+  static wxBitmapBundle m_questionmarkBundle;
+  static wxBitmapBundle m_dividecellBundle;
+  static wxBitmapBundle m_addToWatchlistBundle;
+  static wxBitmapBundle m_cellMergeBundle;
+#endif
 };
 
 #endif
