@@ -31,7 +31,6 @@
 
 #include "Autocomplete.h"
 #include "Dirstructure.h"
-#include "ErrorRedirector.h"
 #include <wx/filename.h>
 #include <wx/sstream.h>
 #include <wx/textfile.h>
@@ -91,15 +90,13 @@ void AutoComplete::LoadBuiltinSymbols() {
   m_wordList.at(command).erase(newEnd, m_wordList.at(command).end());
 }
 
-bool AutoComplete::HasDemofile(wxString commandname)
+bool AutoComplete::HasDemofile(const wxString &commandname)
 {
   const std::lock_guard<std::mutex> lock(m_keywordsLock);
-  for (auto &file : m_wordList.at(demofile))
-    {
-      if(file == "\"" + commandname + "\"")
-        return true;
-    }
-  return false;
+  return std::any_of(m_wordList.at(demofile).begin(),
+                     m_wordList.at(demofile).end(),
+                     [commandname](const wxString &file){
+                       return file == wxS("\"") + commandname + wxS("\"");});
 }
 
 
@@ -113,7 +110,7 @@ void AutoComplete::AddSymbols(wxString xml) {
     m_addSymbols_backgroundThread.join();
 
   if((m_configuration->UseThreads() && xml.Length() > 300))
-    m_addSymbols_backgroundThread = std::thread(&AutoComplete::AddSymbols_Backgroundtask_string,
+    m_addSymbols_backgroundThread = jthread(&AutoComplete::AddSymbols_Backgroundtask_string,
                                                 this, std::move(xml));
   else
     AddSymbols_Backgroundtask_string(std::move(xml));
@@ -127,19 +124,19 @@ void AutoComplete::AddSymbols(wxXmlDocument xml) {
     }
   wxLogMessage(_("Scheduling a background task that compiles a new list "
                  "of autocompletable maxima commands."));
-  
+
   if(m_configuration->UseThreads())
-    m_addSymbols_backgroundThread = std::thread(&AutoComplete::AddSymbols_Backgroundtask,
+    m_addSymbols_backgroundThread = jthread(&AutoComplete::AddSymbols_Backgroundtask,
                                                 this, std::move(xml));
   else
     AddSymbols_Backgroundtask(std::move(xml));
-    
+
 }
 
 void AutoComplete::AddSymbols_Backgroundtask_string(wxString xml) {
   wxXmlDocument xmldoc;
   wxStringInputStream xmlStream(xml);
-  xmldoc.Load(xmlStream, wxS("UTF-8"));
+  xmldoc.Load(xmlStream);
   AddSymbols_Backgroundtask(xmldoc);
 }
 
@@ -230,6 +227,9 @@ void AutoComplete::LoadSymbols() {
   wxString sharedir = m_configuration->MaximaShareDir();
   sharedir.Replace("\n", "");
   sharedir.Replace("\r", "");
+  wxString demodir = m_configuration->MaximaDemoDir();
+  demodir.Replace("\n", "");
+  demodir.Replace("\r", "");
   if(m_addFiles_backgroundThread.joinable())
     {
       wxLogMessage(_("Waiting for m_addFiles_backgroundThread to finish"));
@@ -242,15 +242,15 @@ void AutoComplete::LoadSymbols() {
     }
   if(m_configuration->UseThreads())
     {
-      m_addSymbols_backgroundThread = std::thread(&AutoComplete::BuiltinSymbols_BackgroundTask,
-                                                  this);
-      m_addFiles_backgroundThread = std::thread(&AutoComplete::LoadableFiles_BackgroundTask,
-                                                this, sharedir);
+      m_addSymbols_backgroundThread = jthread(&AutoComplete::BuiltinSymbols_BackgroundTask,
+                                              this);
+      m_addFiles_backgroundThread = jthread(&AutoComplete::LoadableFiles_BackgroundTask,
+                                            this, sharedir, demodir);
     }
   else
     {
       BuiltinSymbols_BackgroundTask();
-      LoadableFiles_BackgroundTask(sharedir);
+      LoadableFiles_BackgroundTask(sharedir, demodir);
     }
 }
 
@@ -323,7 +323,6 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
     }
     priv.Close();
   } else {
-    SuppressErrorDialogs logNull;
     wxFileOutputStream output(privateList);
     if (output.IsOk()) {
       wxTextOutputStream text(output);
@@ -343,10 +342,7 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
   }
 }
 
-void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-
+void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir, wxString demodir) {
   // Prepare a list of all built-in loadable files of maxima.
   {
     GetMacFiles_includingSubdirs maximaLispIterator(m_builtInLoadFiles, &m_keywordsLock);
@@ -371,11 +367,8 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
 
   // Prepare a list of all built-in demos of maxima.
   {
-    wxFileName shareDir(sharedir + "/");
-    shareDir.MakeAbsolute();
-    wxFileName demoDir(shareDir.GetFullPath() + "/");
+    wxFileName demoDir(demodir + "/");
     demoDir.MakeAbsolute();
-    demoDir.RemoveLastDir();
     GetDemoFiles_includingSubdirs maximaLispIterator(m_builtInDemoFiles, &m_keywordsLock);
     wxDir maximadir(demoDir.GetFullPath());
     if (maximadir.IsOpened())
@@ -392,7 +385,7 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
   QueueEvent(event);
 }
 
-void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
+void AutoComplete::UpdateDemoFiles(wxString partial, const wxString &maximaDir) {
   // Remove the opening quote from the partial.
   if (partial.at(0) == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
@@ -400,7 +393,7 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
   if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
-    partial = wxEmptyString;
+    partial.Clear();
   else
     partial = partial.Left(pos);
   wxString prefix = partial + wxS("/");
@@ -428,7 +421,7 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
   }
 }
 
-void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
+void AutoComplete::UpdateGeneralFiles(wxString partial, const wxString &maximaDir) {
   // Remove the opening quote from the partial.
   if (partial.at(0) == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
@@ -436,7 +429,7 @@ void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
   if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
-    partial = wxEmptyString;
+    partial.Clear();
   else
     partial = partial.Left(pos);
   wxString prefix = partial + wxS("/");
@@ -461,7 +454,7 @@ void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
   }
 }
 
-void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
+void AutoComplete::UpdateLoadFiles(wxString partial, const wxString &maximaDir) {
   wxLogMessage(_("Scheduling a background task that scans for autocompletable "
                  "file names."));
   // Remove the opening quote from the partial.
@@ -471,7 +464,7 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
   if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
-    partial = wxEmptyString;
+    partial.Clear();
   else
     partial = partial.Left(pos);
   wxString prefix = partial + wxS("/");
@@ -536,10 +529,10 @@ std::vector<wxString> AutoComplete::CompleteSymbol(wxString partial,
     }
   }
 
+  const std::lock_guard<std::mutex> lock(m_keywordsLock);
   // Add a list of words that were defined on the work sheet but that aren't
   // defined as maxima commands or functions.
   if (type == command) {
-    const std::lock_guard<std::mutex> lock(m_keywordsLock);
     for (const auto &it : m_worksheetWords) {
       if (it.first.StartsWith(partial)) {
         if (std::find(completions.begin(), completions.end(), it.first) == completions.end()) {
@@ -549,13 +542,13 @@ std::vector<wxString> AutoComplete::CompleteSymbol(wxString partial,
     }
   }
 
-  const std::lock_guard<std::mutex> lock(m_keywordsLock);
   std::sort(completions.begin(), completions.end());
   auto newEnd = std::unique(completions.begin(), completions.end());
   completions.erase(newEnd, completions.end());
   if (perfectCompletions.size() > 0)
     return perfectCompletions;
-  return completions;
+  else
+    return completions;
 }
 
 void AutoComplete::AddSymbol(wxString fun, autoCompletionType type) {
@@ -592,8 +585,8 @@ void AutoComplete::AddSymbol(wxString fun, autoCompletionType type) {
       {
         wxString funName = fun.SubString(0, openpos);
         auto count = fun.Freq('<');
-        std::size_t i = 0;
         {
+          std::size_t i = 0;
           const std::lock_guard<std::mutex> lock(m_keywordsLock);
           for (const auto &o: m_wordList.at(type)) {
             if (o.StartsWith(funName) && (o.Freq('<') == count))
