@@ -45,6 +45,7 @@
 #include <wx/hashmap.h>
 #include "Configuration.h"
 #include "precomp.h"
+#include "Version.h"
 #include <unordered_map>
 /* The autocompletion logic
 
@@ -102,11 +103,11 @@ public:
 
 
   //! Replace the list of files in the directory the worksheet file is in to the demo files list
-  void UpdateDemoFiles(wxString partial, wxString maximaDir);
+  void UpdateDemoFiles(wxString partial, const wxString &maximaDir);
   //! Replace the list of files in the directory the worksheet file is in to the load files list
-  void UpdateLoadFiles(wxString partial, wxString maximaDir);
+  void UpdateLoadFiles(wxString partial, const wxString &maximaDir);
   //! Assemble a list of files
-  void UpdateGeneralFiles(wxString partial, wxString maximaDir);
+  void UpdateGeneralFiles(wxString partial, const wxString &maximaDir);
 
   //! Add words to the list of words that appear in the workSheet's code cells
   void AddWorksheetWords(const WordList &words);
@@ -126,13 +127,13 @@ public:
   //! Returns a list of Symbols we know
   std::vector<wxString> GetSymbolList();
   //! Does a demo file for this command exist?
-  bool HasDemofile(wxString commandname);
+  bool HasDemofile(const wxString &commandname);
 
 private:
   //! The configuration storage
   Configuration *m_configuration;
   //! Loads the list of loadable files and can be run in a background task
-  void LoadableFiles_BackgroundTask(wxString sharedir);
+  void LoadableFiles_BackgroundTask(wxString sharedir, wxString demodir);
   //! Prepares the list of built-in symbols and can be run in a background task
   void BuiltinSymbols_BackgroundTask();
 
@@ -149,7 +150,7 @@ private:
   public:
     explicit GetGeneralFiles(std::vector<wxString>& files,
                              std::mutex *lock,
-                             wxString prefix = wxEmptyString) :
+                             const wxString &prefix = wxEmptyString) :
       m_files(files), m_lock(lock), m_prefix(prefix) { }
     wxDirTraverseResult OnFile(const wxString& filename) override
       {
@@ -191,7 +192,7 @@ private:
   public:
     explicit GetMacFiles_includingSubdirs(std::vector<wxString>& files,
                                           std::mutex *lock,
-                                          wxString prefix = wxEmptyString) :
+                                          const wxString &prefix = wxEmptyString) :
       m_files(files), m_lock(lock), m_prefix(prefix)  { }
     wxDirTraverseResult OnFile(const wxString& filename) override
       {
@@ -240,7 +241,7 @@ private:
   public:
     explicit GetMacFiles(std::vector<wxString>& files,
                          std::mutex *lock,
-                         wxString prefix = wxEmptyString) :
+                         const wxString &prefix = wxEmptyString) :
       GetMacFiles_includingSubdirs(files, lock, prefix){ }
     wxDirTraverseResult OnDir(const wxString& dirname) override
       {
@@ -262,7 +263,7 @@ private:
   public:
     explicit GetDemoFiles_includingSubdirs(std::vector<wxString>& files,
                                            std::mutex *lock,
-                                           wxString prefix = wxEmptyString) :
+                                           const wxString &prefix = wxEmptyString) :
       m_files(files), m_lock(lock), m_prefix(prefix) { }
     wxDirTraverseResult OnFile(const wxString& filename) override
       {
@@ -307,7 +308,7 @@ private:
   public:
     explicit GetDemoFiles(std::vector<wxString>& files,
                           std::mutex *lock,
-                          wxString prefix = wxEmptyString) :
+                          const wxString &prefix = wxEmptyString) :
       GetDemoFiles_includingSubdirs(files, lock, prefix){ }
     virtual wxDirTraverseResult OnDir(const wxString& dirname) override
       {
@@ -323,8 +324,8 @@ private:
       }
   };
  
-  std::thread m_addSymbols_backgroundThread;
-  std::thread m_addFiles_backgroundThread;
+  jthread m_addSymbols_backgroundThread;
+  jthread m_addFiles_backgroundThread;
   //! Is locked when someone accesses a keyword list
   std::mutex m_keywordsLock;
   //! The lists of autocompletable symbols for the classes defined in autoCompletionType
