@@ -31,7 +31,6 @@
 #include "cells/Cell.h"
 #include "cells/TextStyle.h"
 #include "Dirstructure.h"
-#include "ErrorRedirector.h"
 #include "StringUtils.h"
 #include <wx/config.h>
 #include <wx/fileconf.h>
@@ -249,9 +248,9 @@ void Configuration::ResetAllToDefaults() {
 
   m_wizardTab = 0;
   for (const auto &i : m_renderableChars)
-    m_renderableChars[i.first] = wxEmptyString;
+    m_renderableChars[i.first].Clear();
   for (const auto &i : m_nonRenderableChars)
-    m_nonRenderableChars[i.first] = wxEmptyString;
+    m_nonRenderableChars[i.first].Clear();
   m_showAllDigits = false;
   m_lineBreaksInLongNums = false;
   m_autoSaveMinutes = 3;
@@ -278,7 +277,7 @@ void Configuration::ResetAllToDefaults() {
 #else
   m_usepngCairo = true;
 #endif
-  m_wxMathML_Filename = wxEmptyString;
+  m_wxMathML_Filename.Clear();
 
   m_mathJaxURL =
     wxS("https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js");
@@ -573,35 +572,53 @@ void Configuration::ShowCodeCells(bool show) {
   m_showCodeCells = show;
 }
 
-void Configuration::SetBackgroundBrush(wxBrush brush) {
+void Configuration::SetBackgroundBrush(const wxBrush &brush) {
   m_BackgroundBrush = brush;
   m_tooltipBrush = brush;
   m_tooltipBrush.SetColour(wxColour(255, 255, 192, 128));
 }
 
-bool Configuration::MaximaFound(wxString location) {
-  if (location == wxEmptyString)
-    return false;
+wxString Configuration::FindProgram(const wxString &location) {
+  if (location.IsEmpty())
+    return location;
 
-  bool maximaFound = false;
   if (wxFileExists(location))
-    maximaFound = true;
+    return location;
+  
+  wxString exePath;
+  #if defined __WXOSX__
+  // Find the program within our application bundle.
+  exePath = wxStandardPaths::Get().GetExecutablePath() + wxS("/Contents/Resources/") + location;
+  if (wxFileExists(exePath))
+    return exePath;
+  #endif
 
-  // Find a maxima within an application package.
-  if (wxFileExists(location + wxS("/Contents/Resources/maxima.sh")))
-    maximaFound = true;
-
-  // Don't complain if PATH doesn't yield a result.
-  SuppressErrorDialogs logNull;
+  exePath = wxStandardPaths::Get().GetExecutablePath() + location;
+  if (wxFileExists(exePath))
+    return exePath;
+  
 
   if (!(location.EndsWith("/") || location.EndsWith("\\"))) {
     wxPathList pathlist;
     pathlist.AddEnvList(wxS("PATH"));
     wxString path = pathlist.FindAbsoluteValidPath(location);
     if (!path.empty())
-      maximaFound = true;
+      return path;
+    #if defined __WXMSW__
+    pathlist.FindAbsoluteValidPath(location + wxS(".exe"));
+    if (!path.empty())
+      return path;
+    pathlist.FindAbsoluteValidPath(location + wxS(".bat"));
+    if (!path.empty())
+      return path;
+    #endif
+    #if defined __WXOSX__
+    pathlist.FindAbsoluteValidPath(location + wxS(".app"));
+    if (!path.empty())
+      return path;
+    #endif
   }
-  return maximaFound;
+  return wxEmptyString;
 }
 
 void Configuration::ReadConfig() {
@@ -631,9 +648,6 @@ void Configuration::ReadConfig() {
   config->SetPath("/");
 
   {
-    // If this preference cannot be loaded we don't want an error message about
-    // it
-    SuppressErrorDialogs suppressor;
     wxString hideMessagesConfigString;
     config->Read(wxS("Print/Margin/Top"), &m_printMargin_Top);
     config->Read(wxS("Print/Margin/Bot"), &m_printMargin_Bot);
@@ -642,6 +656,8 @@ void Configuration::ReadConfig() {
     config->Read(wxS("showAllDigits"), &m_showAllDigits);
     config->Read(wxS("lineBreaksInLongNums"), &m_lineBreaksInLongNums);
     config->Read(wxS("autoSaveMinutes"), &m_autoSaveMinutes);
+    if (m_autoSaveMinutes <= 0)
+      m_autoSaveMinutes = 3;
     config->Read(wxS("wrapLatexMath"), &m_wrapLatexMath);
     config->Read(wxS("allowNetworkHelp"), &m_allowNetworkHelp);
     config->Read(wxS("exportContainsWXMX"), &m_exportContainsWXMX);
@@ -743,6 +759,9 @@ void Configuration::ReadConfig() {
   if (m_maxClipbrd_BitmapMegabytes < 0)
     m_maxClipbrd_BitmapMegabytes = 1;
   config->Read(wxS("wizardTab"), &m_wizardTab);
+  #ifdef __WXMSW__
+  config->Read("usewgnuplot", &m_useWgnuplot);
+  #endif
   config->Read(wxS("numpadEnterEvaluates"), &m_numpadEnterEvaluates);
   config->Read(wxS("saveImgFileName"), &m_saveImgFileName);
   config->Read(wxS("usePartialForDiff"), &m_usePartialForDiff);
@@ -1060,16 +1079,16 @@ long Configuration::GetLineWidth() const {
 }
 
 //! A comparison operator for wxImage
-static bool operator==(const wxImage &a, const wxImage &b) {
-  if (a.GetSize() != b.GetSize())
-    return false;
+// static bool operator==(const wxImage &a, const wxImage &b) {
+//   if (a.GetSize() != b.GetSize())
+//     return false;
 
-  long bytes = (long)a.GetWidth() * b.GetHeight() * 3;
-  if (bytes < 0)
-    return false;
+//   long bytes = (long)a.GetWidth() * b.GetHeight() * 3;
+//   if (bytes < 0)
+//     return false;
 
-  return memcmp(a.GetData(), b.GetData(), bytes) == 0;
-}
+//   return memcmp(a.GetData(), b.GetData(), bytes) == 0;
+// }
 
 void Configuration::SetZoomFactor(double newzoom) {
   if(m_zoomFactor == newzoom)
@@ -1077,7 +1096,7 @@ void Configuration::SetZoomFactor(double newzoom) {
 
   RecalculateForce();
 
-  for (auto &i: m_styles)
+  for (const auto &i: m_styles)
     i.ClearCache();
   if (newzoom > GetMaxZoomFactor())
     newzoom = GetMaxZoomFactor();
@@ -1095,72 +1114,72 @@ Configuration::~Configuration() {
     }
 }
 
-bool Configuration::CharsExistInFont(const wxFont &font,
-                                     const wxString &chars) {
-  wxASSERT(!chars.empty());
-  for (auto const &ex : m_charsInFont)
-    // cppcheck-suppress useStlAlgorithm
-    if (ex.chars == chars)
-      return ex.exist;
+// bool Configuration::CharsExistInFont(const wxFont &font,
+//                                      const wxString &chars) {
+//   wxASSERT(!chars.empty());
+//   for (auto const &ex : m_charsInFont)
+//     // cppcheck-suppress useStlAlgorithm
+//     if (ex.chars == chars)
+//       return ex.exist;
 
-  auto const cache = [this, &chars](bool result) {
-    m_charsInFont.emplace_back(chars, result);
-    return result;
-  };
+//   auto const cache = [this, &chars](bool result) {
+//     m_charsInFont.emplace_back(chars, result);
+//     return result;
+//   };
 
-  if (!font.IsOk())
-    return cache(false);
+//   if (!font.IsOk())
+//     return cache(false);
 
-  // Seems like Apple didn't hold to their high standards as the maths part of
-  // this font don't form nice big mathematical symbols => Blacklisting this
-  // font.
-  if (font.GetFaceName() == wxS("Monaco"))
-    return cache(false);
+//   // Seems like Apple didn't hold to their high standards as the maths part of
+//   // this font don't form nice big mathematical symbols => Blacklisting this
+//   // font.
+//   if (font.GetFaceName() == wxS("Monaco"))
+//     return cache(false);
 
-  if (!m_useUnicodeMaths)
-    return cache(false);
+//   if (!m_useUnicodeMaths)
+//     return cache(false);
 
-  struct Params {
-    wxUniChar ch;
-    wxSize size;
-    wxImage image;
-    explicit Params(wxUniChar ch) : ch(ch) {}
-  };
-  std::vector<Params> P(chars.begin(), chars.end());
+//   struct Params {
+//     wxUniChar ch;
+//     wxSize size;
+//     wxImage image;
+//     explicit Params(wxUniChar ch) : ch(ch) {}
+//   };
+//   std::vector<Params> P(chars.begin(), chars.end());
 
-  // Letters with width or height = 0 don't exist in the current font
-  GetRecalcDC()->SetFont(font);
-  for (auto &p : P) {
-    wxCoord descent;
-    GetRecalcDC()->GetTextExtent(p.ch, &p.size.x, &p.size.y, &descent);
-    if ((p.size.x < 1) || ((p.size.y - descent) < 1))
-      return cache(false);
-  }
+//   // Letters with width or height = 0 don't exist in the current font
+//   GetRecalcDC()->SetFont(font);
+//   for (auto &p : P) {
+//     wxCoord descent;
+//     GetRecalcDC()->GetTextExtent(p.ch, &p.size.x, &p.size.y, &descent);
+//     if ((p.size.x < 1) || ((p.size.y - descent) < 1))
+//       return cache(false);
+//   }
 
-  bool allDifferentSizes = true;
-  for (auto i = P.begin(); allDifferentSizes && i != P.end(); ++i)
-    for (auto j = i + 1; allDifferentSizes && j != P.end(); ++j)
-      allDifferentSizes &= i->size != j->size;
+//   bool allDifferentSizes = true;
+//   for (auto i = P.begin(); allDifferentSizes && i != P.end(); ++i)
+//     for (auto j = i + 1; allDifferentSizes && j != P.end(); ++j)
+//       allDifferentSizes &= i->size != j->size;
 
-  if (allDifferentSizes)
-    return cache(true);
+//   if (allDifferentSizes)
+//     return cache(true);
 
-  for (auto &p : P) {
-    wxBitmap bmp(p.size);
-    wxMemoryDC dc(bmp);
-    dc.SetFont(font);
-    dc.Clear();
-    dc.DrawText(p.ch, wxPoint(0, 0));
-    p.image = bmp.ConvertToImage();
-  }
+//   for (auto &p : P) {
+//     wxBitmap bmp(p.size);
+//     wxMemoryDC dc(bmp);
+//     dc.SetFont(font);
+//     dc.Clear();
+//     dc.DrawText(p.ch, wxPoint(0, 0));
+//     p.image = bmp.ConvertToImage();
+//   }
 
-  for (auto i = P.begin(); i != P.end(); ++i)
-    for (auto j = i + 1; j != P.end(); ++j)
-      if (i->image == j->image)
-        return cache(false);
+//   for (auto i = P.begin(); i != P.end(); ++i)
+//     for (auto j = i + 1; j != P.end(); ++j)
+//       if (i->image == j->image)
+//         return cache(false);
 
-  return cache(true);
-}
+//   return cache(true);
+// }
 
 wxString Configuration::GetFontName(TextStyle const ts) const {
   wxString retval;
@@ -1315,7 +1334,9 @@ void Configuration::WriteSettings(const wxString &file) {
     config->Write(wxS("suppressYellowMarkerMessages"),
                   hideMessagesConfigString);
   }
-
+#ifdef __WXMSW__
+  config->Write("usewgnuplot", m_useWgnuplot);
+#endif
   config->Write("maximaHelpFormat", static_cast<long>(m_maximaHelpFormat));
   config->Write(wxS("Print/Margin/Top"), m_printMargin_Top);
   config->Write(wxS("Print/Margin/Bot"), m_printMargin_Bot);
@@ -1388,9 +1409,12 @@ wxColor Configuration::MakeColorDifferFromBackground(wxColor color) {
     return InvertColour(color);
   } else {
     int maxOldCol = std::max(std::max(color.Red(), color.Green()), color.Blue());
-    return wxColour(newBrightness * color.Red() / maxOldCol,
-                    newBrightness * color.Green() / maxOldCol,
-                    newBrightness * color.Blue() / maxOldCol);
+    if (maxOldCol < 1)
+      return *wxWHITE;
+    else
+      return wxColour(newBrightness * color.Red() / maxOldCol,
+                      newBrightness * color.Green() / maxOldCol,
+                      newBrightness * color.Blue() / maxOldCol);
   }
 }
 
@@ -1410,7 +1434,7 @@ bool Configuration::InUpdateRegion(wxRect const rect) const {
   return updateRegion.Intersects(rect);
 }
 
-bool Configuration::FontRendersChar(wxChar ch, const wxFont &font) {
+bool Configuration::FontRendersChar(wxUniChar ch, const wxFont &font) {
   wxString fontName = font.GetNativeFontInfoDesc();
   fontName.Replace("/", "_");
   if (m_renderableChars[fontName].Contains(ch))
@@ -1424,14 +1448,14 @@ bool Configuration::FontRendersChar(wxChar ch, const wxFont &font) {
     CharVisiblyDifferent(ch, L'\uF000', font);
 
   if (retval)
-    m_renderableChars[fontName] += wxString(ch);
+    m_renderableChars[fontName] += ch;
   else
-    m_nonRenderableChars[fontName] += wxString(ch);
+    m_nonRenderableChars[fontName] += ch;
 
   return retval;
 }
 
-bool Configuration::FontDisplaysChar(wxChar ch, const wxFont &font) {
+bool Configuration::FontDisplaysChar(wxUniChar ch, const wxFont &font) {
   int width = 200;
   int height = 200;
 
@@ -1455,7 +1479,7 @@ bool Configuration::FontDisplaysChar(wxChar ch, const wxFont &font) {
 
   // Now draw the character our button shows into one of these bitmaps and see
   // if that changed any aspect of the bitmap
-  characterDC.DrawText(wxString(ch), 100, 100);
+  characterDC.DrawText(ch, 100, 100);
   wxImage characterImage = characterBitmap.ConvertToImage();
   wxImage referenceImage = referenceBitmap.ConvertToImage();
   for (int x = 0; x < width; x++)
@@ -1690,7 +1714,29 @@ const wxString &Configuration::GetStyleName(TextStyle textStyle) {
     return wxm::emptyString;
 }
 
+std::size_t Configuration::ShowLength_Bytes() const
+{
+  std::size_t showLength;
+  switch (ShowLength()) {
+  case 0:
+    showLength = 6000;
+    break;
+  case 1:
+    showLength = 20000;
+    break;
+  case 2:
+    showLength = 100000;
+    break;
+  case 3:
+    showLength = 0;
+    break;
+  default:
+    showLength = 6000;
+  }
+  return showLength;
+}
 wxString Configuration::m_configfileLocation_override;
 std::unordered_map<TextStyle, wxString> Configuration::m_styleNames;
 bool Configuration::m_debugMode = false;
 bool Configuration::m_use_threads = true;
+wxString Configuration::m_maxima_LANG;
