@@ -39,10 +39,12 @@
 #include <vector>
 #include <algorithm>
 #include <wx/wupdlock.h>
+#ifdef USE_WEBVIEW
 #include <wx/webview.h>
 #ifdef __WXMSW__
 #include <wx/msw/webview_ie.h>
 #endif
+#endif
 
 #define MC_LINE_SKIP Scale_Px(2)
 #define MC_TEXT_PADDING Scale_Px(1)
@@ -65,16 +67,9 @@
 static constexpr AFontSize MC_MIN_SIZE{ 6.0f };
 static constexpr AFontSize MC_MAX_SIZE{ 48.0f };
 
-#define LIBERTINE1 "LinLibertine_DRah.ttf"
-#define LIBERTINE2 "LinLibertine_I.ttf"
-#define LIBERTINE3 "LinLibertine_Mah.ttf"
-#define LIBERTINE4 "LinLibertine_Rah.ttf"
-#define LIBERTINE5 "LinLibertine_RBah.ttf"
-#define LIBERTINE6 "LinLibertine_RBIah.ttf"
-#define LIBERTINE7 "LinLibertine_RIah.ttf"
-#define LIBERTINE8 "LinLibertine_RZah.ttf"
-#define LIBERTINE9 "LinLibertine_RZIah.ttf"
-
+// The minimal and maximal label width
+#define LABELWIDTH_MIN 3
+#define LABELWIDTH_MAX 10
 class Cell;
 
 /*! The configuration storage for the current worksheet.
@@ -182,7 +177,7 @@ public:
   void UnsetContext() {m_dc = NULL;}
 
   //! Set the brush to be used for the worksheet background
-  void SetBackgroundBrush(wxBrush brush);
+  void SetBackgroundBrush(const wxBrush &brush);
   //! Use a typewriter font in wizard entry fields that can contain maxima commands?
   bool FixedFontInTextControls() const {return m_fixedFontTC;}
   //! Use a typewriter font in wizard entry fields that can contain maxima commands?
@@ -643,7 +638,7 @@ public:
   class TextsnippetToDraw
   {
   public:
-    TextsnippetToDraw(const wxPoint &pos, const wxString &text, const wxColor color):
+    TextsnippetToDraw(const wxPoint &pos, const wxString &text, const wxColor &color):
       m_pos(pos),
       m_text(text),
       m_color(color)
@@ -808,7 +803,7 @@ public:
     If location == wxEmptyString the default location from the configuration
     is taken.
   */
-  static bool MaximaFound(wxString location = wxEmptyString);
+  static wxString FindProgram(const wxString &location);
 
   //! Renumber out-of-order cell labels on saving.
   bool FixReorderedIndices() const
@@ -840,7 +835,7 @@ public:
   bool CopyMathMLHTML() const {return m_copyMathMLHTML;}
   void CopyMathMLHTML(bool copyMathMLHTML){ m_copyMathMLHTML = copyMathMLHTML; }
   bool HideMarkerForThisMessage(wxString message);
-  void HideMarkerForThisMessage(wxString message, bool hide)
+  void HideMarkerForThisMessage(const wxString &message, bool hide)
     {m_hideMarkerForThisMessage[message] = hide;}
   bool CopyRTF() const {return m_copyRTF;}
   void CopyRTF(bool copyRTF) { m_copyRTF = copyRTF; }
@@ -850,10 +845,14 @@ public:
   void CopyEMF(bool copyEMF) { m_copyEMF = copyEMF; }
   bool UseSVG() const {return m_useSVG;}
   void UseSVG(bool useSVG) { m_useSVG = useSVG ;}
-  void ShowLength(long length) { m_showLength = length; }
+  //! The choice for the "maximum output length to display" setting
+  void ShowLength(long length) {
+    m_showLength = length;
+  }
+  //! The choice for the "maximum output length to display" setting
   long ShowLength() const {return m_showLength;}
-  void LispType(wxString type) { m_lispType = std::move(type); }
-  wxString LispType() const {return m_lispType;}
+  //! The "maximum output length to display" setting in cells
+  std::size_t ShowLength_Bytes() const;
 
   //! Which way do we want to draw parenthesis?
   void SetParenthesisDrawMode(drawMode mode) {
@@ -943,6 +942,8 @@ public:
   wxPoint GetWorksheetPosition() const {return m_worksheetPosition;}
   wxString MaximaShareDir() const {return m_maximaShareDir;}
   void MaximaShareDir(wxString dir){m_maximaShareDir = std::move(dir);}
+  wxString MaximaDemoDir() const {return m_maximaDemoDir;}
+  void MaximaDemoDir(wxString dir){m_maximaDemoDir = std::move(dir);}
   void InLispMode(bool lisp){m_inLispMode = lisp;}
   bool InLispMode() const {return m_inLispMode;}
   void BitmapScale(int factor){m_bitmapScale = factor;}
@@ -1007,14 +1008,27 @@ public:
   void Display2d_Unicode(bool unicode){m_display2d_Unicode = unicode;}
   bool Display2d_Unicode() const {return m_display2d_Unicode;}
 
+  #ifdef __WXMSW__
+  bool UseWGnuplot() const {return m_useWgnuplot;}
+  void UseWGnuplot(bool usewgnuplot) {m_useWgnuplot = usewgnuplot;}
+  #endif
   wxString TexPreamble() const {return m_texPreamble;}
   void TexPreamble(wxString texPreamble) {m_texPreamble = std::move(texPreamble);}
 
+  void SetMaximaVersion(const wxString &version){m_maximaVersion = version;}
+  wxString GetMaximaVersion() const {return m_maximaVersion;}
+  void SetMaximaArch(const wxString &arch){m_maximaArch = arch;}
+  wxString GetMaximaArch() const {return m_maximaArch;}
+  void SetLispVersion(const wxString &version){m_lispVersion = version;}
+  wxString GetLispVersion() const {return m_lispVersion;}
+  void SetLispType(const wxString &type){m_lispType = type;}
+  wxString GetLispType() const {return m_lispType;}
+
   Style m_styles[NUMBEROFSTYLES];
   //! Initialize the text styles on construction.
   void InitStyles();
   //! True if we are confident that the font renders this char
-  bool FontRendersChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
+  bool FontRendersChar(wxUniChar ch, const wxFont &font = *wxNORMAL_FONT);
   wxTextCtrl *LastActiveTextCtrl() const { return m_lastActiveTextCtrl; }
   void LastActiveTextCtrl(wxTextCtrl *last);
 
@@ -1037,6 +1051,10 @@ public:
   void MaximaHelpFormat(maximaHelpFormat format) {m_maximaHelpFormat = format;}
 
 private:
+  wxString m_maximaArch;
+  wxString m_lispVersion;
+  wxString m_lispType;
+  wxString m_maximaVersion;
   //! The options this class got at initialization time
   InitOpt m_initOpts;
   /*! The id of the current configuration
@@ -1059,9 +1077,13 @@ public:
   */
   std::int_fast32_t CellCfgCnt() const {return m_cellCfgCnt;}
   void RecalculateForce() { m_cellCfgCnt++; }
-  bool UseThreads(){return m_use_threads;}
+  static bool UseThreads(){return m_use_threads;}
   static void UseThreads(bool use){m_use_threads = use;}
+  static void SetMaximaLang(const wxString &LANG){m_maxima_LANG = LANG;}
+  static wxString GetMaximaLang(){return m_maxima_LANG;}
 private:
+  //! Which LANG environment variable to communicate to maxima?
+  static wxString m_maxima_LANG;
   //! Which styles affect how code is displayed?
   std::vector<TextStyle> m_codeStyles;
   //! Which styles affect how math output is displayed?
@@ -1072,7 +1094,7 @@ private:
   RenderablecharsHash m_renderableChars;
   RenderablecharsHash m_nonRenderableChars;
   //! True if drawing the char this button displays alters at least one pixel
-  static bool FontDisplaysChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
+  static bool FontDisplaysChar(wxUniChar ch, const wxFont &font = *wxNORMAL_FONT);
   //! True if drawing the char this button displays differs visibly from otherChar
   static bool CharVisiblyDifferent(wxChar ch, wxChar otherChar, const wxFont &font = *wxNORMAL_FONT);
   mathDisplayMode m_displayMode = display_2d;
@@ -1118,7 +1140,7 @@ private:
     As these might be costly operations it is important to cache the result
     of this function.
   */
-  bool CharsExistInFont(const wxFont &font, const wxString& chars);
+//  bool CharsExistInFont(const wxFont &font, const wxString& chars);
   //! Caches the information on how to draw big parenthesis for GetParenthesisDrawMode().
   bool m_wrapLatexMath;
   bool m_allowNetworkHelp;
@@ -1175,6 +1197,7 @@ private:
   double m_zoomFactor;
   wxDC *m_dc;
   wxString m_maximaShareDir;
+  wxString m_maximaDemoDir;
   bool m_forceUpdate;
   bool m_clipToDrawRegion = true;
   bool m_outdated;
@@ -1238,12 +1261,14 @@ private:
   wxBrush m_BackgroundBrush;
   wxBrush m_tooltipBrush;
   bool m_greekSidebar_ShowLatinLookalikes;
+  #ifdef __WXMSW__
+  bool m_useWgnuplot = false;
+  #endif
   bool m_greekSidebar_Show_mu;
   wxString m_symbolPaneAdditionalChars;
   bool m_invertBackground;
   long m_undoLimit;
   long m_recentItems;
-  wxString m_lispType;
   int m_bitmapScale;
   int m_defaultFramerate;
   int m_tocDepth;
