@@ -57,29 +57,26 @@
 class Dirstructure
 {
 public:
-  //! The constructor
+  //! The constructor and destructor
   Dirstructure();
-
+  ~Dirstructure(){ m_dirStructure = NULL; }
 private:
   //! The directory all data is stored relative to.
-  wxString ResourcesDir() const;
+  static wxString ResourcesDir();
 
 public:
   //! The directory the user stores its data in.
   static wxString UserConfDir() {return m_userConfDir;}
   //! Set the directory the user stores its data in.
-  static void UserConfDir(wxString userConfDir);
+  static void UserConfDir(const wxString &userConfDir);
 
   //! The directory general data is stored in
-  wxString DataDir() const;
-
-  //! The directory our private fonts are stored in
-  wxString FontDir() const {return DataDir()+wxS("/../fonts");}
+  static wxString DataDir();
 
   //! The directory the help file is stored in
   wxString HelpDir() const {return m_helpDir;}
   //! Set the directory the help file is stored in
-  void HelpDir(wxString helpDir){m_helpDir = helpDir;}
+  void HelpDir(const wxString &helpDir){m_helpDir = helpDir;}
 
   /*! The file private accelerator key information is stored in
 
@@ -87,21 +84,20 @@ public:
   static wxString UserAutocompleteFile();
 
   //! The path to wxMaxima's own AutoComplete file
-  wxString AutocompleteFile() const
+  static wxString AutocompleteFile()
     { return DataDir() + wxS("/autocomplete.txt"); }
 
   /*! The directory the locale data is to be found in
 
     Is only used on MSW and MAC
   */
-  wxString LocaleDir() const
+  static wxString LocaleDir()
     { return ResourcesDir() + wxS("/locale"); }
 
   //! The executable file path to the maxima executable (or .bat on Windows)
   static wxString MaximaDefaultLocation();
 
-  static wxString
-  AnchorsCacheFile()
+  static wxString AnchorsCacheFile()
     {
       return UserConfDir() + "/manual_anchors.xml";
     }
