@@ -24,6 +24,7 @@
   This file defines the class EventIDs that contains unique IDs for many events
   wxMaxima needs.
 */
+#include "Configuration.h"
 #include "EventIDs.h"
 #include <wx/utils.h>
 #include <wx/window.h>
@@ -35,7 +36,6 @@ const wxWindowIDRef EventIDs::menu_pane_xmlInspector(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_format(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_greek(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_unicode(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::menu_pane_log(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_variables(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_draw(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_pane_help(wxWindow::NewControlId());
@@ -374,6 +374,21 @@ const wxWindowIDRef EventIDs::menu_animationautostart(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_animationframerate(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_display(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_soft_restart(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_dependencies(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_values(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_functions(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_arrays(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_myoptions(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_rules(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_aliases(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_structures(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_labels(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_gradefs(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_props(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_macros(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_kill_let_rule_packages(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_garbage_collect(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_room(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_plot_format(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_build_info(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_bug_report(wxWindow::NewControlId());
@@ -461,6 +476,7 @@ const wxWindowIDRef EventIDs::menu_autocomplete(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_autocomplete_templates(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_paste_input(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_fullscreen(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_show_logwindow(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_remove_output(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_list_create_from_elements(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_list_create_from_rule(wxWindow::NewControlId());
@@ -492,11 +508,11 @@ const wxWindowIDRef EventIDs::menu_list_append_item_end(wxWindow::NewControlId()
 const wxWindowIDRef EventIDs::menu_list_append_list(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_list_interleave(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_recent_packages(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::menu_recent_package_0(wxWindow::NewControlId(NumberOfRecentFiles()));
+const wxWindowIDRef EventIDs::menu_recent_package_0(wxWindow::NewControlId(NumberOfRecentFiles));
 const wxWindowIDRef EventIDs::menu_unsaved_documents(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::menu_recent_document_0(wxWindow::NewControlId(NumberOfRecentFiles()));
+const wxWindowIDRef EventIDs::menu_recent_document_0(wxWindow::NewControlId(NumberOfRecentFiles));
 const wxWindowIDRef EventIDs::menu_recent_documents(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::menu_unsaved_document_0(wxWindow::NewControlId(NumberOfRecentFiles()));
+const wxWindowIDRef EventIDs::menu_unsaved_document_0(wxWindow::NewControlId(NumberOfRecentFiles));
 const wxWindowIDRef EventIDs::menu_construct_fraction(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_insert_image(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_stats_mean(wxWindow::NewControlId());
@@ -527,6 +543,7 @@ const wxWindowIDRef EventIDs::menu_format_title(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_format_image(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_format_pagebreak(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tutorials(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_help_maxima_homepage(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_demo_for_command(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tutorials_start(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_solving(wxWindow::NewControlId());
@@ -536,6 +553,7 @@ const wxWindowIDRef EventIDs::menu_help_numberformats(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tolerances(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_listaccess(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_memoizing(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_help_2d(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_3d(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_varnames(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_fittingData(wxWindow::NewControlId());
@@ -596,7 +614,7 @@ const wxWindowIDRef EventIDs::popid_labels_useronly(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_labels_autogenerated(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_inputlabels_hide(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_labelwidth(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::popid_labelwidth1(wxWindow::NewControlId(NumberOfLabelWidths()));
+const wxWindowIDRef EventIDs::popid_labelwidth1(wxWindow::NewControlId(LABELWIDTH_MAX - LABELWIDTH_MIN));
 const wxWindowIDRef EventIDs::popid_digits_20(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_digits_50(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_digits_100(wxWindow::NewControlId());
@@ -619,7 +637,7 @@ const wxWindowIDRef EventIDs::popid_insert_subsubsection(wxWindow::NewControlId(
 const wxWindowIDRef EventIDs::popid_insert_heading5(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_insert_heading6(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_auto_answer(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::popid_autocomplete_keyword1(wxWindow::NewControlId(NumberOfAutocompleteKeywords()));
+const wxWindowIDRef EventIDs::popid_autocomplete_keyword1(wxWindow::NewControlId(NumberOfAutocompleteKeywords));
 const wxWindowIDRef EventIDs::popid_never_autoanswer(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_popup_gnuplot(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_fold(wxWindow::NewControlId());
@@ -627,7 +645,6 @@ const wxWindowIDRef EventIDs::popid_unfold(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_maxsizechooser(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_resolutionchooser(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_reloadimage(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::popid_suggestion1(wxWindow::NewControlId(NumberOfSuggestions()));
 const wxWindowIDRef EventIDs::popid_hide_tooltipMarker(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_hide_tooltipMarkerForThisMessage(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_property_real(wxWindow::NewControlId());
@@ -672,7 +689,7 @@ const wxWindowIDRef EventIDs::popid_Unfold(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_SelectTocChapter(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_EvalTocChapter(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_ToggleTOCshowsSectionNumbers(wxWindow::NewControlId());
-const wxWindowIDRef EventIDs::popid_tocLevel1(wxWindow::NewControlId(NumberOfTocLevels()));
+const wxWindowIDRef EventIDs::popid_tocLevel1(wxWindow::NewControlId(NumberOfTocLevels));
 const wxWindowIDRef EventIDs::popid_tocdnd(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_tocMoveIn(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::popid_tocMoveOut(wxWindow::NewControlId());
