@@ -50,15 +50,15 @@ class EventIDs
 public:
   EventIDs();
   //! How many IDs we have reserved for autocompletion keywords?
-  static constexpr int NumberOfAutocompleteKeywords() {return 25;}
+  static constexpr int NumberOfAutocompleteKeywords = 25;
   //! How many IDs we have reserved for recent files/packages?
-  static constexpr int NumberOfRecentFiles()  {return 30;}
+  static constexpr int NumberOfRecentFiles = 30;
   //! How many IDs we have reserved for suggestions of similar command names?
-  static constexpr int NumberOfSuggestions()  {return 10;}
-  //! How many IDs we have reserved for label width choices?
-  static constexpr int NumberOfLabelWidths()  {return 10;}
+  // Note: If this value is changed, the enum with the IDs (popid_suggestion1, ...)
+  // must be changed too.
+  static constexpr int NumberOfSuggestions = 10;
   //! How many IDs have we reserved for table of contents depths
-  static constexpr int NumberOfTocLevels()  {return 6;}
+  static constexpr int NumberOfTocLevels = 6;
 /*! @{
   This list serves several purposes:
   - wxwidgets uses this list to tell us what kind of events it has to inform us about.
@@ -94,7 +94,6 @@ public:
   static const wxWindowIDRef menu_pane_format;    //!< Both the "toggle the format pane" command and the format pane
   static const wxWindowIDRef menu_pane_greek;     //!< Both the "toggle the greek pane" command and the "greek" pane
   static const wxWindowIDRef menu_pane_unicode;   //!< Both the "toggle the unicode pane" command and the "unicode" pane
-  static const wxWindowIDRef menu_pane_log;       //!< Both the "toggle the log pane" command and the "log" pane
   static const wxWindowIDRef menu_pane_variables; //!< Both the "toggle the variables pane" command and the "variables" pane
   static const wxWindowIDRef menu_pane_draw;      //!< Both the "toggle the draw pane" command for the "draw" pane
   static const wxWindowIDRef menu_pane_help;      //!< Both the "toggle the draw pane" command for the help browser
@@ -438,6 +437,21 @@ public:
   static const wxWindowIDRef menu_animationframerate;
   static const wxWindowIDRef menu_display;
   static const wxWindowIDRef menu_soft_restart;
+  static const wxWindowIDRef menu_kill_dependencies;
+  static const wxWindowIDRef menu_kill_values;
+  static const wxWindowIDRef menu_kill_functions;
+  static const wxWindowIDRef menu_kill_arrays;
+  static const wxWindowIDRef menu_kill_myoptions;
+  static const wxWindowIDRef menu_kill_rules;
+  static const wxWindowIDRef menu_kill_aliases;
+  static const wxWindowIDRef menu_kill_structures;
+  static const wxWindowIDRef menu_kill_labels;
+  static const wxWindowIDRef menu_kill_gradefs;
+  static const wxWindowIDRef menu_kill_props;
+  static const wxWindowIDRef menu_kill_macros;
+  static const wxWindowIDRef menu_kill_let_rule_packages;
+  static const wxWindowIDRef menu_garbage_collect;
+  static const wxWindowIDRef menu_room;
   static const wxWindowIDRef menu_plot_format;
   static const wxWindowIDRef menu_build_info;
   static const wxWindowIDRef menu_bug_report;
@@ -529,6 +543,7 @@ public:
   static const wxWindowIDRef menu_autocomplete_templates;
   static const wxWindowIDRef menu_paste_input;
   static const wxWindowIDRef menu_fullscreen;
+  static const wxWindowIDRef menu_show_logwindow;
   static const wxWindowIDRef menu_remove_output;
   static const wxWindowIDRef menu_list_create_from_elements;
   static const wxWindowIDRef menu_list_create_from_rule;
@@ -598,6 +613,7 @@ public:
   static const wxWindowIDRef menu_regex_isTextSearch;
   static const wxWindowIDRef menu_help_demo_for_command;
   static const wxWindowIDRef menu_help_tutorials;
+  static const wxWindowIDRef menu_help_maxima_homepage;
   static const wxWindowIDRef menu_help_tutorials_start; //! Start of bundled tutorials
   static const wxWindowIDRef menu_help_solving;
   static const wxWindowIDRef menu_help_casvsprogramming;
@@ -606,6 +622,7 @@ public:
   static const wxWindowIDRef menu_help_tolerances;
   static const wxWindowIDRef menu_help_listaccess;
   static const wxWindowIDRef menu_help_memoizing;
+  static const wxWindowIDRef menu_help_2d;
   static const wxWindowIDRef menu_help_3d;
   static const wxWindowIDRef menu_help_varnames;
   static const wxWindowIDRef menu_help_fittingData;
@@ -695,16 +712,22 @@ public:
   static const wxWindowIDRef popid_maxsizechooser;
   static const wxWindowIDRef popid_resolutionchooser;
   static const wxWindowIDRef popid_reloadimage;
-  static const wxWindowIDRef popid_suggestion1;
-  static const wxWindowIDRef popid_suggestion2;
-  static const wxWindowIDRef popid_suggestion3;
-  static const wxWindowIDRef popid_suggestion4;
-  static const wxWindowIDRef popid_suggestion5;
-  static const wxWindowIDRef popid_suggestion6;
-  static const wxWindowIDRef popid_suggestion7;
-  static const wxWindowIDRef popid_suggestion8;
-  static const wxWindowIDRef popid_suggestion9;
-  static const wxWindowIDRef popid_suggestion10;
+
+  // remark: popid_suggestion2 .. popid_suggestion10 is nowhere used in the code.
+  // But we need NumberOfSuggestions (currently 10) IDs, and maybe later the enum
+  // with the IDs will be extended.
+  enum {
+    popid_suggestion1 = wxID_HIGHEST+1,
+    popid_suggestion2,
+    popid_suggestion3,
+    popid_suggestion4,
+    popid_suggestion5,
+    popid_suggestion6,
+    popid_suggestion7,
+    popid_suggestion8,
+    popid_suggestion9,
+    popid_suggestion10
+  };
   static const wxWindowIDRef popid_hide_tooltipMarker;
   static const wxWindowIDRef popid_hide_tooltipMarkerForThisMessage;
   static const wxWindowIDRef popid_property_real;
