@@ -28,7 +28,6 @@
 #include "precomp.h"
 #include "cells/Cell.h"
 #include "Version.h"
-#include "ErrorRedirector.h"
 #include <wx/image.h>
 #include <wx/rawbmp.h>
 
@@ -55,7 +54,7 @@ Image::Image(Configuration *config) {
   InvalidBitmap();
 }
 
-Image::Image(Configuration *config, wxMemoryBuffer image, wxString type) {
+Image::Image(Configuration *config, const wxMemoryBuffer &image, const wxString &type) {
   m_configuration = config;
   m_scaledBitmap.Create(1, 1);
   m_compressedImage = image;
@@ -87,9 +86,8 @@ Image::Image(Configuration *config, const wxBitmap &bitmap) {
 }
 
 // constructor which loads an image
-// cppcheck-suppress performance symbolName=filesystem
-Image::Image(Configuration *config, wxString image,
-             wxString wxmxFile, bool remove)
+Image::Image(Configuration *config, const wxString &image,
+             const wxString &wxmxFile, bool remove)
 {
   m_svgImage = NULL;
   m_configuration = config;
@@ -112,7 +110,6 @@ Image::Image(Configuration *config, const Image &image) {
 }
 
 Image::~Image() {
-  wxLogNull logNull;
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
   if(m_loadGnuplotSourceTask.joinable())
@@ -161,7 +158,6 @@ wxBitmap Image::GetUnscaledBitmap() {
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
 
-  SuppressErrorDialogs logNull;
   if (m_svgRast) {
     std::vector<unsigned char> imgdata(m_originalWidth * m_originalHeight * 4);
 
@@ -201,8 +197,7 @@ std::size_t Image::GetOriginalHeight() const {
 }
 
 void Image::GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                          wxString wxmxFile) {
-  SuppressErrorDialogs suppressor;
+                          const wxString &wxmxFile) {
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
   m_gnuplotSource = std::move(gnuplotFilename);
@@ -210,10 +205,10 @@ void Image::GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
   std::unique_ptr<ThreadNumberLimiter> limiter(new
                                                ThreadNumberLimiter(&m_gnuplotDataThreadRunning));
   if(m_configuration->UseThreads())
-    m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask,
-                                          this,
-                                          std::move(limiter),
-                                          m_gnuplotSource, m_gnuplotData, wxmxFile);
+    m_loadGnuplotSourceTask = jthread(&Image::LoadGnuplotSource_Backgroundtask,
+                                      this,
+                                      std::move(limiter),
+                                      m_gnuplotSource, m_gnuplotData, wxmxFile);
   else
     LoadGnuplotSource_Backgroundtask(
       std::move(limiter),
@@ -225,7 +220,6 @@ void Image::LoadGnuplotSource_Backgroundtask(
   wxString gnuplotFile, wxString dataFile, wxString wxmxFile)
 {
   std::unique_ptr<ThreadNumberLimiter> threadNumLimit = std::move(limiter);
-  SuppressErrorDialogs suppressor;
   if(wxmxFile.IsEmpty())
   {
     {
@@ -253,7 +247,7 @@ void Image::LoadGnuplotSource_Backgroundtask(
 }
 
 void Image::CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                                    wxString wxmxFile) {
+                                    const wxString &wxmxFile) {
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
   std::unique_ptr<ThreadNumberLimiter> limiter(new
@@ -263,12 +257,12 @@ void Image::CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilen
   m_gnuplotData = std::move(dataFilename);
   if(m_configuration->UseThreads())
     m_loadGnuplotSourceTask =
-      std::thread(&Image::LoadCompressedGnuplotSource_Backgroundtask,
-                  this,
-                  std::move(limiter),
-                  m_gnuplotSource,
-                  m_gnuplotData,
-                  wxmxFile);
+      jthread(&Image::LoadCompressedGnuplotSource_Backgroundtask,
+              this,
+              std::move(limiter),
+              m_gnuplotSource,
+              m_gnuplotData,
+              wxmxFile);
   else
     LoadCompressedGnuplotSource_Backgroundtask(
       std::move(limiter),
@@ -307,12 +301,11 @@ void Image::LoadGnuplotSource(
     // A RegEx that matches the name of the data file (needed if we ever
     // want to move a data file into the temp directory of a new computer
     // that locates its temp data somewhere strange).
-    wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9]*\\.data'");
+    // TODO: Manipulates a variable that isn't used at all.
+    wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[_0-9]*\\.data'");
     while (!source->Eof()) {
       line = textIn.ReadLine();
       if (replaceDataFileName.Matches(line)) {
-        wxString dataFileName;
-        dataFileName = replaceDataFileName.GetMatch(line);
         replaceDataFileName.Replace(&line, wxS("'<DATAFILENAME>'"));
       }
       textOut << line + wxS("\n");
@@ -367,9 +360,6 @@ void Image::LoadCompressedGnuplotSource_Backgroundtask(
   ) {
   std::unique_ptr<ThreadNumberLimiter> threadNumLimit = std::move(limiter);
   {
-    // Error dialogues need to be created by the foreground thread.
-    SuppressErrorDialogs suppressor;
-
     // Read the gnuplot source
     {
       wxFileInputStream wxmx(wxmxFile);
@@ -399,7 +389,7 @@ void Image::LoadCompressedGnuplotSource_Backgroundtask(
   }
 }
 
-Image::WxmxStream::WxmxStream(wxInputStream &wxmxFile, wxString fileInWxmx):
+Image::WxmxStream::WxmxStream(wxInputStream &wxmxFile, const wxString &fileInWxmx):
   wxZipInputStream(wxmxFile, wxConvLocal)
 {
   while(!Eof())
@@ -690,7 +680,7 @@ wxBitmap Image::GetBitmap(double scale) {
   return m_scaledBitmap;
 }
 
-void Image::InvalidBitmap(wxString message) {
+void Image::InvalidBitmap(const wxString &message) {
   m_originalWidth = m_width = 1200 * m_ppi / 96;
   m_originalHeight = m_height = 900 * m_ppi / 96;
   // Create a "image not loaded" bitmap.
@@ -767,7 +757,7 @@ wxString Image::GetExtension() const {
   return m_extension;
 }
 
-void Image::LoadImage(wxString image, wxString wxmxFile,
+void Image::LoadImage(wxString image, const wxString &wxmxFile,
                       bool remove) {
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
@@ -779,16 +769,16 @@ void Image::LoadImage(wxString image, wxString wxmxFile,
   m_compressedImage.Clear();
   m_scaledBitmap.Create(1, 1);
   if(m_configuration->UseThreads())
-    m_loadImageTask = std::thread(&Image::LoadImage_Backgroundtask,
-                                  this,
-                                  std::move(limiter),
-                                  std::move(image), std::move(wxmxFile),
-                                  remove
+    m_loadImageTask = jthread(&Image::LoadImage_Backgroundtask,
+                              this,
+                              std::move(limiter),
+                              std::move(image), wxmxFile,
+                              remove
       );
   else
     LoadImage_Backgroundtask(
       std::move(limiter),
-      std::move(image), std::move(wxmxFile),
+      std::move(image), wxmxFile,
       remove
       );
 }
@@ -835,7 +825,6 @@ void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limite
       InvalidBitmap(errorAggregator.GetBuffer());
   }
 
-  SuppressErrorDialogs suppressor;
   wxImage Image;
   if (m_compressedImage.GetDataLen() > 0) {
     if ((m_extension == "svg") || (m_extension == "svgz")) {
@@ -991,9 +980,8 @@ void Image::Recalculate(double scale) {
     ClearCache();
 }
 
-const wxString &Image::GetBadImageToolTip() {
-  // cppcheck-suppress returnTempReference
-  return T_(
+const wxString Image::GetBadImageToolTip() {
+  return _(
     "The image could not be displayed. It may be broken, in a wrong format "
     "or "
     "be the result of gnuplot not being able to write the image or not being "
