@@ -33,7 +33,8 @@
 #include <thread>
 #include "ThreadNumberLimiter.h"
 #include "precomp.h"
-#include "cells/Cell.h"
+#include "Version.h"
+#include "Configuration.h"
 #include <wx/image.h>
 #include <wx/buffer.h>
 #include <wx/zipstrm.h>
@@ -73,7 +74,7 @@ public:
   explicit Image(Configuration *config);
 
   //! A constructor that loads the compressed file from a wxMemoryBuffer
-  Image(Configuration *config, wxMemoryBuffer image, wxString type);
+  Image(Configuration *config, const wxMemoryBuffer &image, const wxString &type);
 
   /*! A constructor that loads a bitmap
 
@@ -90,8 +91,8 @@ public:
     Empty when loading from a standalone file from the filesystem.
     \param remove true = Delete the file after loading it
   */
-  Image(Configuration *config, wxString image,
-        wxString wxmxFile, bool remove = true);
+  Image(Configuration *config, const wxString &image,
+        const wxString &wxmxFile, bool remove = true);
 
   Image(Configuration *config, const Image &image);
   Image(const Image &image) = delete;
@@ -119,7 +120,7 @@ public:
     m_ppi = ppi;}
 
   //! Creates a bitmap showing an error message
-  void InvalidBitmap(wxString message = wxEmptyString);
+  void InvalidBitmap(const wxString &message = wxEmptyString);
 
   /*! Sets the name of the gnuplot source and data file of this image
 
@@ -128,13 +129,13 @@ public:
     memory in their compressed form.
   */
   void GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                     wxString wxmxFile = wxEmptyString);
+                     const wxString &wxmxFile = wxEmptyString);
 
   /*! Loads the compressed gnuplot source and data file for this image
 
    */
   void CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                               wxString wxmxFile = wxEmptyString);
+                               const wxString &wxmxFile = wxEmptyString);
 
 /*! Returns the gnuplot source file name of this image
 
@@ -242,19 +243,18 @@ public:
     return m_svgRast != nullptr;}
 
   //! The tooltip to use wherever an image that's not Ok is shown.
-  static const wxString &GetBadImageToolTip();
+  static const wxString GetBadImageToolTip();
 
   class WxmxStream: public wxZipInputStream
   {
   public:
-    WxmxStream(wxInputStream &wxmxFile, wxString fileInWxmx);
+    WxmxStream(wxInputStream &wxmxFile, const wxString &fileInWxmx);
   };
 
-  bool HasGnuplotSource(){return m_gnuplotSource_Compressed.GetDataLen() > 20;}
+  bool HasGnuplotSource() const {return m_gnuplotSource_Compressed.GetDataLen() > 20;}
 private:
   bool m_fromWxFS = false;
   bool m_gnuplotDataThreadRunning = false;
-  //  static std::atomic<int> m_numberOfThreads;
   //! A zipped version of the gnuplot commands that produced this image.
   wxMemoryBuffer m_gnuplotSource_Compressed;
   //! A zipped version of the gnuplot data needed in order to create this image.
@@ -271,11 +271,11 @@ private:
   wxString m_gnuplotSource;
   //! The gnuplot data file for this image, if any.
   wxString m_gnuplotData;
-  mutable std::thread m_loadImageTask;
+  mutable jthread m_loadImageTask;
   void LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limiter,
                                 wxString image, wxString wxmxFile,
                                 bool remove);
-  std::thread m_loadGnuplotSourceTask;
+  jthread m_loadGnuplotSourceTask;
   void LoadGnuplotSource_Backgroundtask(
     std::unique_ptr<ThreadNumberLimiter> limiter,
     wxString gnuplotFile, wxString dataFile, wxString wxmxFile);
@@ -292,10 +292,10 @@ private:
                                                   wxString wxmxFile
     );
   //! Loads an image from a file
-  void LoadImage(wxString image, wxString wxmxFile, bool remove = true);
+  void LoadImage(wxString image, const wxString &wxmxFile, bool remove = true);
   //! Reads the compressed image into a memory buffer
   static wxMemoryBuffer ReadCompressedImage(wxInputStream *data);
-  Configuration *m_configuration;
+  Configuration *m_configuration = NULL;
   /*! The upper width limit for displaying this image
    */
   wxCoord m_maxWidth = -1;
