@@ -45,7 +45,7 @@
 class MarkDownParser
 {
 protected:
-  Configuration *m_configuration;
+  Configuration *m_configuration = NULL;
 
   //! A pair of a regExp and a string that has to replace the matches.
   class RegexReplacer : public wxRegEx
@@ -146,7 +146,7 @@ private:
     { return wxS("</li>\n"); }
 
   virtual wxString NewLine() override
-    { return wxS("<br/>"); }
+    { return wxS("<br>"); }
 };
 
 #endif // MARKDOWN_H
