@@ -33,7 +33,6 @@
 #include <wx/intl.h>
 #include <wx/sstream.h>
 #include <wx/tokenzr.h>
-#include "ErrorRedirector.h"
 
 #include "MathParser.h"
 
@@ -161,7 +160,6 @@ MathParser::MathParser(Configuration *cfg, const wxString &zipfile) {
     m_groupTags[wxS("heading5")] = &MathParser::GroupCellHeading5Tag;
     m_groupTags[wxS("heading6")] = &MathParser::GroupCellHeading6Tag;
   }
-  m_highlight = false;
   m_wxmxFile = zipfile;
 }
 
@@ -377,7 +375,6 @@ std::unique_ptr<Cell> MathParser::ParseImageTag(wxXmlNode *node) {
       }
     } else {
     if (node->GetAttribute(wxS("del"), wxS("yes")) != wxS("no")) {
-      SuppressErrorDialogs suppressor;
       if ((!wxFileExists(filename)) || (wxImage::GetImageCount(filename) < 2))
         imageCell = std::make_unique<ImgCell>(m_group, m_configuration,
                                               filename, wxEmptyString, true);
@@ -385,7 +382,6 @@ std::unique_ptr<Cell> MathParser::ParseImageTag(wxXmlNode *node) {
         return std::make_unique<AnimationCell>(m_group, m_configuration,
                                                filename, true);
     } else {
-      SuppressErrorDialogs suppressor;
       // This is the only case show_image() produces ergo this is the only
       // case we might get a local path
       if ((!wxFileExists(filename)) &&
@@ -457,7 +453,10 @@ std::unique_ptr<Cell> MathParser::ParseOutputLabelTag(wxXmlNode *node) {
     }
   }
   if ((tmp == NULL) || (dynamic_cast<LabelCell *>(tmp.get()) == NULL))
-    tmp.reset(new LabelCell(m_group, m_configuration, wxEmptyString));
+    {
+      wxString empty;
+      tmp.reset(new LabelCell(m_group, m_configuration, empty));
+    }
 
   dynamic_cast<LabelCell *>(tmp.get())->SetUserDefinedLabel(user_lbl);
   tmp->ForceBreakLine(true);
@@ -627,11 +626,10 @@ MathParser::HandleNullPointer(std::unique_ptr<Cell> &&cell) {
   auto tmp = std::move(cell);
   if (!tmp) {
     tmp = std::make_unique<VisiblyInvalidCell>(m_group, m_configuration);
-    tmp->SetToolTip(
-                    &T_("The xml data from maxima or from the .wxmx file was missing data "
-                        "here.\n"
-                        "If you find a way how to reproduce this problem please file a bug "
-                        "report against wxMaxima."));
+    tmp->SetToolTip(_("The xml data from maxima or from the .wxmx file was missing data "
+                      "here.\n"
+                      "If you find a way how to reproduce this problem please file a bug "
+                      "report against wxMaxima."));
     tmp->SetStyle(TS_ERROR);
   }
   return tmp;
@@ -657,7 +655,7 @@ std::unique_ptr<Cell> MathParser::ParseEditorTag(wxXmlNode *node) {
   else if (type == wxS("heading6"))
     editor->SetType(MC_TYPE_HEADING6);
 
-  wxString text = wxEmptyString;
+  wxString text;
   wxXmlNode *line = node->GetChildren();
   while (line) {
     if (line->GetName() == wxS("line")) {
@@ -889,9 +887,9 @@ std::unique_ptr<Cell> MathParser::ParseFunTag(wxXmlNode *node) {
 
   ParseCommonAttrs(node, fun);
   if (fun->ToString().Contains(")("))
-    fun->SetToolTip(&T_("If this isn't a function returning a lambda() "
-                        "expression a multiplication sign (*) between closing "
-                        "and opening parenthesis is missing here."));
+    fun->SetToolTip(_("If this isn't a function returning a lambda() "
+                      "expression a multiplication sign (*) between closing "
+                      "and opening parenthesis is missing here."));
   return fun;
 }
 
@@ -1084,11 +1082,11 @@ std::unique_ptr<Cell> MathParser::ParseSumTag(wxXmlNode *node) {
 
   std::unique_ptr<Cell> sum;
   if ((type == wxS("prod")) || (type == wxS("lprod")))
-    sum = std::make_unique<ProductCell>(m_group, m_configuration, 
+    sum = std::make_unique<ProductCell>(m_group, m_configuration,
                                     std::move(under), std::move(over),
                                     std::move(base));
   else
-    sum = std::make_unique<SumCell>(m_group, m_configuration, 
+    sum = std::make_unique<SumCell>(m_group, m_configuration,
                                     std::move(under), std::move(over),
                                     std::move(base));
   sum->SetHighlight(highlight);
@@ -1183,7 +1181,7 @@ std::unique_ptr<Cell> MathParser::ParseTag(wxXmlNode *node, bool all) {
 
   node = SkipWhitespaceNode(node);
   for (; node; node = GetNextTag(node)) {
-    auto &tagName = node->GetName();
+    const auto &tagName = node->GetName();
     tree.ClearLastAppended();
     if (node->GetType() == wxXML_ELEMENT_NODE) {
       // Parse XML tags. The only other type of element we recognize are text
@@ -1237,7 +1235,7 @@ std::unique_ptr<Cell> MathParser::ParseTag(wxXmlNode *node, bool all) {
       break;
   }
 
-  return tree;
+  return std::move(tree);
 }
 
 std::unique_ptr<Cell> MathParser::ParseLine(wxString s, CellType style) {
@@ -1274,7 +1272,11 @@ std::unique_ptr<Cell> MathParser::ParseLine(wxString s, CellType style) {
 
     {
       wxLogNull suppressErrorMessages;
+#if wxCHECK_VERSION(3, 3, 0)
+      xml.Load(xmlStream, wxXMLDOC_KEEP_WHITESPACE_NODES);
+#else
       xml.Load(xmlStream, wxS("UTF-8"), wxXMLDOC_KEEP_WHITESPACE_NODES);
+#endif
     }
 
     wxXmlNode *doc = xml.GetRoot();
@@ -1282,13 +1284,9 @@ std::unique_ptr<Cell> MathParser::ParseLine(wxString s, CellType style) {
     if (doc != NULL)
       cell = ParseTag(doc->GetChildren());
   } else {
-    cell = std::make_unique<TextCell>(
-                                      m_group, m_configuration,
-                                      T_("(wxMaxima is configured not to show long expressions - which would be slow)"),
+    cell = std::make_unique<TextCell>(m_group, m_configuration,
+                                      _("(Invalid XML from maxima)"),
                                       TS_WARNING);
-    cell->SetToolTip(&T_(
-                         "The maximum size of the expressions wxMaxima is allowed to display "
-                         "can be changed in the configuration dialogue."));
     cell->ForceBreakLine(true);
   }
   return cell;
@@ -1298,25 +1296,6 @@ std::unique_ptr<Cell> MathParser::ParseLine(const wxXmlDocument &xml, CellType s
   m_ParserStyle = style;
   m_FracStyle = FracCell::FC_NORMAL;
   m_highlight = false;
-  size_t showLength;
-
-  switch (m_configuration->ShowLength()) {
-  case 0:
-    showLength = 600;
-    break;
-  case 1:
-    showLength = 2000;
-    break;
-  case 2:
-    showLength = 25000;
-    break;
-  case 3:
-    showLength = 0;
-    break;
-  default:
-    showLength = 5000;
-  }
-
   std::unique_ptr<Cell> cell;
 
   wxXmlNode *doc = xml.GetRoot();
@@ -1325,18 +1304,6 @@ std::unique_ptr<Cell> MathParser::ParseLine(const wxXmlDocument &xml, CellType s
       auto child = doc->GetChildren();
       cell = ParseTag(child);
     }
-
-  if ((cell != NULL ) && (cell->GetInnerCellCount_recursive() > showLength))
-    {
-      cell = std::make_unique<TextCell>(
-                                        m_group, m_configuration,
-                                        T_("(wxMaxima is configured not to show long expressions - which would be slow)"),
-                                        TS_WARNING);
-      cell->SetToolTip(&T_(
-                           "The maximum size of the expressions wxMaxima is allowed to display "
-                           "can be changed in the configuration dialogue."));
-      cell->ForceBreakLine(true);
-    }
   return cell;
 }
 
