@@ -29,6 +29,7 @@
 #include <wx/app.h>
 #include <wx/debug.h>
 #include <wx/sstream.h>
+#include <wx/tokenzr.h>
 
 //! The time, in ms, we'll wait for an end of string to arrive from maxima after
 //! the input was first read.
@@ -51,9 +52,9 @@ Maxima::Maxima(wxSocketBase *socket, Configuration *config) :
   m_configuration(config),
   m_socket(socket),
   m_socketInput(*m_socket),
-  m_textInput(m_socketInput, wxS("\n"), wxConvUTF8)
+  m_textInput(m_socketInput, wxS("\n"), wxConvUTF8),
+  m_abortParserThread(false)
 {
-  m_abortReaderThread = false;
   if(m_knownTags.empty())
     {
       m_knownTags[wxS("PROMPT")] = XML_PROMPT;
@@ -67,7 +68,6 @@ Maxima::Maxima(wxSocketBase *socket, Configuration *config) :
       m_knownTags[wxS("math")] = XML_MATHS;
       m_knownTags[wxS("wxxml-key")] = XML_WXXML_KEY;
     }
-  m_socketInputData.reserve(1000000);
   wxASSERT(socket);
   Bind(wxEVT_TIMER, wxTimerEventHandler(Maxima::TimerEvent), this);
   Bind(wxEVT_SOCKET, wxSocketEventHandler(Maxima::SocketEvent), this);
@@ -91,9 +91,11 @@ Maxima::~Maxima() {
   Disconnect(wxEVT_TIMER);
   Disconnect(wxEVT_SOCKET);
   Disconnect(EVT_MAXIMA);
-  m_abortReaderThread = true;
-  if(m_readerTask.joinable())
-    m_readerTask.join();
+  m_abortParserThread = true;
+
+  // Exit all threads before the program ends
+  if(m_parserTask.joinable())
+    m_parserTask.join();
   if(IsConnected())
     {
       // Make wxWidgets close the connection only after we have sent the close
@@ -108,39 +110,23 @@ Maxima::~Maxima() {
       wxCharBuffer buf = closeCommand.ToUTF8();
       m_socket->Write(buf.data(), buf.length());
     }
+  std::lock_guard<std::mutex> lock(m_socketInputMutex);
   m_socket->Close();
   wxEvtHandler::DeletePendingEvents();
 }
 
 bool Maxima::Write(const void *buffer, std::size_t length) {
-  if (!m_socketOutputData.IsEmpty()) {
-    if (buffer && length)
-      m_socketOutputData.AppendData(buffer, length);
-    buffer = m_socketOutputData.GetData();
-    length = m_socketOutputData.GetDataLen();
-  }
-  if (!length)
+  if(!buffer)
+    return false;
+  if (length == 0)
     return false;
   m_socket->Write(buffer, length);
   if (m_socket->Error() && m_socket->LastError() != wxSOCKET_WOULDBLOCK) {
     wxThreadEvent *sendevent = new wxThreadEvent(EVT_MAXIMA);
     sendevent->SetInt(WRITE_ERROR);
     QueueEvent(sendevent);
-    m_socketOutputData.Clear();
-    return true;
+    return false;
   }
-  auto const wrote = m_socket->LastWriteCount();
-  if (wrote < length) {
-    auto *const source = reinterpret_cast<const char *>(buffer);
-    auto const leftToWrite = length - wrote;
-    if (m_socketOutputData.IsEmpty())
-      m_socketOutputData.AppendData(source + wrote, leftToWrite);
-    else {
-      memmove(m_socketOutputData.GetData(), source + wrote, leftToWrite);
-      m_socketOutputData.SetDataLen(leftToWrite);
-    }
-  } else
-    m_socketOutputData.Clear();
   return true;
 }
 
@@ -150,16 +136,11 @@ void Maxima::SocketEvent(wxSocketEvent &event) {
     ReadSocket();
     break;
   case wxSOCKET_OUTPUT:
-    if (Write(nullptr, 0)) {
-      wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
-      event->SetInt(WRITE_PENDING);
-      QueueEvent(event);
-    }
     break;
   case wxSOCKET_LOST: {
-      wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
-      event->SetInt(DISCONNECTED);
-    QueueEvent(event);
+      wxThreadEvent *evt = new wxThreadEvent(EVT_MAXIMA);
+      evt->SetInt(DISCONNECTED);
+    QueueEvent(evt);
     break;
   }
   case wxSOCKET_CONNECTION:
@@ -176,56 +157,80 @@ void Maxima::TimerEvent(wxTimerEvent &event) {
   }
 }
 
-void Maxima::ReadSocket() {
+void Maxima::ReadSocket() {  
   // It is theoretically possible that the client has exited after sending us
   // data and before we had been able to process it.
   if (!m_socket->IsConnected() || !m_socket->IsData())
     return;
 
-  // std::cerr<<"------ transmission start ------\n";
   {
     wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
     event->SetInt(READ_PENDING);
     QueueEvent(event);
   }
+  m_abortParserThread = true;
   wxString line;
-  wxChar ch;
-  m_abortReaderThread = true;
-  if(m_readerTask.joinable())
-    m_readerTask.join();
-  do
-    {
-      ch = m_textInput.GetChar();
-      if(ch == wxS('\r'))
-        ch = wxS('\n');
-      if(ch != wxS('\0'))
-        m_socketInputData.append(ch);
-    }  while (m_socket->LastReadCount() > 0);
-  // std::cerr<<m_socketInputData<<"\n";
-  // std::cerr<<"------ transmission end ------\n";
-  if ((m_pipeToStderr) && (!m_socketInputData.IsEmpty()))
-    {
-      std::cerr << m_socketInputData;
-      std::cerr.flush();
-    }
-  if(m_xmlInspector)
-    {
-      wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
-      event->SetInt(STRING_FOR_XMLINSPECTOR);
-      event->SetString(m_socketInputData);
-      QueueEvent(event);
-    }
+  wxString rawData;
+  wxUniChar ch;
+  wxUniChar lastch = '\0';
+  const bool collectRawData = m_xmlInspector || GetPipeToStdErr();
+  if(collectRawData)
+    rawData.Alloc(1000000);
+
+
+  // We want to modify m_socketInputData, which is the variable we share with the
+  // background thread. In order not to modify it while the background thread
+  // accesses it we wait for the backgroundthread to finish.
+  if(m_parserTask.joinable())
+    m_parserTask.join();
+  
+  {
+    std::lock_guard<std::mutex> lock(m_socketInputMutex);
+    // Try to avoid frequent (slow) reallocs on appending to the string
+    m_socketInputData.Alloc(m_socketInputData.Length() + 1000000);
+    
+    do
+      {
+        ch = m_textInput.GetChar();
+        if(ch == wxS('\0'))
+          continue;
+        if(collectRawData)
+          rawData.Append(ch);
+        if(ch == wxS('\r'))
+          {
+            if(lastch != wxS('\n'))
+              m_socketInputData.Append(wxS('\n'));
+            lastch = ch;
+            continue;
+          }
+        m_socketInputData.Append(ch);
+        lastch = ch;
+      }  while (m_socket->LastReadCount() > 0);
+
+    if(collectRawData)
+      {
+        wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
+        event->SetInt(STRING_FOR_XMLINSPECTOR);
+        event->SetString(rawData);
+        QueueEvent(event);
+      }
+  }
   // The string we have received now is broken into tags by a background task before sending
-  // it to wxMaxima
-  m_abortReaderThread = false;
+  // it to wxMaxima. As the main task no more accesses the string while that thread is running
+  // we don't need any locks or similar for that.
+  m_abortParserThread = false;
   if(m_configuration->UseThreads())
-    m_readerTask = std::thread(&Maxima::SendToWxMaxima, this);
+    m_parserTask = jthread(&Maxima::SendToWxMaxima, this);
   else
     SendToWxMaxima();
 }
 
 void Maxima::SendToWxMaxima()
 {
+  std::lock_guard<std::mutex> lock(m_socketInputMutex);
+  // This thread shares m_socketInputData with the main thread. But it accesses
+  // that variable only when the main thread doesn't and vice versa, therefore
+  // that doesn't cause a race condition
   if(m_socketInputData.IsEmpty())
     return;
   size_t size_before;
@@ -235,21 +240,21 @@ void Maxima::SendToWxMaxima()
     wxString rest;
     std::unordered_map<wxString, EventCause, wxStringHash>::const_iterator tag =
       m_knownTags.end();
-    wxString::const_iterator it = m_socketInputData.begin();
-    while(it != m_socketInputData.end())
+    wxString::const_iterator it;
+    for(it = m_socketInputData.begin(); it < m_socketInputData.end(); ++it)
       {
         if(*it == wxS('<'))
           {
             // Extract the starting tag, if this is one.
             wxString::const_iterator it2 = it;
-            size_t i = 0;
+            std::size_t i = 0;
             wxString tagStart;
-            while((i < 20) && (it2 != m_socketInputData.end()))
+            while((i < 20) && (it2 < m_socketInputData.end()))
               {
                 tagStart += *it2;
                 i++; ++it2;
               }
-            for(tag = m_knownTags.begin(); tag != m_knownTags.end(); tag++)
+            for(tag = m_knownTags.begin(); tag != m_knownTags.end(); ++tag)
               {
                 wxString tagstartname = wxS("<") + tag->first + wxS(">");
                 if(tagStart.StartsWith(tagstartname))
@@ -257,26 +262,36 @@ void Maxima::SendToWxMaxima()
               }
             if(tag != m_knownTags.end())
               break;
-            if(m_abortReaderThread)
+            if(m_abortParserThread)
               return;
           }
         dataToSend += *it;
-        ++it;
+        if(*it == wxS('\n'))
+          {
+            wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
+            event->SetInt(READ_MISC_TEXT);
+            event->SetString(dataToSend);
+            QueueEvent(event);
+            dataToSend.Clear();
+          }
       }
     if(!dataToSend.IsEmpty())
       {
-        wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
-        event->SetInt(READ_MISC_TEXT);
-        event->SetString(dataToSend);
-        QueueEvent(event);
+        wxStringTokenizer lines(dataToSend, wxS("\n"), wxTOKEN_RET_EMPTY_ALL);
+        while (lines.HasMoreTokens()) {
+          wxString line = lines.GetNextToken();
+          if(lines.HasMoreTokens())
+            line += wxS("\n");
+          wxThreadEvent *event = new wxThreadEvent(EVT_MAXIMA);
+          event->SetInt(READ_MISC_TEXT);
+          event->SetString(line);
+          QueueEvent(event);
+        }
       }
-    while(it != m_socketInputData.end())
-      {
+    for(; it < m_socketInputData.end(); ++it)
         rest += *it;
-        it++;
-      }
     m_socketInputData = rest;
-    if(m_abortReaderThread)
+    if(m_abortParserThread)
       return;
     
     if(tag != m_knownTags.end())
@@ -298,9 +313,9 @@ void Maxima::SendToWxMaxima()
                   }
                 else
                   {
-                    if((charsInTag == 0) || (i != '\n'))
+                    if((charsInTag < 0) || (i != '\n'))
                       rest += i;
-                    if(charsInTag >= 0)
+                    if(charsInTag == 0)
                       --charsInTag;
                   }
                 
@@ -313,11 +328,21 @@ void Maxima::SendToWxMaxima()
               // currently still doesn't
               if((tag->second != XML_PROMPT) && (tag->second != XML_SUPPRESSOUTPUT))
               {
-                wxXmlDocument xmldoc;
-                wxStringInputStream xmlStream(dataToSend);
-                wxLogNull suppressErrorDialogs;
-                xmldoc.Load(xmlStream, wxS("UTF-8"));
-                event->SetPayload(xmldoc);
+                if((tag->second == XML_MATHS) &&
+                   ((m_configuration->ShowLength_Bytes() != 0) && (dataToSend.Length() > m_configuration->ShowLength_Bytes())
+                    ))
+                  {
+                    event->SetInt(XML_TOOLONGMATHS);
+                  }
+                else
+                  {
+                    event->SetInt(tag->second);
+                    wxXmlDocument xmldoc;
+                    wxStringInputStream xmlStream(dataToSend);
+                    wxLogNull suppressErrorDialogs;
+                    xmldoc.Load(xmlStream);
+                    event->SetPayload(xmldoc);
+                  }
               }
             else
               event->SetString(dataToSend);
