@@ -55,7 +55,7 @@ public:
     \param commands The maxima commands to tokenize
     \param configuration A pointer to the configuration object
   */
-  MaximaTokenizer(wxString commands, Configuration *configuration);
+  MaximaTokenizer(const wxString &commands, const Configuration * const configuration);
 
   //! A maxima code snippet from this tokenizer
   class Token
@@ -77,18 +77,23 @@ public:
     wxString m_text;
     TextStyle m_style = TS_CODE_DEFAULT;
   };
-  static bool IsAlpha(wxChar ch);
-  static bool IsNum(wxChar ch);
-  static bool IsAlphaNum(wxChar ch);
-  static bool IsSpace(wxChar ch);
-  static const wxString &UnicodeNumbers() { return m_unicodeNumbers; }
-  static const wxString &Operators() { return m_operators; }
+  static bool IsAlpha(wxUniChar ch);
+  static bool IsNum(wxUniChar ch);
+  static bool IsAlphaNum(wxUniChar ch);
+  static bool IsSpace(wxUniChar ch);
+  static const wxString UnicodeNumbers() {
+    return wxS("\u00BD\u00B2\u00B3\u221E"); // VULGAR FRACTION ONE HALF, SUPERSCRIPT TWO, SUPERSCRIPT THREE, INFINITY
+  }
+  static const wxString Operators() {
+    return wxS("\u221A\u22C0\u22C1\u22BB\u22BC\u22BD\u00AC\u222b\u2264\u2265\u2211"
+      "\u2260+-*/^:=#'!()[]{}");
+  }
 
   using TokenList = std::vector<Token>;
   TokenList PopTokens() && { return std::move(m_tokens); }
 
   //! A constructor that adds additional words to the token list
-  MaximaTokenizer(wxString commands, Configuration *configuration,
+  MaximaTokenizer(const wxString &commands, const Configuration * const configuration,
                   const TokenList &initialTokens);
 
 protected:
@@ -106,12 +111,8 @@ protected:
   static const wxString m_minusSigns;
   //! Linebreak characters
   static const wxString m_linebreaks;
-  //! Unicode numbers
-  static const wxString m_unicodeNumbers;
-  //! Operators
-  static const wxString m_operators;
 
-  Configuration *m_configuration;
+  const Configuration * const m_configuration = NULL;
 
   typedef std::unordered_map <wxString, int, wxStringHash> StringHash;
   /*! Names of functions that don't require parenthesis
@@ -122,6 +123,7 @@ protected:
     argument. These fake functions are kept in this hash.
   */
   static StringHash m_hardcodedFunctions;
+
 };
 
 #endif // MAXIMATOKENIZER_H
