@@ -30,7 +30,19 @@
 #include "Image.h"
 #include "ArtProvider.h"
 #include "SvgBitmap.h"
-#include "wxm_statusbar_images.h"
+#include "art/statusbar/network-idle.h"
+#include "art/statusbar/Dialog-accept.h"
+#include "art/statusbar/network-offline.h"
+#include "art/statusbar/Emblem-equal-defined.h"
+#include "art/statusbar/network-receive.h"
+#include "art/statusbar/Emblem-important.h"
+#include "art/statusbar/network-transmit-receive.h"
+#include "art/statusbar/Go-previous.h"
+#include "art/statusbar/network-transmit.h"
+#include "art/statusbar/Go-up.h"
+#include "art/statusbar/System-lock-screen.h"
+#include "art/statusbar/network-error.h"
+#include "art/statusbar/Waiting.h"
 #include <wx/artprov.h>
 #include <wx/display.h>
 #include <wx/mstream.h>
@@ -42,8 +54,6 @@ StatusBar::StatusBar(wxWindow *parent, int id)
   : wxStatusBar(parent, id), m_ppi(wxSize(-1, -1)) {
   m_svgRast.reset(wxm_nsvgCreateRasterizer());
   int widths[] = {-1, GetSize().GetHeight(), GetSize().GetHeight()};
-  m_maximaPercentage = -1;
-  m_oldmaximaPercentage = -1;
   SetFieldsCount(3, widths);
   int styles[] = {wxSB_NORMAL, wxSB_NORMAL, wxSB_FLAT};
   SetStatusStyles(3, styles);
@@ -85,10 +95,7 @@ StatusBar::StatusBar(wxWindow *parent, int id)
   m_networkStatus->SetToolTip(m_stdToolTip);
   ReceiveTimer.SetOwner(this, wxID_ANY);
   SendTimer.SetOwner(this, wxID_ANY);
-  m_icon_shows_receive = m_icon_shows_transmit = false;
-  m_networkState = offline;
   // Mark the network state as "to be changed"
-  m_oldNetworkState = receive;
   Connect(wxEVT_SIZE, wxSizeEventHandler(StatusBar::OnSize));
   Connect(wxEVT_TIMER, wxTimerEventHandler(StatusBar::OnTimerEvent));
 }
