@@ -31,7 +31,37 @@
 #include "Image.h"
 #include "SvgBitmap.h"
 #include "ArtProvider.h"
-#include "wxm_toolbar_images.h"
+#include "art/toolbar/arrow-up-square.h"
+#include "art/toolbar/gtk-new.h"
+#include "art/toolbar/gtk-open.h"
+#include "art/toolbar/dialog-information.h"
+#include "art/toolbar/gtk-paste.h"
+#include "art/toolbar/edit-copy.h"
+#include "art/toolbar/gtk-preferences.h"
+#include "art/toolbar/edit-cut.h"
+#include "art/toolbar/gtk-print.h"
+#include "art/toolbar/edit-find.h"
+#include "art/toolbar/gtk-redo.h"
+#include "art/toolbar/eye-slash.h"
+#include "art/toolbar/gtk-save.h"
+#include "art/toolbar/go-bottom.h"
+#include "art/toolbar/gtk-select-all.h"
+#include "art/toolbar/go-jump.h"
+#include "art/toolbar/gtk-stop.h"
+#include "art/toolbar/go-last.h"
+#include "art/toolbar/gtk-undo.h"
+#include "art/toolbar/go-next.h"
+#include "art/toolbar/input.h"
+#include "art/toolbar/gtk-copy.h"
+#include "art/toolbar/media-playback-stop.h"
+#include "art/toolbar/gtk-cut.h"
+#include "art/toolbar/software-update-urgent.h"
+#include "art/toolbar/gtk-find.h"
+#include "art/toolbar/text.h"
+#include "art/toolbar/gtk-help.h"
+#include "art/toolbar/view-refresh1.h"
+#include "art/media-playback-start.h"
+#include "art/media-playback-reverse.h"
 #include <cstdlib>
 #include <wx/artprov.h>
 #include <wx/display.h>
@@ -93,8 +123,8 @@ ToolBar::~ToolBar() { m_plotSlider = NULL; }
 void ToolBar::UpdateSlider(AnimationCell *cell) {
   if (cell == NULL)
     return;
-  int animationDisplayedIndex = cell->GetDisplayedIndex();
-  int animationMaxIndex = cell->Length();
+  std::size_t animationDisplayedIndex = cell->GetDisplayedIndex();
+  std::size_t animationMaxIndex = cell->Length();
 
   if ((m_animationDisplayedIndex != animationDisplayedIndex) ||
       (m_animationMaxIndex != animationMaxIndex)) {
@@ -125,13 +155,7 @@ ToolBar::ToolBar(wxWindow *parent)
     m_worksheetEmpty_old(false)
 {
   m_svgRast.reset(wxm_nsvgCreateRasterizer());
-
-  m_needsInformation = false;
-  m_AnimationStartStopState = Inactive;
-
   SetGripperVisible(false);
-  m_plotSlider = NULL;
-  m_textStyle = NULL;
   SetToolBitmapSize(GetOptimalBitmapSize());
   AddTools();
 
@@ -297,8 +321,7 @@ void ToolBar::AddTools() {
                            _("After clicking on animations created with with_slider_draw() or "
                              "similar this slider allows to change the current frame."));
   m_plotSlider->Enable(false);
-  m_animationMaxIndex = -1;
-  m_animationDisplayedIndex = -1;
+  m_animationMaxIndex = 0;
   AddControl(m_plotSlider);
   AddStretchSpacer(100);
   if (ShowHelp())
@@ -565,8 +588,8 @@ void ToolBar::AnimationButtonState(AnimationStartStopState state) {
       m_plotSlider->SetToolTip(
                                _("After clicking on animations created with with_slider_draw() or "
                                  "similar this slider allows to change the current frame."));
-      m_animationMaxIndex = -1;
-      m_animationDisplayedIndex = -1;
+      m_animationMaxIndex = 0;
+      m_animationDisplayedIndex = 0;
 
       if (m_AnimationStartStopState == Running) {
         SetToolBitmap(tb_animation_startStop, m_PlayButton);
