@@ -50,13 +50,15 @@
 #include "Notification.h"
 #include "cells/Cell.h"
 #include "cells/EditorCell.h"
+#include "cells/ImgCell.h"
+#include "cells/ImgCellBase.h"
+#include "cells/AnimationCell.h"
 #include "cells/GroupCell.h"
 #include "cells/TextCell.h"
 #include "EvaluationQueue.h"
 #include "dialogs/FindReplaceDialog.h"
 #include "Autocomplete.h"
 #include "AutocompletePopup.h"
-#include "sidebars/TableOfContents.h"
 #include "sidebars/UnicodeSidebar.h"
 #include "ToolBar.h"
 #include <thread>
@@ -97,25 +99,24 @@ public:
   bool UpdateControlsNeeded(){bool result = m_updateControls; m_updateControls = false; return result;}
   void UpdateControlsNeeded(bool updateControlsNeeded){m_updateControls = updateControlsNeeded;}
 private:
-  wxString m_maximaVersion;
   //! The directory with maxima's documentation
   wxString m_maximaDocDir;
   //! The storage for UpdateControlsNeeded()
   bool m_updateControls = true;
   //! Is a scroll to the cursor scheduled?
-  bool m_scrollToCaret;
+  bool m_scrollToCaret = false;
   //! The pointers to cells that can be deleted by these cells on deletion of the cells.
   CellPointers m_cellPointers;
   // The x position to scroll to
-  int m_newxPosition;
+  int m_newxPosition = -1;
   // The y position to scroll to
-  int m_newyPosition;
+  int m_newyPosition = -1;
   //! Which zoom level were we at when we started the zoom gesture?
-  double m_zoomAtGestureStart;
+  double m_zoomAtGestureStart = 1.0;
   //! If m_cellPointers.m_scrollToCell = true: Do we want to scroll to the top of this cell?
-  bool m_scrollToTopOfCell;
+  bool m_scrollToTopOfCell = false;
   //! Is our window currently active?
-  bool m_windowActive;
+  bool m_windowActive = true;
   //! The rectangle we need to refresh.
   wxRegion m_regionToRefresh;
   /*! The size of a scroll step
@@ -124,16 +125,16 @@ private:
     scroll step, but besides that also the accuracy wxScrolledCanvas
     calculates some widths in.
   */
-  int m_scrollUnit;
+  int m_scrollUnit = 10;
   /*! The drawing context used for calculating sizes.
 
     Drawing is done from a wxPaintDC in OnPaint() instead.
   */
   wxClientDC m_dc;
   //! Where do we need to start the repainting of the worksheet?
-  GroupCell *m_redrawStart;
+  CellPtr<GroupCell> m_redrawStart;
   //! Do we need to redraw the worksheet?
-  bool m_fullRedrawRequested;
+  bool m_fullRedrawRequested = false;
   //! The clipboard format "mathML"
 
   //! A class that publishes wxm data to the clipboard
@@ -164,7 +165,7 @@ private:
   class wxmDataObject : public wxCustomDataObject
   {
   public:
-    explicit wxmDataObject(wxString data);
+    explicit wxmDataObject(const wxString &data);
 
     wxmDataObject();
 
@@ -175,7 +176,7 @@ private:
   class MathMLDataObject2 : public wxCustomDataObject
   {
   public:
-    explicit MathMLDataObject2(wxString data);
+    explicit MathMLDataObject2(const wxString &data);
 
     MathMLDataObject2();
 
@@ -188,7 +189,7 @@ private:
   class RtfDataObject : public wxCustomDataObject
   {
   public:
-    explicit RtfDataObject(wxString data);
+    explicit RtfDataObject(const wxString &data);
 
     RtfDataObject();
 
@@ -199,7 +200,7 @@ private:
   class RtfDataObject2 : public wxCustomDataObject
   {
   public:
-    explicit RtfDataObject2(wxString data);
+    explicit RtfDataObject2(const wxString &data);
 
     RtfDataObject2();
 
@@ -208,11 +209,11 @@ private:
   };
 
 //! true, if we have the current focus.
-  bool m_hasFocus;
+  bool m_hasFocus = true;
   //! The last beginning for the area being drawn
-  long m_lastTop;
+  long m_lastTop = 0;
   //! The last ending for the area being drawn
-  long m_lastBottom;
+  long m_lastBottom = 0;
   /*! \defgroup UndoBufferFill Undo methods for cell additions/deletions:
 
     Each EditorCell has its own private undo buffer Additionally wxMaxima
@@ -312,10 +313,10 @@ private:
   void TreeUndo_ClearUndoActionList();
 
   //! Remove one action ftom the action list
-  void TreeUndo_DiscardAction(UndoActions *actionList);
+  static void TreeUndo_DiscardAction(UndoActions *actionList);
 
   //! Add another action to this undo action
-  void TreeUndo_AppendAction(UndoActions *actionList)
+  static void TreeUndo_AppendAction(UndoActions *actionList)
     {
       if(!actionList->empty())
         actionList->front().m_partOfAtomicAction = true;
@@ -328,7 +329,7 @@ private:
 
     This pointer is needed for keeping track of cell contents changes.
   */
-  GroupCell *TreeUndo_ActiveCell;
+  CellPtr<GroupCell> TreeUndo_ActiveCell;
 
   //! Drop actions from the back of the undo list until itis within the undo limit.
   void TreeUndo_LimitUndoBuffer();
@@ -394,10 +395,7 @@ private:
   void TreeUndo_MarkCellsAsAdded(GroupCell *parentOfStart, GroupCell *end);
   //! @}
 
-  bool m_scrolledAwayFromEvaluation;
-
-  //! The cell the current question from maxima is being kept in.
-  EditorCell *m_answerCell;
+  bool m_scrolledAwayFromEvaluation = false;
 
   /*! Escape all chars that aren't allowed in html.
 
@@ -427,7 +425,7 @@ private:
   };
 
   //! Add a line to a file.
-  void AddLineToFile(wxTextFile &output, const wxString &s);
+  static void AddLineToFile(wxTextFile &output, const wxString &s);
 
   //! Copy the currently selected cells
   std::unique_ptr<Cell> CopySelection(bool asData = false) const;
@@ -448,12 +446,6 @@ private:
   //! Is executed if a timer associated with Worksheet has expired.
   void OnTimer(wxTimerEvent &event);
 
-  /*! Has the autosave interval expired?
-
-    True means: A save will be issued after the user stops typing.
-  */
-  bool m_autoSaveIntervalExpired;
-
 #if wxCHECK_VERSION(3, 1, 1)
   //! Handle pinch-to-zoom-events using the gesture interface
   void OnZoom(wxZoomGestureEvent &event);
@@ -488,7 +480,7 @@ private:
   void DrawGroupCell_UsingBitmap(wxDC *dc, GroupCell *cell);
 
   //! All that has need to be done before drawing a GroupCell in a DC
-  void PrepareDrawGC(wxDC &dc);
+  void PrepareDrawGC(wxDC &dc) const;
 
   void OnSize(wxSizeEvent &event);
 
@@ -503,7 +495,7 @@ private:
 
   void OnMouseLeftDown(wxMouseEvent &event);
 
-  void OnMouseLeftInGcCell(wxMouseEvent &event, GroupCell *clickedInGc);
+  void OnMouseLeftInGcCell(wxMouseEvent &event, GroupCell *clickedInGC);
 
   void OnMouseLeftInGcLeft(wxMouseEvent &event, GroupCell *clickedInGC);
 
@@ -552,6 +544,7 @@ private:
 
   void AdjustSize();
 
+  //! Cannot be static as it is called using a function pointer to an object
   void OnEraseBackground(wxEraseEvent& WXUNUSED(event))
     {}
 
@@ -559,10 +552,10 @@ private:
 
   void OnMouseMiddleUp(wxMouseEvent &event);
 
-  bool IsLesserGCType(int type, int comparedTo);
+  static bool IsLesserGCType(int type, int comparedTo);
 
   //! Finds the start of the current chapter/section/...
-  GroupCell *StartOfSectioningUnit(GroupCell *start);
+  static GroupCell *StartOfSectioningUnit(GroupCell *start);
 
   //! Finds the end of the current chapter/section/...
   GroupCell *EndOfSectioningUnit(GroupCell *start);
@@ -586,44 +579,39 @@ private:
     See m_hCaretPosition and EditorCell::GetActiveCell() for the position of the two
     types of cursors.
   */
-  bool m_hCaretActive;
+  bool m_hCaretActive = true;
   /*! The group above the hcaret, NULL for the top of the document
     See EditorCell::GetActiveCell() for the position if the cursor that is drawn as a
     vertical line.
   */
-  GroupCell *m_hCaretPosition;
+  CellPtr<GroupCell> m_hCaretPosition;
   /*! The start for the selection when selecting group with the horizontally drawn cursor
 
     This cell does define were the selection was actually started and therefore does not need
     to be above m_hCaretPositionEnd in the worksheet. See also m_cellPointers.m_selectionStart.
   */
-  GroupCell *m_hCaretPositionStart;
+  CellPtr<GroupCell> m_hCaretPositionStart;
   /*! The end of the selection when selecting group with the horizontally drawn cursor
 
     This cell does define where the selection was actually ended and therefore does not need
     to be below m_hCaretPositionEnd in the worksheet. See also m_cellPointers.m_selectionEnd.
   */
-  GroupCell *m_hCaretPositionEnd;
-  bool m_leftDown;
+  CellPtr<GroupCell> m_hCaretPositionEnd;
+  bool m_leftDown = false;
   //! Do we want to automatically scroll to a cell as soon as it is being evaluated?
-  bool m_followEvaluation;
-  bool m_mouseDrag;
-  bool m_mouseOutside;
-  //! The list of tree that contains the document itself
-  std::unique_ptr<GroupCell> m_tree;
-  //! A pointer to the last cell of this worksheet
-  mutable CellPtr<GroupCell> m_last;
+  bool m_followEvaluation = true;
+  bool m_mouseDrag = false;
+  bool m_mouseOutside = false;
   //! Request adjusting the worksheet size?
   mutable bool m_adjustWorksheetSizeNeeded = false;
   //! Returns a pointer to the last cell of this worksheet
   GroupCell *GetLastCellInWorksheet() const;
-  int m_clickType;
-  int m_clickType_selectionStart;
-  GroupCell *m_clickInGC;
+  int m_clickType = CLICK_TYPE_NONE;
+  CellPtr<GroupCell> m_clickInGC;
   //! true = blink the cursor
-  bool m_blinkDisplayCaret;
+  bool m_blinkDisplayCaret = true;
   //! Is the blinking vertically-drawn cursor currently visible?
-  bool m_hCaretBlinkVisible;
+  bool m_hCaretBlinkVisible = true;
   //! Time step for autoscrolll when the mouse is outside the window
   wxTimer m_timer;
   //! The cursor blink rate. Also the timeout for redrawing the worksheet
@@ -631,12 +619,10 @@ private:
   //! True if no changes have to be saved.
   bool m_saved = true;
   std::vector<wxString> m_completions;
-  bool m_autocompleteTemplates;
+  bool m_autocompleteTemplates = true;
   AutocompletePopup *m_autocompletePopup;
 
 public:
-  void SetMaximaVersion(wxString version){m_maximaVersion = version;}
-  wxString GetMaximaVersion(){return m_maximaVersion;}
   //! Is this worksheet empty?
   bool IsEmpty() const
     { return !m_tree || (!m_tree->GetNext() && m_tree->GetEditable()->GetValue().Length() <= 1); }
@@ -663,12 +649,12 @@ public:
   void SetCellStyle(GroupCell *group, GroupType style);
 
   //! Renumber all sections
-  void NumberSections();
+  void NumberSections() const;
 
   //! Make this chapter/section/... a section/subsection/... changing its subheadings, too.
-  bool SectioningMoveIn();
+  bool SectioningMoveIn(GroupCell *parent);
   //! Make this section/subsection/... a chapter/section/... changing its subheadings, too.
-  bool SectioningMoveOut();
+  bool SectioningMoveOut(GroupCell *parent);
 //! A error notification message
   stx::optional<Notification> m_notificationMessage;
   //! Is this window active?
@@ -684,11 +670,15 @@ public:
   //! Is called if this element looses or gets the focus
   void OnActivate(wxActivateEvent &event);
 private:
+  //! The list of tree that contains the document itself
+  std::unique_ptr<GroupCell> m_tree;
+  //! A pointer to the last cell of this worksheet
+  mutable CellPtr<GroupCell> m_last;
 //  std::vector<std::thread> m_drawThreads;
   static std::mutex m_drawDCLock;
   /*! The pointer to thesettings storage
    */
-  Configuration *m_configuration;
+  Configuration *m_configuration = NULL;
 public:
   //! The storage for the autocompletion feature
   AutoComplete m_autocomplete;
@@ -706,7 +696,7 @@ public:
   EditorCell *SearchStart() const
     { return m_cellPointers.m_cellSearchStartedIn; }
 
-  int IndexSearchStartedAt()
+  int IndexSearchStartedAt() const
     { return m_cellPointers.m_indexSearchStartedAt; }
 
   CellPointers &GetCellPointers() { return m_cellPointers; }
@@ -721,7 +711,7 @@ public:
     This function actually only schedules the update of the table-of-contents-tab.
     The actual update is done when wxMaxima is idle.
   */
-  void UpdateTableOfContents() { m_scheduleUpdateToc = true; }
+  void UpdateTableOfContents();
 
   /*! Handle redrawing the worksheet or of parts of it
 
@@ -799,7 +789,7 @@ public:
 
     Does convert the not equal sign to a '#' and similar.
   */
-  wxString UnicodeToMaxima(wxString s);
+  const wxString UnicodeToMaxima(wxString s);
 
   //! Scroll to the start of the worksheet.
   void ScrollToStart() { Scroll(0, 0); }
@@ -810,12 +800,6 @@ public:
   //! The find-and-replace-dialog
   FindReplaceDialog *m_findDialog = NULL;
 
-  /*! True = schedule an update of the table of contents
-
-    used by UpdateTableOfContents() and the idle task.
-  */
-  bool m_scheduleUpdateToc;
-
   //! Is the vertically-drawn cursor active?
   bool HCaretActive() const { return m_hCaretActive; }
 
@@ -896,7 +880,12 @@ public:
   //! The group that the line's cells will belong to - used by InsertLine
   GroupCell *GetInsertGroup() const;
 
-  // Actually recalculate the worksheet.
+  /*! Actually recalculate the worksheet.
+
+    \todo We check here if the recalc start is within the worksheet. Would it make
+    more sense to store the recalculation start in a CellPointer that automagically
+    zeroes itself if that isn't the case?
+   */
   bool RecalculateIfNeeded(bool timeout = false);
 
   //! Schedule a recalculation of the worksheet starting with the cell start.
@@ -912,17 +901,17 @@ public:
 
   void ResetInputPrompts();
 
-  bool CanCopy()
+  bool CanCopy() const
     {
       return m_cellPointers.m_selectionStart ||
         (m_cellPointers.m_activeCell &&
          m_cellPointers.m_activeCell->CanCopy());
     }
 
-  bool CanPaste()
+  bool CanPaste() const
     { return m_cellPointers.m_activeCell || m_hCaretActive; }
 
-  bool CanCut()
+  bool CanCut() const
     {
       return (m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->CanCopy()) ||
         (m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart->GetType() == MC_TYPE_GROUP);
@@ -968,10 +957,10 @@ public:
   */
   void DeleteSelection();
 
-  void TOCdnd();
+  void TOCdnd(GroupCell *dndStart, GroupCell *dndEnd);
 
   //! Is it possible to delete the cells between start and end?
-  bool CanDeleteRegion(GroupCell *start, GroupCell *end) const;
+  bool CanDeleteRegion(GroupCell *start, const GroupCell *end) const;
 
   //! Is it possible to delete the currently selected cells?
   bool CanDeleteSelection() const;
@@ -982,11 +971,43 @@ public:
   */
   void DeleteCurrentCell();
 
+  //! Returns the selected cell - or NULL, if the selection isn't an animation 
+  AnimationCell *GetSelectedAnimation() const
+    {
+      if(m_cellPointers.m_selectionStart != m_cellPointers.m_selectionEnd)
+        return NULL;
+      return dynamic_cast<AnimationCell *>(GetSelectionStart());
+    }
+
+  //! Returns the selected cell - or NULL, if the selection isn't an image 
+  ImgCell *GetSelectedImgCell() const
+    {
+      if(m_cellPointers.m_selectionStart != m_cellPointers.m_selectionEnd)
+        return NULL;
+      return dynamic_cast<ImgCell *>(GetSelectionStart());
+    }
+  
+  //! Returns the selected cell - or NULL, if the selection isn't image nor animation
+  ImgCellBase *GetSelectedImgCellBase() const
+    {
+      if(m_cellPointers.m_selectionStart != m_cellPointers.m_selectionEnd)
+        return NULL;
+      return dynamic_cast<ImgCellBase *>(GetSelectionStart());
+    }
+
+  //! Returns the selected cell - or NULL, if the selection isn't a text cell
+  TextCell *GetSelectedTextCell() const
+    {
+      if(m_cellPointers.m_selectionStart != m_cellPointers.m_selectionEnd)
+        return NULL;
+      return dynamic_cast<TextCell *>(GetSelectionStart());
+    }
+
   //! Does it make sense to enable the "Play" button and the slider now?
-  bool CanAnimate()
+  bool CanAnimate() const
     {
       return m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart == m_cellPointers.m_selectionEnd &&
-        m_cellPointers.m_selectionStart->GetType() == MC_TYPE_SLIDE;
+        (dynamic_cast<AnimationCell *>(GetSelectionStart()) != NULL);
     }
 
   /*! Animate the current slide show
@@ -995,14 +1016,14 @@ public:
     - false: Stop the animation
     - true: Run the animation
   */
-  void Animate(bool run = true);
+  void Animate(bool run = true) const;
 
   void DivideCell();
 
   void MergeCells();
 
   void SetLastQuestion(const wxString &lastQuestion){m_lastQuestion = lastQuestion;}
-  wxString GetLastQuestion(){return m_lastQuestion;}
+  wxString GetLastQuestion() const {return m_lastQuestion;}
 
   //! Add the currently selected cells to the clipboard and delete them.
   bool CutToClipboard();
@@ -1015,49 +1036,49 @@ public:
     - true:  Copy the current selection as text
     - false: Copy the current selection as they would appear in a .wxm file
   */
-  bool Copy(bool astext = false);
+  bool Copy(bool astext = false) const;
 
   //! Copy the selection to the clipboard as it would appear in a .wxm file
-  bool CopyCells();
+  bool CopyCells() const;
 
   //! Copy a Matlab representation of the current selection to the clipboard
-  bool CopyMatlab();
+  bool CopyMatlab() const;
 
   //! Copy a textual representation of the current selection to the clipboard
-  bool CopyText();
+  bool CopyText() const;
 
   //! Copy the TeX representation of the current selection to the clipboard
-  bool CopyTeX();
+  bool CopyTeX() const;
 
   //! Convert the current selection to MathML
-  wxString ConvertSelectionToMathML();
+  wxString ConvertSelectionToMathML() const;
 
   //! Convert the current selection to a bitmap
-  wxBitmap ConvertSelectionToBitmap();
+  wxBitmap ConvertSelectionToBitmap() const;
 
   //! Copy the MathML representation of the current selection to the clipboard
-  bool CopyMathML();
+  bool CopyMathML() const;
 
   //! Copy a bitmap of the current selection to the clipboard
-  bool CopyBitmap();
+  bool CopyBitmap() const;
 
   //! Copy the current animation to the clipboard
-  bool CopyAnimation();
+  bool CopyAnimation() const;
 
   //! Copy a svg of the current selection to the clipboard
-  bool CopySVG();
+  bool CopySVG() const;
 
 #if wxUSE_ENH_METAFILE
   //! Copy a svg of the current selection to the clipboard
-  bool CopyEMF();
+  bool CopyEMF() const;
 #endif
 
   //! Copy a rtf version of the current selection to the clipboard
-  bool CopyRTF();
+  bool CopyRTF() const;
 
-  wxSize CopyToFile(const wxString &file);
+  wxSize CopyToFile(const wxString &file) const;
 
-  wxSize CopyToFile(const wxString &file, Cell *start, Cell *end, bool asData = false, double scale = 1);
+  wxSize CopyToFile(const wxString &file, Cell *start, Cell *end, bool asData = false, double scale = 1) const;
 
   void CalculateReorderedCellIndices(GroupCell *tree, int &cellIndex, std::vector<int> &cellMap);
 
@@ -1077,13 +1098,6 @@ public:
   //! Export the file to a text file maxima's load command can read
   bool ExportToMAC(const wxString &file);
 
-  /*! export to xml compatible file
-    \param file The file name
-    \param markAsSaved false means that this action doesn't clear the
-    worksheet's "modified" status.
-  */
-  bool ExportToWXMX(const wxString &file, bool markAsSaved = true);
-
   //! The start of a RTF document
   wxString RTFStart() const;
 
@@ -1098,7 +1112,7 @@ public:
     - true:  Include linebreaks
     - false: Remove linebreaks from the converted string
   */
-  wxString GetString(bool lb = false);
+  wxString GetString(bool lb = false) const;
 
   GroupCell *GetTree() const { return m_tree.get(); }
   std::unique_ptr<GroupCell> *GetTreeAddress() { return &m_tree; }
@@ -1132,15 +1146,15 @@ public:
 
   bool ActivatePrevInput() { return ActivateInput(-1); }
   bool ActivateNextInput() { return ActivateInput(+1); }
-  wxString GetStatusText() const{return m_statusText;}
-  bool StatusTextChangedHas(){
+  wxString GetStatusText() const {return m_statusText;}
+  bool StatusTextChangedHas() {
     bool retval = (m_statusTextHas != m_statusTextHas_old) ||
       (m_statusText != m_statusText_old);
     m_statusText_old = m_statusText;
     m_statusTextHas_old = m_statusTextHas;
     return retval;
   }
-  bool StatusTextHas(){return m_statusTextHas;}
+  bool StatusTextHas() const {return m_statusTextHas;}
 private:
   /* ! A timer that tells us to urgently update the display
 
@@ -1169,7 +1183,7 @@ private:
   wxString m_statusText_old;
   bool m_statusTextHas = false;
   bool m_statusTextHas_old = false;
-  void StatusText(wxString text){m_statusText = text; m_statusTextHas = true;}
+  void StatusText(const wxString &text){m_statusText = text; m_statusTextHas = true;}
   void UnsetStatusText(){m_statusTextHas = false;}
   bool ActivateInput(int direction);
 
@@ -1239,7 +1253,7 @@ public:
   void StepAnimation(int change = 1);
 
   //! Is the editor active in the last cell of the worksheet?
-  bool IsActiveInLast()
+  bool IsActiveInLast() const
     { return m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->GetGroup() == m_last; }
 
   //! Returns the last cell of the worksheet
@@ -1319,12 +1333,12 @@ public:
   */
   void ScrolledAwayFromEvaluation(bool ScrolledAway);
 
-  bool ScrolledAwayFromEvaluation()
+  bool ScrolledAwayFromEvaluation() const
     { return m_scrolledAwayFromEvaluation; }
 
   void SaveValue();
 
-  bool IsSaved()
+  bool IsSaved() const
     { return m_saved; }
 
   void SetSaved(bool saved)
@@ -1377,18 +1391,6 @@ public:
   //! The list of cells that have to be evaluated
   EvaluationQueue m_evaluationQueue;
 
-  /*! Update the info which cell is the last of the worksheet
-
-    Also adjusts the scrollbar range to the worksheet length
-  */
-  GroupCell *UpdateMLast();
-  /*! Update the info which cell is the last of the worksheet
-
-    Also adjusts the scrollbar range to the worksheet length
-    \param gc The last GroupCell of the worksheet
-  */
-  GroupCell *UpdateMLast(GroupCell *gc);
-
   void FoldOccurred();
 
   // methods for folding
@@ -1461,7 +1463,7 @@ public:
     { m_autocomplete.AddSymbol(fun, type); }
 
   //! Add a xml-encoded list of symbols to the autocompletion list
-  void AddSymbols(wxString xml)
+  void AddSymbols(const wxString &xml)
     { m_autocomplete.AddSymbols(xml); }
   //! Add a xml-encoded list of symbols to the autocompletion list
   void AddSymbols(wxXmlDocument xml)
@@ -1473,14 +1475,11 @@ public:
 
   void OpenNextOrCreateCell();
 
-  //! The table of contents pane
-  TableOfContents *m_tableOfContents;
-
   //! Called when the "Scroll to currently evaluated" button is pressed.
   void OnFollow();
 
   //! The toolbar of the main window: We need to access it and therefore have it defined here.
-  ToolBar *m_mainToolBar;
+  ToolBar *m_mainToolBar = NULL;
 
   //! Set this cell as the currently selected one
   void SelectGroupCell(GroupCell *cell);
@@ -1494,29 +1493,29 @@ public:
   void QuestionAnswered();
 
   //! true = the last reply from maxima was a question
-  bool m_questionPrompt;
+  bool m_questionPrompt = false;
 
   /*! Does maxima wait for the answer of a question?
 
     \retval true = maxima waits for the answer of a question.
   */
-  bool QuestionPending()
+  bool QuestionPending() const
     { return m_questionPrompt; }
   //!@}
 
-  /*! Does maxima wait for the answer of a question?
+  /*! Does maxima currently wait for the answer of a question?
 
    */
   void QuestionPending(bool pending)
     { m_questionPrompt = pending; }
 
-  void SetMaximaDocDir(wxString dir)
+  void SetMaximaDocDir(const wxString &dir)
     {
       m_maximaDocDir = dir;
     }
 
-//! Does the GroupCell cell points to contain the question currently asked by maxima?
-  bool GCContainsCurrentQuestion(GroupCell *cell);
+  //! Does the GroupCell cell points to contain the question currently asked by maxima?
+  bool GCContainsCurrentQuestion(const GroupCell *cell);
 
   /*! Move the cursor to the question maxima currently asks and if needed add a cell for user input
    */
@@ -1531,15 +1530,12 @@ public:
   */
   GroupCell *GetWorkingGroup(bool resortToLast = false) const;
   //! Tries to parse maxima's manual in order to find out which anchors it contains
-  void LoadHelpFileAnchors(wxString docdir, wxString maximaVersion)
+  void LoadHelpFileAnchors(const wxString &docdir, const wxString &maximaVersion)
     {m_maximaManual.LoadHelpFileAnchors(docdir, maximaVersion);}
-  wxString GetHelpfileAnchorName(wxString keyword)
+  wxString GetHelpfileAnchorName(const wxString &keyword)
     {return m_maximaManual.GetHelpfileAnchorName(keyword);}
-  wxString GetHelpfileURL(wxString keyword)
+  wxString GetHelpfileURL(const wxString &keyword)
     {return m_maximaManual.GetHelpfileURL(keyword);}
-  //! The panel the user can display variable contents in
-  Variablespane *m_variablesPane = NULL;
-
   //! Returns the index in (%i...) or (%o...)
   int GetCellIndex(Cell *cell) const;
 
@@ -1584,8 +1580,8 @@ public:
                                  int *childId, wxAccessible **childObject);
     wxAccStatus GetDescription(int childId, wxString *description);
   private:
-    wxWindow *m_parent;
-    Worksheet *m_worksheet;
+    wxWindow *m_parent = NULL;
+    Worksheet *m_worksheet = NULL;
   };
 #endif
   MaximaManual m_maximaManual;
@@ -1593,23 +1589,23 @@ public:
 protected:
   void FocusTextControl();
   wxString m_lastQuestion;
-  int m_virtualWidth_Last;
-  int m_virtualHeight_Last;
+  int m_virtualWidth_Last = -1;
+  int m_virtualHeight_Last = -1;
   //! A memory we can manually buffer the contents of the area that is to be redrawn in
   wxBitmap m_memory;
-  virtual wxSize DoGetBestClientSize() const;
+  virtual wxSize DoGetBestClientSize() const override;
 #if wxUSE_ACCESSIBILITY
-  AccessibilityInfo *m_accessibilityInfo;
+  AccessibilityInfo *m_accessibilityInfo = NULL;
 #endif
   void UpdateConfigurationClientSize();
   //! Where to start recalculation. NULL = No recalculation needed.
-  GroupCell *m_recalculateStart;
+  CellPtr<GroupCell> m_recalculateStart;
   //! The x position of the mouse pointer
-  int m_pointer_x;
+  int m_pointer_x = -1;
   //! The y position of the mouse pointer
-  int m_pointer_y;
+  int m_pointer_y = -1;
   //! Was there a mouse motion we didn't react to until now?
-  bool m_mouseMotionWas;
+  bool m_mouseMotionWas = false;
   //! Is there an active popup menu?
   bool m_inPopupMenu = false;
 };
@@ -1621,4 +1617,6 @@ inline Worksheet *Cell::GetWorksheet() const
   return static_cast<Worksheet*>(worksheet);
 }
 
+wxDECLARE_EVENT(TOC_UPDATE_NEEDED_EVENT, wxCommandEvent);
+
 #endif // WORKSHEET_H
