@@ -42,9 +42,6 @@ AbsCell::AbsCell(GroupCell *group, Configuration *config,
   SetStyle(TS_VARIABLE);
 }
 
-// Old cppcheck bugs:
-// cppcheck-suppress uninitMemberVar symbolName=AbsCell::m_open
-// cppcheck-suppress uninitMemberVar symbolName=AbsCell::m_close
 AbsCell::AbsCell(GroupCell *group, const AbsCell &cell)
   : AbsCell(group, cell.m_configuration,
             CopyList(group, cell.m_innerCell.get())) {
@@ -127,8 +124,8 @@ wxString AbsCell::ToTeX() const {
 }
 
 wxString AbsCell::ToMathML() const {
-  return wxS("<row><mo>|</mo>") + m_innerCell->ListToMathML() +
-    wxS("<mo>|</mo></row>\n");
+  return wxS("<mrow><mo>|</mo>") + m_innerCell->ListToMathML() +
+    wxS("<mo>|</mo></mrow>\n");
   //  return wxS("<apply><abs/><ci>") + m_innerCell->ListToMathML() +
   //  wxS("</ci></apply>");
 }
