@@ -31,7 +31,6 @@
 #define PRINT_SIZE_MULTIPLIER (72.0 / 96.0)
 
 #include "AnimationCell.h"
-#include "../ErrorRedirector.h"
 #include "CellImpl.h"
 #include "CellPointers.h"
 #include "ImgCell.h"
@@ -183,7 +182,6 @@ void AnimationCell::LoadImages(wxMemoryBuffer imageData) {
 }
 
 void AnimationCell::LoadImages(wxString imageFile) {
-  SuppressErrorDialogs logNull;
   wxImage images;
   size_t count = wxImage::GetImageCount(imageFile);
 
@@ -218,7 +216,7 @@ void AnimationCell::LoadImages(wxArrayString images, bool deleteRead) {
         }
       }
     }
-  m_wxmxFile = wxEmptyString;
+  m_wxmxFile.Clear();
   m_displayed = 0;
 }
 
@@ -462,7 +460,7 @@ wxString AnimationCell::ToRTF() const {
   return header + image + footer;
 }
 
-const wxString &AnimationCell::GetToolTip(const wxPoint point) const {
+const wxString AnimationCell::GetToolTip(const wxPoint point) const {
   if (!ContainsPoint(point))
     return wxm::emptyString;
 
