@@ -39,9 +39,6 @@ BoxCell::BoxCell(GroupCell *group, Configuration *config,
   SetStyle(TS_VARIABLE);
 }
 
-// Old cppcheck bugs:
-// cppcheck-suppress uninitMemberVar symbolName=BoxCell::m_open
-// cppcheck-suppress uninitMemberVar symbolName=BoxCell::m_close
 BoxCell::BoxCell(GroupCell *group, const BoxCell &cell)
   : BoxCell(group, cell.m_configuration,
             CopyList(group, cell.m_innerCell.get())) {
@@ -140,8 +137,8 @@ wxString BoxCell::ToTeX() const {
 }
 
 wxString BoxCell::ToMathML() const {
-  return wxS("<apply><box/><ci>") + m_innerCell->ListToMathML() +
-    wxS("</ci></apply>");
+  return wxS("<menclose notation=\"box\">") + m_innerCell->ListToMathML() +
+    wxS("</menclose>");
 }
 
 wxString BoxCell::ToOMML() const {
