@@ -46,7 +46,7 @@
 
 const wxString &Cell::GetLocalToolTip() const { return *m_toolTip; }
 
-const wxString &Cell::GetToolTip(const wxPoint point) const {
+const wxString Cell::GetToolTip(const wxPoint point) const {
   if (!ContainsPoint(point))
     return wxm::emptyString;
 
@@ -136,6 +136,8 @@ wxBitmap Cell::BitmapFromSVG(wxString svgData, wxSize size)
 {
   svgData.Replace("\"currentColor\"",
                   "\"#" + wxColor2HtmlString(GetForegroundColor()) + "\"");
+  svgData.Replace("\"#FFFFFF\"",
+                  "\"#" + wxColor2HtmlString(m_configuration->DefaultBackgroundColor()) + "\"");
 #if wxCHECK_VERSION(3, 1, 6)
   wxBitmapBundle sumbitmap = wxBitmapBundle::FromSVG(svgData.c_str(),
                                                      size);
@@ -190,7 +192,7 @@ std::unique_ptr<Cell> Cell::CopyList(GroupCell *group) const {
   CellListBuilder<> copy;
   for (auto &src : OnList(this))
     copy.Append(src.Copy(group));
-  return copy;
+  return std::move(copy);
 }
 
 std::unique_ptr<Cell> Cell::CopyList(GroupCell *group, const Cell *cell) {
@@ -286,7 +288,7 @@ int Cell::GetLineWidth() const {
     if (&tmp != this)
       if (tmp.m_isBrokenIntoLines || tmp.m_breakLine ||
           (tmp.m_type == MC_TYPE_MAIN_PROMPT))
-        break; 
+        break;
     width += tmp.m_width;
   }
   return width;
@@ -339,13 +341,13 @@ void Cell::ClearToolTip() {
     m_toolTip = &wxm::emptyString;
 }
 
-void Cell::SetToolTip(wxString &&tooltip) {
+void Cell::SetToolTip(const wxString &tooltip) {
   if (m_ownsToolTip)
-    const_cast<wxString &>(*m_toolTip) = std::move(tooltip);
+    const_cast<wxString &>(*m_toolTip) = tooltip;
   else {
     m_toolTip = nullptr;
     m_ownsToolTip = true;
-    m_toolTip = new wxString(std::move(tooltip));
+    m_toolTip = new wxString(tooltip);
   }
 }
 
@@ -364,7 +366,7 @@ void Cell::AddToolTip(const wxString &tip) {
     return;
   if (m_ownsToolTip) {
     auto &wrToolTip = const_cast<wxString &>(*m_toolTip);
-    if (!m_toolTip->empty() && !wxm::EndsWithChar(*m_toolTip, '\n'))
+    if (!m_toolTip->empty() && !m_toolTip->EndsWith(wxS("\n")))
       wrToolTip << '\n';
     wrToolTip << tip;
   } else
@@ -514,7 +516,7 @@ void Cell::BreakLines_List()
   ResetSize_RecursivelyList();
 }
 
-bool Cell::BreakUpCells() {  
+bool Cell::BreakUpCells() {
   int clientWidth =
     .8 * m_configuration->GetCanvasSize().x - m_configuration->GetIndent();
   if (clientWidth < Scale_Px(50))
@@ -542,7 +544,7 @@ bool Cell::UnBreakUpCells() {
   }
   if(retval)
     ResetSize_RecursivelyList();
-    
+
   return retval;
 }
 
@@ -743,14 +745,14 @@ wxString Cell::ListToMathML(bool startofline) const {
   if (highlight)
     retval += wxS("</mrow>");
 
-  // If we grouped multiple cells as a single object we need to cose this group
+  // If we grouped multiple cells as a single object we need to close this group
   // now
   if ((multiCell) && (!needsTable))
     retval = wxS("<mrow>") + retval + wxS("</mrow>\n");
 
   // If we put the region we exported into a table we need to end this table now
   if (needsTable)
-    retval = wxS("<mtable>\n<mlabeledtr columnalign=\"left\"><mtd>") + retval +
+    retval = wxS("<mtable side=\"left\">\n<mlabeledtr><mtd>") + retval +
       wxS("</mtd></mlabeledtr>\n</mtable>");
   return retval;
 }
@@ -795,7 +797,7 @@ wxString Cell::OMML2RTF(wxString ommltext) {
 
   wxStringInputStream ommlStream(ommltext);
 
-  ommldoc.Load(ommlStream, wxS("UTF-8"));
+  ommldoc.Load(ommlStream);
 
   wxXmlNode *node = ommldoc.GetRoot();
   result += OMML2RTF(node);
@@ -1100,8 +1102,6 @@ wxColour Cell::GetForegroundColor() const {
   return color;
 }
 
-// cppcheck-suppress functionStatic
-// cppcheck-suppress functionConst
 // Set the pen in device context according to the style of the cell.
 void Cell::SetPen(wxDC *dc, double lineWidth) const {
   wxPen pen = *(wxThePenList->FindOrCreatePen(
@@ -1426,14 +1426,6 @@ wxAccStatus Cell::GetRole(int WXUNUSED(childId), wxAccRole *role) const {
 
 #endif
 
-size_t Cell::GetInnerCellCount_recursive() const
-{
-  size_t retval = GetInnerCellCount();
-  for (const Cell &cell : OnInner(this))
-    retval += cell.GetInnerCellCount_recursive();
-  return retval;
-}
-
 size_t Cell::GetInnerCellCount() const { return 0; }
 
 Cell *Cell::GetInnerCell(size_t) const {
