@@ -367,7 +367,7 @@ public:
       long long m_selEnd = -1;
     };
     bool AddState(HistoryEntry entry, Action action = any);
-    bool AddState(wxString text, long long selStart, long long selEnd, Action action = any);
+    bool AddState(const wxString &text, long long selStart, long long selEnd, Action action = any);
     bool Undo();
     bool Redo();
     bool CanUndo() const;
@@ -407,7 +407,7 @@ public:
   /*! Replaces all occurrences of a given string
    */
   size_t ReplaceAll(wxString oldString, const wxString &newString, bool ignoreCase);
-  size_t ReplaceAll_RegEx(wxString oldString, const wxString &newString);
+  size_t ReplaceAll_RegEx(const wxString &oldString, const wxString &newString);
 
   /*! Finds the next occurrences of a string
 
@@ -457,7 +457,7 @@ public:
   wxString GetWordUnderCaret();
 
   //! Get the command the cursor is in the arguments for.
-  wxString GetCurrentCommand();
+  wxString GetCurrentCommand() const;
 
   //! Sets the index the error is at
   void SetErrorIndex(size_t index){m_errorIndex = index; m_errorIndexSet = true;}
@@ -532,14 +532,14 @@ private:
     /*! The text of this text portion
      */
     wxString m_text;
+    //! The color of this text portion
+    TextStyle m_style = TS_CODE_DEFAULT;
     //! Chars that mark continued indentation
     wxString m_indentChar;
     //! The cached width of this piece of text
     wxCoord m_width = -1;
     //! By How many pixels we want to indent this line?
     wxCoord m_indentPixels = 0;
-    //! The color of this text portion
-    TextStyle m_style = TS_CODE_DEFAULT;
     //! Do we really want to style this text portion different than the default?
     bool m_styleThisText = false;
   public:
@@ -548,9 +548,9 @@ private:
       : m_text(text), m_style(style), m_styleThisText(true) {}
 
     //! Defines a piece of text with the default style that possibly is indented
-    explicit StyledText(const wxString &text, wxCoord indentPixels = 0,
+    explicit StyledText(const wxString &text, TextStyle style, wxCoord indentPixels = 0,
                         const wxString &indentChar = {})
-      : m_text(text), m_indentChar(indentChar), m_indentPixels(indentPixels)  {}
+      : m_text(text), m_style(style), m_indentChar(indentChar), m_indentPixels(indentPixels)  {}
 
     void SetWidth(wxCoord width){m_width = width;}
     void ResetSize(){SetWidth(-1);}
