@@ -915,7 +915,7 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
   }
 }
 
-wxRect GroupCell::HideRect() {
+wxRect GroupCell::HideRect() const {
   return wxRect(m_currentPoint.x - m_configuration->GetCellBracketWidth() -
                 m_configuration->GetDefaultLineWidth() / 2,
                 m_currentPoint.y - m_center -
@@ -991,9 +991,9 @@ wxString GroupCell::ToRTF() const {
   return retval;
 }
 
-wxString GroupCell::ToTeX(wxString imgDir, wxString filename,
-                          int *imgCounter) const {
-  int myImgCounter = 0;
+wxString GroupCell::ToTeX(const wxString &imgDir, const wxString &filename,
+                          std::size_t *imgCounter) const {
+  std::size_t myImgCounter = 0;
   if (imgCounter == NULL)
     imgCounter = &myImgCounter;
   wxString str;
@@ -1008,7 +1008,7 @@ wxString GroupCell::ToTeX(wxString imgDir, wxString filename,
       auto const copy = m_output->Copy(&parent);
       auto *const imgCopy = dynamic_cast<ImgCell *>(copy.get());
       (*imgCounter)++;
-      wxString image = filename + wxString::Format(wxS("_%d"), *imgCounter);
+      wxString image = filename + wxString::Format(wxS("_%zu"), *imgCounter);
       wxString file;
 
       if (!wxDirExists(imgDir))
@@ -1078,15 +1078,15 @@ wxString GroupCell::ToTeX(wxString imgDir, wxString filename,
   return str;
 }
 
-wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename,
-                                  int *imgCounter) const {
+wxString GroupCell::ToTeXCodeCell(const wxString &imgDir, const wxString &filename,
+                                  std::size_t *imgCounter) const {
   wxString str;
 
   // Input cells
   if (m_configuration->ShowCodeCells()) {
     // For LaTeX export we must use a dot as decimal separator
     // Save LC_NUMERIC, set it to "C", print out the float and then restore it.
-    char *old_lc_numeric;
+    const char *old_lc_numeric;
     wxString saved_lc_numeric("C");
     old_lc_numeric =
       std::setlocale(LC_NUMERIC, NULL); // get current LC_NUMERIC locale
@@ -1162,8 +1162,8 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename,
   return str;
 }
 
-wxString GroupCell::ToTeXImage(const Cell *tmp, wxString imgDir, wxString filename,
-                               int *imgCounter) {
+wxString GroupCell::ToTeXImage(const Cell *tmp, const wxString &imgDir, const wxString &filename,
+                               std::size_t *imgCounter) {
   wxASSERT_MSG((imgCounter != NULL), _("Bug: No image counter to write to!"));
   if(tmp == NULL) {
       wxLogMessage(_("No image to export"));
@@ -1178,8 +1178,10 @@ wxString GroupCell::ToTeXImage(const Cell *tmp, wxString imgDir, wxString filena
     // TODO: Is this the right Group?
     auto const copy = tmp->Copy(tmp->GetGroup());
     auto *const imgCopy = dynamic_cast<ImgCell *>(copy.get());
+    if(!imgCopy)
+      return wxEmptyString;
     (*imgCounter)++;
-    wxString image = filename + wxString::Format(wxS("_%d"), *imgCounter);
+    wxString image = filename + wxString::Format(wxS("_%zu"), *imgCounter);
     if (!wxDirExists(imgDir))
       if (!wxMkdir(imgDir))
         return wxEmptyString;
@@ -1379,7 +1381,7 @@ Cell::Range GroupCell::GetCellsInOutputRect(const wxRect &rect,
   return r;
 }
 
-const wxString &GroupCell::GetToolTip(const wxPoint point) const {
+const wxString GroupCell::GetToolTip(const wxPoint point) const {
   // TODO: There's a question of whether we want to return
   // the local tooltip, or empty string (latter would be in line
   // with Cell's behavior.
@@ -1390,10 +1392,10 @@ const wxString &GroupCell::GetToolTip(const wxPoint point) const {
   // if there is a more accurate solution.
   m_cellPointers->m_cellUnderPointer = const_cast<GroupCell *>(this);
 
-  const wxString *retval = &GetLocalToolTip();
+  wxString retval = GetLocalToolTip();
 
   if (IsHidden())
-    return *retval;
+    return retval;
 
   for (auto &tmp : OnList(m_inputLabel.get())) {
     if (tmp.ContainsPoint(point))
@@ -1410,15 +1412,14 @@ const wxString &GroupCell::GetToolTip(const wxPoint point) const {
     // TODO: Why do we keep iterating? Is there a reason to return the
     // tooltip of the last cell with a tooltip, instead of the first one?
 
-    auto &toolTip = tmp.GetToolTip(point);
+    auto toolTip = tmp.GetToolTip(point);
     if (!toolTip.empty())
-      retval = &toolTip;
+      retval = toolTip;
   }
 
-  return *retval;
+  return retval;
 }
 
-// cppcheck-suppress functionConst
 bool GroupCell::SetEditableContent(const wxString &text) {
   if (GetEditable()) {
     GetEditable()->SetValue(text);
@@ -1428,7 +1429,7 @@ bool GroupCell::SetEditableContent(const wxString &text) {
 }
 
 void GroupCell::BreakLines() {
-  Cell *cell = m_output.get();
+  const Cell * const cell = m_output.get();
 
   if (cell == NULL)
     return;
@@ -1781,7 +1782,7 @@ wxAccStatus GroupCell::GetDescription(int childId,
     }
   }
 
-  *description = wxEmptyString;
+  (*description).Clear();
   return wxACC_FAIL;
 }
 
@@ -1825,17 +1826,14 @@ wxAccStatus GroupCell::GetLocation(wxRect &rect, int elementId) {
 void CellList::Check(const GroupCell *c) {
   if (!c)
     return;
-  //cppcheck-suppress knownPointerToBool
   wxASSERT_MSG(!c->m_next || dynamic_cast<GroupCell *>(c->m_next.get()),
                _("Bug: The successor to a GroupCell is not a GroupCell."));
-  //cppcheck-suppress knownPointerToBool
   wxASSERT_MSG(!c->m_previous || dynamic_cast<GroupCell *>(c->m_previous),
                _("Bug: The predecessor to a GroupCell is not a GroupCell."));
   CellList::Check(static_cast<const Cell *>(c));
 }
 
-wxString GroupCell::m_lookalikeChars(
-                                     wxS("µ") wxS("\u03bc") wxS("\u2126") wxS("\u03a9") wxS("C") wxS(
+wxString GroupCell::m_lookalikeChars(wxS("µ") wxS("\u03bc") wxS("\u2126") wxS("\u03a9") wxS("C") wxS(
                                                                                                      "\u03F2") wxS("C") wxS("\u0421") wxS("\u03F2") wxS("\u0421") wxS("A")
                                      wxS("\u0391") wxS("A") wxS("\u0410") wxS("\u0391") wxS("\u0410") wxS(
                                                                                                           "M") wxS("\u0392") wxS("E") wxS("\u0395") wxS("E") wxS("\u0415")
