@@ -90,7 +90,7 @@ public:
   const wxString &GetAnswer(size_t answer) const;
   const wxString &GetAnswer(const wxString &question) const;
   //! Does this GroupCell know the answer to any of maxima's questions?
-  bool ContainsSavedAnswers() { return !m_knownAnswers.empty(); }
+  bool ContainsSavedAnswers() const { return !m_knownAnswers.empty(); }
   //! Does this GroupCell save the answer to a question?
   bool AutoAnswer() const { return m_autoAnswer; }
   void SetAutoAnswer(bool autoAnswer);
@@ -120,7 +120,7 @@ public:
 
     wxEmptyString means: No toolTip.
   */
-  const wxString &GetToolTip(wxPoint point) const override;
+  const wxString GetToolTip(wxPoint point) const override;
 
   // general methods
   GroupType GetGroupType() const { return m_groupType; }
@@ -162,13 +162,13 @@ public:
     doesn't contain other GroupCells that can export images and therefore
     need to enumerate them.
   */
-  wxString ToTeX(wxString imgDir, wxString filename, int *imgCounter) const;
+  wxString ToTeX(const wxString &imgDir, const wxString &filename, std::size_t *imgCounter) const;
 
   wxString ToRTF() const override;
 
-  wxString ToTeXCodeCell(wxString imgDir, wxString filename, int *imgCounter) const;
+  wxString ToTeXCodeCell(const wxString &imgDir, const wxString &filename, std::size_t *imgCounter) const;
 
-  static wxString ToTeXImage(const Cell *tmp, wxString imgDir, wxString filename, int *imgCounter);
+  static wxString ToTeXImage(const Cell *tmp, const wxString &imgDir, const wxString &filename, std::size_t *imgCounter);
 
   wxString ToTeX() const override;
 
@@ -178,7 +178,7 @@ public:
   virtual bool FirstLineOnlyEditor() override;
   void SwitchHide();
 
-  wxRect HideRect();
+  wxRect HideRect() const;
 
   // raw manipulation of GC (should be protected)
   void SetInput(std::unique_ptr<Cell> &&input);
