@@ -94,7 +94,7 @@ public:
   */
   void ClearCache() override { if (m_image) m_image->ClearCache(); }
 
-  const wxString &GetToolTip(wxPoint point) const override;
+  const wxString GetToolTip(wxPoint point) const override;
 
   //! Sets the bitmap that is shown
   void SetBitmap(const wxBitmap &bitmap);
@@ -113,7 +113,7 @@ public:
     { return m_origImageFile; }
 
   //! Sets the name of the file the image was originally created from
-  void SetOrigImageFile(wxString file)
+  void SetOrigImageFile(const wxString &file)
     { m_origImageFile = file; }
 
   //! Returns the original compressed version of the image
