@@ -26,7 +26,6 @@
   IntCell is the Cell type that represents maxima's <code>integrate()</code> command.
 */
 
-
 #ifndef INTCELL_H
 #define INTCELL_H
 
@@ -41,17 +40,17 @@ class IntCell final : public Cell
 {
 public:
   IntCell(GroupCell *group, Configuration *config,
-          std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&under,
-          std::unique_ptr<Cell> &&over, std::unique_ptr<Cell> &&var);
+          std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&lowerLimit,
+          std::unique_ptr<Cell> &&upperLimit, std::unique_ptr<Cell> &&var);
   IntCell(GroupCell *group, Configuration *config,
           std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&var);
   IntCell(GroupCell *group, const IntCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 9; }
+  size_t GetInnerCellCount() const override { return 9; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -76,9 +75,14 @@ public:
   bool BreakUp() override;
   void SetNextToDraw(Cell *next) override;
 
+  //! Does this integral have limits?
+  bool HasLimits() const {return (m_intStyle == INT_DEF) &&
+      (m_upperLimit != NULL) && (m_lowerLimit != NULL); }
+  
 private:
+  wxCoord IntSignLimitYoffset() const { return Scale_Px(8); }
   void MakeBreakUpCells();
-
+  const static wxString m_svgIntegralSign;
   // The pointers below point to inner cells and must be kept contiguous.
   // ** This is the draw list order. All pointers must be the same:
   // ** either Cell * or std::unique_ptr<Cell>. NO OTHER TYPES are allowed.
@@ -91,23 +95,23 @@ private:
   std::unique_ptr<Cell> m_var;
   std::unique_ptr<Cell> m_comma2;
   //! The lower limit of the integral
-  std::unique_ptr<Cell> m_under;
+  std::unique_ptr<Cell> m_lowerLimit;
   std::unique_ptr<Cell> m_comma3;
   //! The upper limit of the integral
-  std::unique_ptr<Cell> m_over;
+  std::unique_ptr<Cell> m_upperLimit;
   //! A text cell reading ")"
   std::unique_ptr<Cell> m_close;
   // The pointers above point to inner cells and must be kept contiguous.
 
   //! The height of the integral sign
-  int m_signHeight = 35;
+  wxCoord m_signHeight = 35;
   //! The width of the integral sign
-  int m_signWidth = 18;
+  wxCoord m_signWidth = 18;
   //! How far is the integral sign's center from the top of this cell?
-  int m_signTop = m_signHeight / 2;
+  wxCoord m_signTop = m_signHeight / 2;
 #if defined __WXMSW__
-  int m_charHeight = 12;
-  int m_charWidth = 12;
+  wxCoord m_charHeight = 12;
+  wxCoord m_charWidth = 12;
 #endif
 
   //! Is this integral definitive?
@@ -115,10 +119,10 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_IntCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
 };
 
-#endif  // INTCELL_H
+#endif  // INTCELL_Hs.
