@@ -30,7 +30,6 @@
 #include "TipOfTheDay.h"
 #include "Image.h"
 #include "SvgBitmap.h"
-#include "wxm_tipoftheday_images.h"
 #include <cstdlib>
 #include <wx/config.h>
 #include <wx/display.h>
@@ -42,6 +41,13 @@
 #include <wx/zstream.h>
 #include <algorithm>
 
+/* declared in wxm_media_playback_start_svg.h / wxm_media_playback_reverse_svg.h,
+   which is included in Toolbar.cpp */
+extern unsigned char MEDIA_PLAYBACK_START_SVG_GZ[];
+extern size_t MEDIA_PLAYBACK_START_SVG_GZ_SIZE;
+extern unsigned char MEDIA_PLAYBACK_REVERSE_SVG_GZ[];
+extern size_t MEDIA_PLAYBACK_REVERSE_SVG_GZ_SIZE;
+
 #define ICON_SCALE (0.35)
 
 TipOfTheDay::TipOfTheDay(wxWindow *parent)
@@ -255,7 +261,7 @@ TipOfTheDay::TipOfTheDay(wxWindow *parent)
   m_num = 0;
   wxConfigBase *config = wxConfig::Get();
 
-  // If nm is negative the if will make it posigive.
+  // If nm is negative, the if will make it positive.
   long nm;
   config->Read(wxS("tipNum"), &nm);
   m_num = nm;
@@ -267,8 +273,8 @@ TipOfTheDay::TipOfTheDay(wxWindow *parent)
   wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
   wxBoxSizer *hbox = new wxBoxSizer(wxHORIZONTAL);
   wxButton *backButton = new wxButton(this, -1);
-  backButton->SetBitmap(GetImage(MEDIA_PLAYBACK_START_REVERSE1_SVG_GZ,
-                                 MEDIA_PLAYBACK_START_REVERSE1_SVG_GZ_SIZE));
+  backButton->SetBitmap(GetImage(MEDIA_PLAYBACK_REVERSE_SVG_GZ,
+                                 MEDIA_PLAYBACK_REVERSE_SVG_GZ_SIZE));
   backButton->Connect(wxEVT_BUTTON,
                       wxCommandEventHandler(TipOfTheDay::OnPreviousButton),
                       NULL, this);
@@ -277,8 +283,8 @@ TipOfTheDay::TipOfTheDay(wxWindow *parent)
                              wxDefaultSize, wxALIGN_CENTRE_HORIZONTAL),
             wxSizerFlags().Proportion(10).Center());
   wxButton *forwardButton = new wxButton(this, -1);
-  forwardButton->SetBitmap(GetImage(MEDIA_PLAYBACK_START1_SVG_GZ,
-                                    MEDIA_PLAYBACK_START1_SVG_GZ_SIZE));
+  forwardButton->SetBitmap(GetImage(MEDIA_PLAYBACK_START_SVG_GZ,
+                                    MEDIA_PLAYBACK_START_SVG_GZ_SIZE));
   forwardButton->Connect(wxEVT_BUTTON,
                          wxCommandEventHandler(TipOfTheDay::OnNextButton), NULL,
                          this);
