@@ -23,7 +23,6 @@
 //  SPDX-License-Identifier: GPL-2.0+
 
 #include "OutCommon.h"
-#include "ErrorRedirector.h"
 #include "cells/GroupCell.h"
 #include "Worksheet.h"
 #include <cmath>
@@ -35,7 +34,7 @@ static wxString MakeTempFilename() {
     return wxFileName::CreateTempFileName(wxS("wxmaxima_size_"));
 }
 
-OutCommon::OutCommon(Configuration **configuration, const wxString &filename,
+OutCommon::OutCommon(const Configuration * const *configuration, const wxString &filename,
                      int fullWidth, double scale)
     : m_tempFilename(MakeTempFilename()),
       m_filename(filename.empty()
@@ -45,7 +44,7 @@ OutCommon::OutCommon(Configuration **configuration, const wxString &filename,
     m_thisconfig.ShowCodeCells(m_oldconfig->ShowCodeCells());
     m_thisconfig.SetWorkSheet((*configuration)->GetWorkSheet());
 
-    *m_configuration = &m_thisconfig;
+    //    *m_configuration = &m_thisconfig;
     m_thisconfig.SetZoomFactor_temporarily(1);
     m_thisconfig.FontChanged();
 
@@ -56,20 +55,17 @@ OutCommon::OutCommon(Configuration **configuration, const wxString &filename,
     m_thisconfig.SetParenthesisDrawMode(Configuration::handdrawn);
 }
 
-OutCommon::OutCommon(Configuration **configuration, int fullWidth, double scale)
+OutCommon::OutCommon(const Configuration * const *configuration, int fullWidth, double scale)
     : OutCommon(configuration, {}, fullWidth, scale) {}
 
 OutCommon::~OutCommon() {
     if (wxFileExists(m_tempFilename)) {
-        // We don't want a braindead virus scanner that disallows us to delete our
-        // temp files to trigger asserts.
-        SuppressErrorDialogs messageBlocker;
 
         if (!wxRemoveFile(m_tempFilename))
             wxLogMessage(_("Cannot remove the file %s"), m_tempFilename.mb_str());
     }
-    *m_configuration = m_oldconfig;
-    (*m_configuration)->FontChanged();
+    //    *m_configuration = m_oldconfig;
+    //    (*m_configuration)->FontChanged();
 }
 
 wxSize OutCommon::GetScaledSize() const {
@@ -138,7 +134,7 @@ void OutCommon::BreakLines(Cell *tree) const {
         // if (tmp.SoftLineBreak(false))
         //     // Note: This ResetData() call was unconditional in EMFout and SVGout.
         //     // The condition check was only performed in BitmapOut. That was likely
-        //     // an ommission. This note is here in case bugs were found in this area.
+        //     // an omission. This note is here in case bugs were found in this area.
         //     tmp.ResetSize_Recursively();
 
         if (tmp.BreakLineHere() || (currentWidth + tmp.GetWidth() >= fullWidth)) {
@@ -170,10 +166,10 @@ void OutCommon::GetMaxPoint(Cell *tree, int *width, int *height) const {
                 currentHeight += MC_LINE_SKIP;
             *height = currentHeight;
             currentWidth = tmp.GetWidth();
-            *width = wxMax(currentWidth, *width);
+            *width = std::max(currentWidth, *width);
         } else {
             currentWidth += (tmp.GetWidth());
-            *width = wxMax(currentWidth, *width);
+            *width = std::max(currentWidth, *width);
         }
         bigSkip = tmp.HasBigSkip();
     }
@@ -256,9 +252,6 @@ OutCommon::GetDataObject(const wxDataFormat &format) {
     }
 
     if ((!m_filename.empty()) && wxFileExists(m_filename)) {
-        // Don't output error messages if the worst thing that can happen is that we
-        // cannot clean up a temp file
-        SuppressErrorDialogs messageBlocker;
         wxRemoveFile(m_filename);
     }
     m_filename.clear();
