@@ -55,6 +55,7 @@
 #include "Version.h"
 #include "examples/CASvsProgrammingLanguage.h"
 #include "examples/diffEquations.h"
+#include "examples/draw2d.h"
 #include "examples/displaying3DCurves.h"
 #include "examples/fastListAccess.h"
 #include "examples/fittingEquations.h"
@@ -70,6 +71,14 @@
 // We have to force gnome_print support to be linked in static builds of
 // wxMaxima.
 
+
+// We require Unicode support now.
+// It is always on by default and builds without unicode support are strongly
+// discouraged by the wxWidgets team
+#if wxUSE_UNICODE == 0
+#error "wxWidgets builds without Unicode support are strongly discouraged and not supported"
+#endif
+
 #if defined wxUSE_LIBGNOMEPRINT
 #if wxUSE_LIBGNOMEPRINT
 #include <wx/html/forcelnk.h>
@@ -85,19 +94,22 @@ wxDECLARE_APP(MyApp);
 int CommonMain() {
   wxTheApp->CallOnInit();
   wxTheApp->OnRun();
-  wxConfigBase *config = wxConfig::Get();
-  config->Flush();
-  delete config;
-  if (CellPtrBase::GetLiveInstanceCount() != 0)
-    wxLogDebug("CellPtr: %zu live instances leaked",
-               CellPtrBase::GetLiveInstanceCount());
-  if (Observed::GetLiveInstanceCount() != 0)
-    wxLogDebug("Cell:    %zu live instances leaked",
-               Observed::GetLiveInstanceCount());
-  if (Observed::GetLiveControlBlockInstanceCount() != 0)
-    wxLogDebug("ControlBlock: %zu live instances leaked",
-               Observed::GetLiveControlBlockInstanceCount());
-  return 0;
+  // wxConfigBase *config = wxConfig::Get();
+  // config->Flush();
+  // delete config;
+  if(Configuration::GetDebugmode())
+    {
+     if (CellPtrBase::GetLiveInstanceCount() != 0)
+       wxLogDebug("CellPtr: %zu live instances leaked",
+                  CellPtrBase::GetLiveInstanceCount());
+     if (Observed::GetLiveInstanceCount() != 0)
+       wxLogDebug("Cell:    %zu live instances leaked",
+                  Observed::GetLiveInstanceCount());
+     if (Observed::GetLiveControlBlockInstanceCount() != 0)
+       wxLogDebug("ControlBlock: %zu live instances leaked",
+                  Observed::GetLiveControlBlockInstanceCount());
+     }
+  return wxMaxima::GetExitCode();
 }
 wxCmdLineParser cmdLineParser;
 static const wxCmdLineEntryDesc cmdLineDesc[] = {
@@ -176,17 +188,24 @@ int WINAPI WinMain(_In_ HINSTANCE hI, _In_opt_ HINSTANCE hPrevI, _In_ LPSTR lpCm
 }
 #endif
 
+
+// TODO: "C++ify" the code, don't use global variables.
+// In wxMaxima.cpp they are used as 'extern' variables.
+wxLogWindow * wxm_logwindow; // The wxWidgets log window, we use.
+int windowcount = 0; // How many wxMaxima windows are open (in the current process)?
 bool MyApp::OnInit() {
-  wxLogStderr noErrorDialogs;
+  // if DEBUG=1 show the logwindow at start, else hide it.
+#if (DEBUG==1)
+  wxm_logwindow = new wxLogWindow( NULL, wxS("wxMaxima log window"), true, false);
+#else
+  wxm_logwindow = new wxLogWindow( NULL, wxS("wxMaxima log window"), false, false);
+#endif
   // Needed for making wxSocket work for multiple threads. We currently don't
   // use this feature. But it doesn't harm to be prepared
   wxSocketBase::Initialize();
 
   m_translations = std::unique_ptr<wxTranslations>(new wxTranslations());
   wxTranslations::Set(m_translations.get());
-  // connect to wxMaxima. We therefore delay all output to the log until there
-  // is a window that can display it on the GUI instead.
-  wxLogBuffer noStdErr;
   {
     // If supported: Generate symbolic backtraces on crashes.
 #if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
@@ -241,7 +260,6 @@ bool MyApp::OnInit() {
 
     {
 #if wxCHECK_VERSION(3, 1, 6)
-      wxLogNull suppressErrorMessages;
       wxUILocale::UseDefault();
 #else
       m_locale = std::unique_ptr<wxLocale>(new wxLocale);
@@ -267,11 +285,23 @@ bool MyApp::OnInit() {
     if (wxLocale::IsAvailable(lang))
       wxTranslations::Get()->SetLanguage(lang);
 
-    // Do we reckon we improve something if we set maxima's language, as well?
+    /* Maxima depending on the lisp it was compiled by and the lisp's version
+       might only support Unicode if LANG tells it so.
+
+       Do we reckon we improve something if we set maxima's language, as well?
+    */
     if ((wxLocale::IsAvailable(lang)) && (lang != wxLANGUAGE_DEFAULT)) {
       // Set maxima's language, as well.
       wxString localeName = wxLocale().GetCanonicalName();
-      if (lang != wxLocale::GetSystemLanguage()) {
+      if(localeName.IsEmpty())
+        localeName = wxS("C");
+      if ((!localeName.Upper().EndsWith(wxS("UTF-8"))) &&
+          (!localeName.Upper().EndsWith(wxS("UTF8"))) &&
+          (!localeName.Upper().EndsWith(wxS("UTF-16"))) &&
+          (!localeName.Upper().EndsWith(wxS("UTF16"))) &&
+          (!localeName.Upper().EndsWith(wxS("UTF-32"))) &&
+          (!localeName.Upper().EndsWith(wxS("UTF32"))))
+        {
         if (wxLocale().GetSystemEncoding() == wxFONTENCODING_UTF16)
           localeName += wxS(".UTF-16");
         else {
@@ -281,19 +311,16 @@ bool MyApp::OnInit() {
             localeName += wxS(".UTF-8");
           }
         }
+        Configuration::SetMaximaLang(localeName);
         wxSetEnv(wxS("LANG"), localeName);
       }
     }
     wxTranslations::Get()->AddCatalog(wxS("wxMaxima"));
-    /* wxWidgets introduced version suffixes to gettext catalogs, see:
-     * https://github.com/wxWidgets/wxWidgets/commit/ded4da5 */
-    /* so try to load a catalog with this suffix */
-    wxTranslations::Get()->AddCatalog("wxstd-"
-                                      // cppcheck-suppress unknownMacro
-                                      wxSTRINGIZE(wxMAJOR_VERSION) "."
-                                      // cppcheck-suppress unknownMacro
-                                      wxSTRINGIZE(wxMINOR_VERSION));
-    wxTranslations::Get()->AddCatalog(wxS("wxstd"));
+    /* Add standard wxWidgets catalogs ("wxstd" and possible port-specific catalogs). */
+    /* returns false, if no suitable catalog was found, in this case log that. */
+    if (wxTranslations::Get()->AddStdCatalog() == false) {
+      wxLogMessage("Translations: no standard wxWidgets catalogs were found");
+    }
   }
 
   bool exitAfterEval = false;
@@ -323,8 +350,24 @@ bool MyApp::OnInit() {
   } else
     wxConfig::Set(new wxConfig(wxS("wxMaxima")));
 
-  if (cmdLineParser.Found(wxS("logtostderr")))
-    ErrorRedirector::LogToStdErr();
+  if (cmdLineParser.Found(wxS("logtostderr"))) {
+#ifdef __WXMSW__
+    // Windows *GUI applications* do not have stderr (and stdout/stdin) assigned.
+    // Assign them, as we want to output something there. (log messages on STDERR
+    // when using the option --logtostderr).
+    // A seperate "text window" will be opened, where the messages will be shown.
+    FreeConsole(); // it does not seem to work without the FreeConsole() / AllocConsole() calls.
+    // create a separate new console window
+    AllocConsole();
+    // attach the new console to this application's process
+    AttachConsole(GetCurrentProcessId());
+    // reopen the std I/O streams to redirect I/O to the new console
+    if (!freopen("CON", "w", stdout)) wxLogMessage(_("Re-opening STDOUT failed."));
+    if (!freopen("CON", "w", stderr)) wxLogMessage(_("Re-opening STDERR failed."));
+    if (!freopen("CON", "r", stdin)) wxLogMessage(_("Re-opening STDIN failed."));
+#endif
+    wxLogChain *logChain = new wxLogChain(new wxLogStderr);
+  }
 
   if (cmdLineParser.Found(wxS("debug")))
     Configuration::SetDebugmode();
@@ -375,8 +418,6 @@ bool MyApp::OnInit() {
                             wxPathOnly(wxStandardPaths::Get().GetExecutablePath()));
   }
 #if wxCHECK_VERSION(3, 1, 1)
-  wxString fontPrefix = m_dirstruct.FontDir() + wxS("/");
-
   wxSetWorkingDirectory(oldWorkingDir);
 #endif
 #endif
@@ -408,9 +449,9 @@ bool MyApp::OnInit() {
 
   if (cmdLineParser.Found(wxS("v"))) {
 #if defined(WXMAXIMA_GIT_SHORT_HASH)
-    wxMessageOutput::Get()->Printf("wxMaxima %s (Git version: %s)\n", GITVERSION, WXMAXIMA_GIT_SHORT_HASH);
+    wxMessageOutput::Get()->Printf("wxMaxima %s (Git version: %s)\n", WXMAXIMA_VERSION, WXMAXIMA_GIT_SHORT_HASH);
 #else
-    wxMessageOutput::Get()->Printf("wxMaxima %s\n", GITVERSION);
+    wxMessageOutput::Get()->Printf("wxMaxima %s\n", WXMAXIMA_VERSION);
 #endif
     exit(0);
   }
@@ -447,18 +488,16 @@ bool MyApp::OnInit() {
   if (!windowOpened)
     NewWindow();
 
-  // Now we can finally send our debug output to a window without making
-  // std::cerr confusing the mac.
-  wxString logMessagesSoFar = noStdErr.GetBuffer();
-  if (!logMessagesSoFar.IsEmpty())
-    wxLogMessage("Log messages during early startup: %s", logMessagesSoFar.mb_str());
   return true;
 }
 
-int MyApp::OnExit() { return wxMaxima::GetExitCode(); }
+int MyApp::OnExit() {
+  for(auto i:m_wxMaximaProcesses)
+    i->Detach();
+  return wxMaxima::GetExitCode();
+}
 
 int MyApp::OnRun() {
-  wxLogStderr noErrorDialogs;
   wxApp::OnRun();
   return 0;
 }
@@ -471,16 +510,10 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
   if (file.Length() > 0)
     title = file;
 
-  int numberOfWindows = 1; // TODO: Count
-
-  wxWindowList::compatibility_iterator node = wxTopLevelWindows.GetFirst();
-  while (node) {
-    numberOfWindows++;
-    node = node->GetNext();
-  }
+  size_t numberOfWindows = wxMaximaFrame::CountWindows();
 
   if (numberOfWindows > 1)
-    title = wxString::Format(_("wxMaxima %d"), numberOfWindows);
+    title = wxString::Format(_("wxMaxima %ld"), static_cast<long>(numberOfWindows));
 
   wxString initialContents;
   if (wxmData) {
@@ -494,14 +527,13 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
       if ((line.StartsWith("/*")) || (line.EndsWith("*/"))) {
         initialContents += _(block);
         initialContents += line + "\n";
-        block = wxEmptyString;
+        block.Clear();
       } else
         block += line + "\n";
     }
     initialContents += _(block);
   }
   wxMaxima *frame = new wxMaxima(NULL, wxID_ANY, title, file, initialContents);
-
   frame->EvalOnStartup(evalOnStartup);
   frame->ExitAfterEval(exitAfterEval);
   frame->Show(true);
@@ -514,6 +546,11 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       NewWindow(wxEmptyString, false, false, NUMBERFORMATS_WXM,
                 NUMBERFORMATS_WXM_SIZE);
     }
+  else if(ev.GetId() == EventIDs::menu_help_2d)
+    {
+      NewWindow(wxEmptyString, false, false, DRAW2D_WXM,
+                DRAW2D_WXM_SIZE);
+    }
   else if(ev.GetId() == EventIDs::menu_help_3d)
     {
       NewWindow(wxEmptyString, false, false, DISPLAYING3DCURVES_WXM,
@@ -577,6 +614,8 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     else {
       // Compile a list of arguments we want to pass to the new process
       std::vector<wxString> args;
+      args.push_back(wxStandardPaths::Get().GetExecutablePath().mb_str());
+
       if (Configuration::m_configfileLocation_override != wxEmptyString)
         {
           args.push_back("-f");
@@ -587,8 +626,6 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
           args.push_back("-m");
           args.push_back(wxMaxima::Get_Maxima_Commandline_Filename());
         }
-      if (ErrorRedirector::LoggingToStdErr())
-        args.push_back("--logtostderr");
       if (Configuration::GetDebugmode())
         args.push_back("--debug");
       if (Maxima::GetPipeToStdErr())
@@ -607,24 +644,27 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       // generate those C strings
       std::vector<wxCharBuffer> args_c_strings;
       for(const auto &i : args)
-        args_c_strings.push_back(wxCharBuffer(i.mb_str()));
+        {
+          wxCharBuffer buf = i.utf8_str();
+          args_c_strings.push_back(buf);
+        }
 
       // Additionally wxExecute expects these C strings in a C array.
+      std::vector<char *> argslist;
+      for(auto &i : args_c_strings)
+        argslist.push_back(static_cast<char *>(i.data()));
+      // Add an "end of arguments list" marker to the list of arguments
+      argslist.push_back(NULL);
+      wxProcess *prcss = new wxProcess;
       // Let's generate an unique pointer to that one so C++ automatically destroys it
       // once it is no more needed.
-      std::unique_ptr<char*[]> args_array(new char*[args.size() + 2]);
-      wxCharBuffer executableName(wxStandardPaths::Get().GetExecutablePath().mb_str());
-      args_array.get()[0] = executableName.data();;
-      args_array.get()[args.size() + 1] = NULL;
-      for(std::size_t i = 0; i< args.size(); i++)
-        args_array.get()[i + 1] = args_c_strings[i].data();
-      wxExecute(args_array.get());
-
-      wxString command;
-      for(std::size_t i = 0; i< args.size() + 1; i++)
-        command += wxString::FromUTF8(args_array.get()[i]) + "\n";
-      command.Trim();
-      wxLogMessage(_("Starting a new wxMaxima process as: %s"), command.mb_str());
+      wxExecute(argslist.data(),
+                wxEXEC_HIDE_CONSOLE | wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER,
+                prcss);
+      m_wxMaximaProcesses.push_back(prcss);
+      // Tell wxWidgets that we don't want any signals from this process
+      prcss->Detach();
+      wxLogMessage(_("Starting a new wxMaxima process for a new window"));
     }
   }
   else if(ev.GetId() == wxID_PREFERENCES) {
@@ -641,7 +681,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
 
 
 void MyApp::MacNewFile() {
-  wxWindow *frame = GetTopWindow();
+  const wxWindow *frame = GetTopWindow();
   if (frame == NULL)
     NewWindow();
 }
@@ -657,13 +697,6 @@ void MyApp::OnFatalException()
 // Adapted from wxWidget's report sample
 void MyApp::GenerateDebugReport(wxDebugReport::Context ctx)
 {
-  if(ErrorRedirector::LoggingToStdErr())
-    {
-      StackToStdErr stackWalker;
-      stackWalker.Walk(0);
-      return;
-    }
-  else
     {
       wxDebugReportCompress *report = new wxDebugReportCompress;
 
@@ -736,3 +769,10 @@ void MyApp::GenerateDebugReport(wxDebugReport::Context ctx)
     }
 }
 #endif
+
+#if defined __WXOSX__
+  bool MyApp::m_allWindowsInOneProcess = true;
+#else
+  bool MyApp::m_allWindowsInOneProcess = false;
+#endif
+std::vector<wxProcess *> MyApp::m_wxMaximaProcesses;
