@@ -43,7 +43,6 @@
 #include <wx/sizer.h>
 #include <wx/txtstrm.h>
 #include <wx/wupdlock.h>
-#include "../ErrorRedirector.h"
 History::History(wxWindow *parent, int id, Configuration *cfg)
   : wxPanel(parent, id) {
   wxConfig::Get()->Read(m_showCurrentSessionOnlyKey, &m_showCurrentSessionOnly);
@@ -71,7 +70,6 @@ History::History(wxWindow *parent, int id, Configuration *cfg)
 
   wxConfig::Get()->Read("history/saveplace", &m_saveplace);
   if(!m_saveplace.IsEmpty() && wxFile::Exists(m_saveplace)) {
-      SuppressErrorDialogs suppressor;
       wxXmlDocument doc;
       wxFileInputStream fstrm(m_saveplace);
       if (fstrm.IsOk()) {
@@ -96,6 +94,7 @@ History::History(wxWindow *parent, int id, Configuration *cfg)
         }
       }
   }
+  m_sessionCommands = 0;
 }
 
 void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event)) {
@@ -234,7 +233,7 @@ void History::OnMenu(wxCommandEvent &event) {
     LoggingMessageBox(_("Exporting to .mac file failed!"), _("Error!"), wxOK);
 }
 
-void History::SetSavePlace(wxString saveplace)
+void History::SetSavePlace(const wxString &saveplace)
 {
   m_saveplace = saveplace + "/wxMaximaHistory.xml";
   wxConfig::Get()->Write("history/saveplace", m_saveplace);
@@ -301,9 +300,18 @@ wxString History::GetCommand(bool next) {
   if (m_commands.size() == 0)
     return wxEmptyString;
 
-  auto current = m_current + (next ? +1 : -1);
+  size_t current = m_current;
+
+  if(next)
+    {
+      current++;
+    }
+  else
+    {
+      if(current > 0)
+      current--;
+    }  
   if (current >= m_history->GetCount()) current = m_history->GetCount()-1;
-  if (current < 0) current = 0;
   SetCurrent(current);
   return m_history->GetString(current);
 }
