@@ -57,33 +57,46 @@ class History final : public wxPanel
 public:
   History(wxWindow *parent, int id, Configuration *cfg);
 
+  //! The destructor
   ~History();
 
   //! Add a file to the recently opened files list.
   void AddToHistory(const wxString &cmd);
 
+  //! Called if the filter text or method changes
   void OnRegExEvent(wxCommandEvent &ev);
 
+  //! Apply all filters and refresh the display
   void RebuildDisplay();
 
+  /*! Get the currently selected command and advance the selection
+
+    \param next
+      - true: Advance the current selection by one
+      - false: Advance the current selection by -1
+   */
   wxString GetCommand(bool next);
 
+  //! Is called when a new maxima session starts
   void MaximaSessionStart();
 
   //! Actually update the history sidebar. Called when no other work is to be done.
   bool UpdateDeferred();
-  void SetSavePlace(wxString saveplace);
+  //! Where to save the history?
+  void SetSavePlace(const wxString &saveplace);
 
 private:
   //! Called on right-clicks on the history panel
   void OnMouseRightDown(wxMouseEvent &event);
+  //! Called if the user calls on a menu item
   void OnMenu(wxCommandEvent &event);
 
   void UnselectAll() const;
   void SetCurrent(long current);
 
   wxString m_saveplace;
-  int m_sessionCommands = 0;
+  //! How many commands in the history are from the current session?
+  size_t m_sessionCommands = 0;
   wxListBox *m_history;
   RegexCtrl *m_regex;
   std::vector<wxString> m_commands;
