@@ -165,7 +165,7 @@ void TableOfContents::OnDragStart(wxListEvent &evt) {
 
     // For the visual feedback: How many toc items does the user drag?
     m_numberOfCaptionsDragged = 1;
-    GroupCell *tmp = m_displayedGroupCells[evt.GetIndex()];
+    const GroupCell *tmp = m_displayedGroupCells[evt.GetIndex()];
     auto index = evt.GetIndex() + 1;
     tmp = tmp->GetNext();
     while ((tmp != NULL) && (index <= m_displayedItems->GetItemCount())) {
@@ -197,7 +197,7 @@ void TableOfContents::OnMouseUp(wxMouseEvent &evt) {
        m_displayedItems->GetItemCount() - m_numberOfCaptionsDragged))
     m_dragStop = m_numberOfCaptionsDragged - 1;
   if ((m_dragStart >= 0) && (m_dragStop >= 0) && (m_dragStart != m_dragStop)) {
-    wxWindow *mainWin = this;
+    const wxWindow *mainWin = this;
     while (mainWin->GetParent() != NULL)
       mainWin = mainWin->GetParent();
     wxCommandEvent *tocEv = new wxCommandEvent;
@@ -523,17 +523,17 @@ void TableOfContents::OnMouseRightDown(wxListEvent &event) {
 
   wxMenu *tocLevelMenu = new wxMenu();
   tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1, _("1 Level"));
-  for(int i = 2; i < EventIDs::NumberOfTocLevels() - 1; i++)
+  for(int i = 2; i < EventIDs::NumberOfTocLevels - 1; i++)
     tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1 + i - 1,
                                   wxString::Format(_("%li Levels"), static_cast<long>(i)));
   tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1 +
-                                EventIDs::NumberOfTocLevels() - 1, _("All Levels"));
+                                EventIDs::NumberOfTocLevels - 1, _("All Levels"));
 
-  if (m_configuration->TocDepth() < EventIDs::NumberOfTocLevels())
+  if (m_configuration->TocDepth() < EventIDs::NumberOfTocLevels)
     tocLevelMenu->Check(EventIDs::popid_tocLevel1 + m_configuration->TocDepth() - 1,
                         true);
   else
-    tocLevelMenu->Check(EventIDs::popid_tocLevel1 + EventIDs::NumberOfTocLevels() - 1, true);
+    tocLevelMenu->Check(EventIDs::popid_tocLevel1 + EventIDs::NumberOfTocLevels - 1, true);
   popupMenu->Append(wxID_ANY, _("Toc levels shown here"), tocLevelMenu);
 
   if (popupMenu->GetMenuItemCount() > 0)
