@@ -25,7 +25,7 @@
 #include <wx/persist/toplevel.h>
 
 Gen4Wiz::Gen4Wiz(wxString lab1, wxString lab2, wxString lab3, wxString lab4,
-                 wxString val1, wxString val2, wxString val3, wxString val4,
+                 const wxString &val1, const wxString &val2, const wxString &val3, const wxString &val4,
                  Configuration *cfg, wxWindow *parent, int id,
                  const wxString &title, bool eq, const wxString &warning,
                  const wxString &warningToolTip, const wxPoint &pos,
