@@ -234,21 +234,21 @@ void Plot2DWiz::Parse(wxString s) {
   while (i < s.Length() && s.GetChar(i) != '[')
     i++;
   i++;
-  curr = wxEmptyString;
+  curr.Clear();
   while (i < s.Length() && s.GetChar(i) != ',') {
     curr += s.GetChar(i);
     i++;
   }
   text_ctrl_2->SetValue(curr);
   i++;
-  curr = wxEmptyString;
+  curr.Clear();
   while (i < s.Length() && s.GetChar(i) != ',') {
     curr += s.GetChar(i);
     i++;
   }
   text_ctrl_3->SetValue(curr);
   i++;
-  curr = wxEmptyString;
+  curr.Clear();
   while (i < s.Length() && s.GetChar(i) != ']') {
     curr += s.GetChar(i);
     i++;
@@ -259,7 +259,7 @@ void Plot2DWiz::Parse(wxString s) {
   while (i < s.Length()) {
     if (s.GetChar(i) == '[') {
       i++;
-      curr = wxEmptyString;
+      curr.Clear();
       while (i < s.Length() && s.GetChar(i) != ',' && s.GetChar(i) != ']') {
         curr += s.GetChar(i);
         i++;
@@ -267,7 +267,7 @@ void Plot2DWiz::Parse(wxString s) {
       curr.Trim();
       curr.Trim(false);
       if (curr == wxS("y")) {
-        curr = wxEmptyString;
+        curr.Clear();
         i++;
         while (i < s.Length() && s.GetChar(i) != ',') {
           curr += s.GetChar(i);
@@ -275,7 +275,7 @@ void Plot2DWiz::Parse(wxString s) {
         }
         text_ctrl_6->SetValue(curr);
         i++;
-        curr = wxEmptyString;
+        curr.Clear();
         while (i < s.Length() && s.GetChar(i) != ']') {
           curr += s.GetChar(i);
           i++;
@@ -286,7 +286,7 @@ void Plot2DWiz::Parse(wxString s) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
-        curr = wxEmptyString;
+        curr.Clear();
         while (i < s.Length() && s.GetChar(i) != '"') {
           curr += s.GetChar(i);
           i++;
@@ -296,14 +296,14 @@ void Plot2DWiz::Parse(wxString s) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
-        curr = wxEmptyString;
+        curr.Clear();
         while (i < s.Length() && s.GetChar(i) != '"') {
           curr += s.GetChar(i);
           i++;
         }
         text_ctrl_9->SetValue(curr);
       } else if (curr == wxS("nticks")) {
-        curr = wxEmptyString;
+        curr.Clear();
         while (i < s.Length() && s.GetChar(i) != ',')
           i++;
         i++;
