@@ -40,6 +40,19 @@
 
 ;; TODO: outchar isn't properly escaped in xml
 
+;; Maxima (compiled with gcl) creates an error, when called with:
+;; maxima --init-lisp=path/to/wxMathML.lisp
+;; and the command :lisp-quiet (wxPrint_autocompletesymbols)
+;; is entered:
+;; Maxima encountered a Lisp error:
+;;
+;; Condition in MACSYMA-TOP-LEVEL [or a callee]: INTERNAL-SIMPLE-ERROR: Caught fatal error [memory may be damaged]
+;;
+;; Camm recommends that command to solve the problem
+;; (see https://groups.google.com/g/linux.debian.bugs.dist/c/YJRvUrVUHGQ)
+;; and indeed it seems to solve the issue.
+#+gcl (si::readline-off)
+
 (format t "<wxxml-key>~A</wxxml-key>~%" (maxima-getenv "MAXIMA_AUTH_CODE"))
 
 (in-package :maxima)
@@ -53,13 +66,6 @@
  (special lop rop $inchar)
  (*expr wxxml-lbp wxxml-rbp))
 
-;; Use rounded parenthesis for matrices by default
-;; Other possible values would be #\| or #\[
-;;
-;; TODO: Why don't we use maxima's default value here, but assign our own?
-(setq $lmxchar #\()
-(setq $rmxchar #\))
-
 (setf *prompt-prefix* "<PROMPT>")
 (setf *prompt-suffix* "</PROMPT>")
 ;; Permanently assign a property named indic with the value val to the symbol sym
@@ -79,7 +85,7 @@
 ;; Define a few variables whose value will be set by wxMaxima
 (defvar *wx-plot-num* 0 "The serial number of the current plot")
 (defvar $wxfilename "" "The filename of the current wxMaxima worksheet")
-(defvar $wxdirname "" "The directory the current wxMaxima worksheet lies in")
+(defvar $wxdirname "" "The directory the current wxMaxima worksheet is located")
 (defvar $wxanimate_autoplay nil "Automatically playback new animations?")
 (defvar wxUserConfDir "" "The location wxMaxima looks for maxima's config files in")
 (defvar wxHelpDir "" "The location wxMaxima searches for help files in")
@@ -93,7 +99,6 @@
   "Recognize TeX-style subscripts")
 (defvar $wxplot_usesvg nil "Create scalable plots?")
 (defvar $wxplot_pngcairo nil "Use gnuplot's pngcairo terminal for new plots?")
-(defmvar $wxplot_old_gnuplot nil)
 
 ;; A string replace function that we later use excessively
 (defun wxxml-string-substitute (newstring oldchar x &aux matchpos)
@@ -128,9 +133,6 @@
       (let* ((tmp-x (wxxml-string-substitute "&amp;" #\& x))
 	     (tmp-x (wxxml-string-substitute "&lt;" #\< tmp-x))
 	     (tmp-x (wxxml-string-substitute "&gt;" #\> tmp-x))
-	     (tmp-x (wxxml-string-substitute "&#13;" #\Return tmp-x))
-	     (tmp-x (wxxml-string-substitute "&#13;" #\Linefeed tmp-x))
-	     (tmp-x (wxxml-string-substitute "&#13;" #\Newline tmp-x))
 	     (tmp-x (wxxml-string-substitute "&quot;" #\" tmp-x)))
 	tmp-x)
       nil))
@@ -195,8 +197,8 @@ Submit bug reports by following the 'New issue' link on that page."))
 ;; It also includes more info, e.g. the directory information from Maxima.
 (defun $wxbuild_info ()
   (progv  '(seconds minute hour day month year) cl-user:*maxima-build-time*
-    (format t "~30a~a~%" "wxMaxima version:" $wxmaximaversion)
-    (format t "~30a~a~%" "using wxWidgets version:" $wxwidgetsversion)
+    (format t "~30a~a~%" "WxMaxima version:" $wxmaximaversion)
+    (format t "~30a~a~%" "Using wxWidgets version:" $wxwidgetsversion)
     (format t "~30a~a~%" "Maxima version:" *autoconf-version*)
     (format t "~30a~4,'0d-~2,'0d-~2,'0d ~2,'0d:~2,'0d:~2,'0d~%" "Maxima build date:"
            year month day hour minute seconds)
@@ -204,7 +206,7 @@ Submit bug reports by following the 'New issue' link on that page."))
     (format t "~30a~a ~a ~a~%" "System type:" (software-type) (software-version) (machine-type))
     (format t "~30a~a~%" "Lisp implementation type:" (lisp-implementation-type))
     (format t "~30a~a~%" "Lisp implementation version:" (lisp-implementation-version))
-    (format t "~30a~a~%~a~%" "wxMaxima help dir:" wxHelpDir "----------" ))
+    (format t "~30a~a~%~a~%" "WxMaxima help dir:" wxHelpDir "----------" ))
     (format t "~%~%Maxima's idea of the directory layout is:~%")
     (format t "~a~%" (print-directories))
   "")
@@ -213,7 +215,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 ;; TODO: Make this to maxima's bug_report() when everybody uses a maxima that shows
 ;; our extensions to that command.
 (defmfun $wxbug_report ()
-  (format t "wxMaxima is a graphical front end for Maxima, which does the mathematics in the background.~%")
+  (format t "WxMaxima is a graphical front end for Maxima, which does the mathematics in the background.~%")
   (format t "If you encounter a mathematical problem, it is probably a Maxima bug and should be submitted there.~%")
   (format t "~%The Maxima bug database is available at~%")
   (format t "    https://sourceforge.net/p/maxima/bugs~%")
@@ -252,9 +254,8 @@ Submit bug reports by following the 'New issue' link on that page."))
 ;; array, not the contents thereof.
 ;;
 ;; Adapted from DIMENSION-ARRAY and DIMENSION-INDICES in Maxima src/displa.lisp.
-(defun wxxml-array (x l r &aux base-symbol)
-  (if (eq (caar x) 'mqapply)
-      (setq base-symbol (cadr x) x (cdr x))
+(defun wxxml-array (x l r &aux (base-symbol nil))
+  (unless (eq (caar x) 'mqapply)
       (setq base-symbol (caar x)))
   (let
       ((display-indices (safe-mget base-symbol 'display-indices))
@@ -369,7 +370,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 			 ($get sub-symb '$wxxml_subscript)
 			 )
 		     (ignore-errors (not
-				     (member '$WXXML_SUBSCRIPTED (cadr (properties x))))))))
+				     (member '$WXXML_SUBSCRIPTED (cdr (properties x))))))))
 	  (format nil  "<munder altCopy=\"~A\"><mrow>~a</mrow><mrow>~a</mrow></munder>"
 		  (wxxml-alt-copy-text x)
 		  (format nil "<mi>~a</mi>" (wxxml-fix-string (format nil "~A" sub-var)))
@@ -708,7 +709,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 	  r (append '("</hl></mrow>") r))
     (append l r))
   )
-;; (caddr x) should return the oütional argument
+;; (caddr x) should return the optional argument
 
 (defun wxxml-mqapply (x l r)
   (setq l (wxxml (cadr x) (append l '("<fn>"))
@@ -728,6 +729,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 (wx-defprop $alpha "<g>alpha</g>" wxxmlword)
 (wx-defprop $%beta "<g>%beta</g>" wxxmlword)
 (wx-defprop $beta "<g>beta</g>" wxxmlword)
+(wx-defprop %beta "<g>beta</g>" wxxmlword) ; Maxima commit [446bc6] requires, that $beta must be replaced with %beta, keep both, so that older and younger Maxima versions work.
 (wx-defprop $%gamma "<g>%gamma</g>" wxxmlword)
 (wx-defprop %gamma "<g>gamma</g>" wxxmlword)
 (wx-defprop $%delta "<g>%delta</g>" wxxmlword)
@@ -823,7 +825,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 (wx-defprop $%i "<s>%i</s>" wxxmlword)
 (wx-defprop $%e "<s>%e</s>" wxxmlword)
 (wx-defprop $inf "<s>inf</s>" wxxmlword)
-(wx-defprop $minf "<mo>-</mo><s>inf</s>" wxxmlword)
+(wx-defprop $minf "<s>minf</s>" wxxmlword)
 
 (wx-defprop mreturn "return" wxxmlword)
 
@@ -1660,27 +1662,27 @@ Submit bug reports by following the 'New issue' link on that page."))
 (defvar *image-counter* 0)
 
 ;; A suitable name for a .gnuplot file
+;; There is no standard function for creating temp file names, add a random number to make it not easily guessable.
 (defun wxplot-gnuplotfilename ()
   (incf *wx-plot-num*)
-  (format nil "maxout_~d_~d.gnuplot" (getpid) *wx-plot-num*))
+  (format nil "maxout_~d_~d_~d.gnuplot" (getpid) *wx-plot-num* (random 1000000)))
 
 ;; A suitable name for a .data file
 (defun wxplot-datafilename ()
   (incf *wx-plot-num*)
-  (format nil "maxout_~d_~d.data" (getpid) *wx-plot-num*))
+  (format nil "maxout_~d_~d_~d.data" (getpid) *wx-plot-num* (random 1000000)))
 
 (defun wxplot-filename (&optional (suff t))
   (incf *image-counter*)
   (plot-temp-file (if suff
 		      (format nil (if
-				   $wxplot_usesvg "maxout_~d_~d.svg" "maxout_~d_~d.png")
-			      (getpid) *image-counter*)
-		      (format nil "maxout_~d_~d" (getpid) *image-counter*))))
+				   $wxplot_usesvg "maxout_~d_~d_~d.svg" "maxout_~d_~d_~d.png")
+			      (getpid) *image-counter* (random 1000000))
+		      (format nil "maxout_~d_~d_~d" (getpid) *image-counter* (random 1000000)))))
 
 (defun $wxplot_preamble ()
   (let ((frmt
 	 (cond
-	   ($wxplot_old_gnuplot "set terminal png picsize ~d ~d; set zeroaxis;")
 	   ((and (not $wxplot_usesvg) $wxplot_pngcairo) "set terminal pngcairo dashed background \"white\" enhanced font \"arial,10\" fontscale 1.0 size ~d,~d; set zeroaxis;")
 	   ((and (not $wxplot_usesvg) (not $wxplot_pngcairo)) "set terminal png size ~d,~d; set zeroaxis;")
 	   (t "set terminal svg size ~d,~d; set zeroaxis;"))))
@@ -2285,7 +2287,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 	    				 :host (pathname-host dir)
 	  				 :device (pathname-device dir)))
 	  		 (t (error "cd(dir): dir must be a string or pathname.")))))
-	  #+  allegro (excl:chdir dir)
+	  #+allegro (excl:chdir dir)
 	  #+clisp (ext:cd dir)
 	  #+cmu (setf (ext:default-directory) dir)
 	  #+cormanlisp (ccl:set-current-directory dir)
@@ -2300,9 +2302,10 @@ Submit bug reports by following the 'New issue' link on that page."))
          ;;; shipped with debian and ubuntu (at least in Feb 2017) doesn't.
 	  #+gcl (xchdir dir)
 	  #+gcl (setf *default-pathname-defaults* dir)
+	  #+abcl (setf *default-pathname-defaults* (truename dir))
 
 	  (ignore-errors (setf *default-pathname-defaults* dir))
-	  #-(or allegro clisp cmu cormanlisp gcl lispworks lucid sbcl ccl ecl) (format t
+	  #-(or allegro clisp cmu cormanlisp gcl lispworks lucid sbcl ccl ecl abcl) (format t
 										       "Info: wxMathml.cpp: Changing the working dir during a maxima session isn't implemented for this lisp.")
   	  (namestring dir)
 	  (wx-print-variables)
@@ -2463,6 +2466,7 @@ Submit bug reports by following the 'New issue' link on that page."))
 (format t "</suppressOutput>~%")
 ;; Publish all new global variables maxima might contain to wxMaxima's
 ;; autocompletion feature.
+(wxPrint_autocompletesymbols)
 (wx-print-variables)
 (wx-print-gui-variables)
 ;; Declare that we want all builtins with underscore not to be printed with subscript
