@@ -33,6 +33,7 @@
 
 #include <vector>
 #include "wxMaximaFrame.h"
+#include "WXMXformat.h"
 #include "MathParser.h"
 #include "MaximaIPC.h"
 #include "Dirstructure.h"
@@ -41,8 +42,6 @@
 #include <wx/process.h>
 #include <wx/regex.h>
 #include <wx/dnd.h>
-#include <wx/wfstream.h>
-#include <wx/zstream.h>
 #include <wx/txtstrm.h>
 #include <wx/sckstrm.h>
 #include <wx/buffer.h>
@@ -53,23 +52,6 @@
 #include <windows.h>
 #endif
 #include <unordered_map>
-#define DOCUMENT_VERSION_MAJOR 1
-/*! The part of the .wxmx format version number that appears after the dot.
-
-  - Updated to version 1.1 after user selectable animation-speeds were introduced:
-  Old wxMaxima versions play them back in the default speed instead but still
-  open the file.
-  - Bumped to version 1.2 after saving highlighting was introduced: Older versions
-  of wxMaxima will ignore the highlighting on opening .wxmx files.
-  - Bumped to version 1.3 after sub-subsections were introduced:
-  Old wxMaxima versions interpret them as subsections but still open the file.
-  - Bumped to version 1.4 when we started allowing to embed .jpg images in a .wxmx
-  file. wxMaxima versions between 13.04 and 15.08 replace these images by a
-  "image cannot be loaded" marker but will correctly display the rest of the file.
-  - Bumped to version 1.5 when GroupCells were added an attribute that allows them to
-  be used as an answer to questions.
-*/
-#define DOCUMENT_VERSION_MINOR 5
 
 //! How many milliseconds should we wait between polling for stdout+cpu power?
 #define MAXIMAPOLLMSECS 2000
@@ -82,13 +64,12 @@ class Maxima; // The Maxima process interface
 class wxMaxima : public wxMaximaFrame
 {
 public:
-  wxMaxima(wxWindow *parent, int id, const wxString title,
+  wxMaxima(wxWindow *parent, int id, const wxString &title,
            const wxString &filename = wxEmptyString,
-           const wxString initialWorksheetContents = wxEmptyString,
+           const wxString &initialWorksheetContents = wxEmptyString,
            const wxPoint pos = wxDefaultPosition, const wxSize size = wxDefaultSize);
 
   virtual ~wxMaxima();
-
   wxString EscapeFilenameForShell(wxString name);
   //! Exit if we encounter an error
   static void ExitOnError(){m_exitOnError = true;}
@@ -138,10 +119,6 @@ public:
   void ExitAfterEval(bool exitaftereval)
     {
       m_exitAfterEval = exitaftereval;
-      if(exitaftereval)
-      {
-        m_logPane->SetBatchMode();
-      }
     }
 
   void StripLispComments(wxString &s);
@@ -159,7 +136,7 @@ public:
     { return m_fileSaved; }
 
   //! Load an image from a file into the worksheet.
-  void LoadImage(wxString file)
+  void LoadImage(const wxString &file)
     { GetWorksheet()->OpenHCaret(file, GC_TYPE_IMAGE); }
 
   //! Query the value of a new maxima variable
@@ -176,13 +153,14 @@ public:
     friend bool operator<(const VersionNumber& v1, const VersionNumber& v2);
     friend bool operator>(const VersionNumber& v1, const VersionNumber& v2);
   private:
-    long m_major;
-    long m_minor;
-    long m_patchlevel;
+    long m_major = -1;
+    long m_minor = -1;
+    long m_patchlevel = -1;
   };
 
   //! Use this maxima command (from a command line option) instead of the configured path
-  static void Set_Maxima_Commandline_Filename(wxString filename) {maxima_command_line_filename = filename;}
+  static void Set_Maxima_Commandline_Filename(const wxString &filename)
+    {maxima_command_line_filename = filename;}
   //! The maxima command, if we use the --maxima=<str> command. If empty we use the configured path, not a command line option --maxima=<str>.
   static const wxString Get_Maxima_Commandline_Filename() {return maxima_command_line_filename;}
 
@@ -207,13 +185,13 @@ private:
   std::vector<wxString> m_varNamesToQuery;
 
   //! Is true if opening the file from the command line failed before updating the statusbar.
-  bool m_openInitialFileError;
+  bool m_openInitialFileError = false;
   //! Escape strings into a format lisp accepts
   wxString EscapeForLisp(wxString str);
   //! The number of Jiffies Maxima had used the last time we asked
-  long long m_maximaJiffies_old;
+  long long m_maximaJiffies_old = 0;
   //! The number of Jiffies the CPU had made the last time
-  long long m_cpuTotalJiffies_old;
+  long long m_cpuTotalJiffies_old = 0;
   //! Do we need to update the menus + toolbars?
   //! All configuration commands we still have to send to maxima
   wxString m_configCommands;
@@ -224,28 +202,28 @@ private:
   //! This string allows us to detect when the string we search for has changed.
   wxString m_oldFindString;
   //! This string allows us to detect when the string we search for has changed.
-  int m_oldFindFlags;
+  int m_oldFindFlags = 0;
   //! On opening a new file we only need a new maxima process if the old one ever evaluated cells.
-  bool m_hasEvaluatedCells;
+  bool m_hasEvaluatedCells = false;
   //! The number of output cells the current command has produced so far.
-  long m_outputCellsFromCurrentCommand;
+  long m_outputCellsFromCurrentCommand = 0;
   //! The maximum number of lines per command we will display
-  long m_maxOutputCellsPerCommand;
+  long m_maxOutputCellsPerCommand = 0;
   /*! Double the number of consecutive unsuccessful attempts to connect to the maxima server
 
     Each prompt is deemed as but one hint for a working maxima while each crash counts twice
     which hinders us from endlessly restarting in case maxima crashes, outputs something
     seemingly sensible and crashes again.
   */
-  int m_unsuccessfulConnectionAttempts;
+  int m_unsuccessfulConnectionAttempts = 11;
   //! The current working directory maxima's file I/O is relative to.
   wxString m_CWD;
   //! Do we want to evaluate the file after startup?
-  bool m_evalOnStartup;
+  bool m_evalOnStartup = false;
   //! Do we want to exit the program after the evaluation was successful?
-  bool m_exitAfterEval;
+  bool m_exitAfterEval = false;
   //! Can we display the "ready" prompt right now?
-  bool m_ready;
+  bool m_ready = false;
 
   /*! A human-readable presentation of eventual unmatched-parenthesis type errors
 
@@ -282,7 +260,7 @@ protected:
   //! Info about the gnuplot process we start for querying the terminals it supports
   wxProcess *m_gnuplotTerminalQueryProcess = NULL;
   //! Is this window active?
-  bool m_isActive;
+  bool m_isActive = true;
   //! Called when this window is focussed or defocussed.
   void OnFocus(wxFocusEvent &event);
 
@@ -331,19 +309,27 @@ protected:
     sure that they will be processed in order - but makes a gui a
     more or less single-processor-task.
 
-    If the queue is empty (which means that the computer has caught
-    up with the incoming events) this function is called once.
+    This function now is called once every time the event queue is
+    empty (which means: wxMaxima has caught up with all events
+    from the GUI). An event.RequestMore() inside that function tells
+    the OS to call OnIdle immediately again when OnIdl finishes while
+    the event queue is still empty.
 
-    Moving the screen update to this function makes sure that we
-    don't do many subsequent updates slowing down the computer any
-    further if there are still a handful of key presses to process
-    lowering the average response times of the program.
+    Moving things to the OnIdle() function makes them nearly feel like
+    they were in a low-priority background thread without the
+    disadvantage that background threads cannot access the GUI.
 
-    The worksheet is refreshed by a timer task in case the computer
-    is too busy to execute the idle task at all.
+    Moving the screen update to this function, as well, makes sure that
+    if we get events faster than we can update the screen that doesn't
+    cause lag, but causes screen updates for old events to be dropped
+    if we already have new ones.
+    This normally makes programs feel way more responsive.
+
+    The worksheet is additionally refreshed by a timer task in case
+    that th computer is too busy to ever reach the idle task at all.
   */
   void OnIdle(wxIdleEvent &event);
-  bool m_dataFromMaximaIs;
+  bool m_dataFromMaximaIs = false;
 
   void MenuCommand(const wxString &cmd);           //!< Inserts command cmd into the worksheet
   void FileMenu(wxCommandEvent &event);            //!< Processes "file menu" clicks
@@ -411,7 +397,7 @@ protected:
      NULL, if there is no such line (for example if the appended object is
      maths instead).
   */
-  TextCell *ConsoleAppend(wxString s, CellType type, const wxString &userLabel = {});        //!< append maxima output to console
+  TextCell *ConsoleAppend(wxString s, CellType type);        //!< append maxima output to console
   void ConsoleAppend(wxXmlDocument xml, CellType type, const wxString &userLabel = {});        //!< append maxima output to console
 
   enum AppendOpt { NewLine = 1, BigSkip = 2, PromptToolTip = 4, DefaultOpt = NewLine|BigSkip };
@@ -566,9 +552,9 @@ protected:
   void VariableActionSinnpiflagUndefined();
   //! Called if maxima tells us the value of the maxima variable logexpand.
   void VariableActionLogexpand(const wxString &value);
-  //! Called if maxima tells us where the user files lie.
+  //! Called if maxima tells us where the user files are located.
   void VariableActionUserDir(const wxString &value);
-  //! Called if maxima tells us where the temp files lie.
+  //! Called if maxima tells us where the temp files are located.
   void VariableActionTempDir(const wxString &value);
   //! Called if maxima tells us the value of the maxima variable debugmode.
   void VariableActionDebugmode(const wxString &value);
@@ -584,6 +570,8 @@ protected:
   void VariableActionGnuplotCommand(const wxString &value);
   //! Called if maxima tells us the maxima share dir.
   void VariableActionMaximaSharedir(const wxString &value);
+  //! Called if maxima tells us the maxima demo dir.
+  void VariableActionMaximaDemodir(const wxString &value);
   //! Called if maxima tells us the lisp name.
   void VariableActionLispName(const wxString &value);
   //! Called if maxima tells us the lisp version.
@@ -734,13 +722,13 @@ protected:
   */
   std::unique_ptr<wxSocketServer,  ServerDeleter> m_server;
 
-  wxProcess *m_maximaProcess;
+  wxProcess *m_maximaProcess = NULL;
   //! The stdout of the maxima process
-  wxInputStream *m_maximaStdout;
+  wxInputStream *m_maximaStdout = NULL;
   //! The stderr of the maxima process
-  wxInputStream *m_maximaStderr;
+  wxInputStream *m_maximaStderr = NULL;
   //! The port the actual maxima process (not its wrapper script) runs at
-  int m_port;
+  int m_port = -1;
   //! A marker for the start of maths
   static wxString m_mathPrefix1;
   //! A marker for the start of maths
@@ -751,12 +739,21 @@ public:
   //! The marker for the end of a input prompt
   const static wxString m_promptSuffix;
 protected:
+  /*! True = schedule an update of the table of contents
+
+    used by UpdateTableOfContents() and the idle task.
+  */
+  bool m_scheduleUpdateToc = false;
+  void QuestionAnswered(){if(GetWorksheet()) GetWorksheet()->QuestionAnswered();}
     //! Is called when we get a new list of demo files
   //! Is called when we get a new list of demo files
   void OnNewDemoFiles(wxCommandEvent &event);
   //! Is called when a demo file menu is clicked
   void OnDemoFileMenu(wxCommandEvent &ev);
 
+  //! Is called when something requests an update of the table of contents
+  void OnUpdateTOCEvent(wxCommandEvent &event);
+
   void OnSize(wxSizeEvent &event);
   void OnMove(wxMoveEvent &event);
   void OnMaximize(wxCommandEvent &event);
@@ -765,9 +762,9 @@ protected:
   void GnuplotCommandName(wxString gnuplot);
   //! The first prompt maxima will output
   static wxString m_firstPrompt;
-  bool m_dispReadOut;               //!< what is displayed in statusbar
-  int m_gnuplot_process_id;
-  int m_maxima_process_id;
+  bool m_dispReadOut = false;               //!< what is displayed in statusbar
+  wxWindowIDRef m_gnuplot_process_id;
+  wxWindowIDRef m_maxima_process_id;
   wxString m_lastPrompt;
   wxString m_lastPath;
   std::unique_ptr<wxPrintData> m_printData;
@@ -775,26 +772,29 @@ protected:
 
     If we didn't we respan an unexpectedly-closing maxima.
   */
-  bool m_closing;
+  bool m_closing = false;
   //! The directory with maxima's temp files
   wxString m_maximaTempDir;
   wxString m_maximaHtmlDir;
-  bool m_fileSaved;
-  wxString m_maximaArch;
-  wxString m_lispVersion;
-  wxString m_lispType;
+  bool m_fileSaved = true;
   static int m_exitCode;
   //! Maxima's idea about gnuplot's location
   wxString m_gnuplotcommand;
+#ifdef __WINDOWS__
+  // For Windows, store "gnuplot.exe", even if wgnuplot.exe is preferred.
+  // We query the terminals using: gnuplot -e "print GPVAL_TERMINALS"
+  // and that does only work with gnuplot, not wgnuplot.
   //! The Char the current command starts at in the current WorkingGroup
-  std::size_t m_commandIndex;
+  wxString m_gnuplotcommand_commandline;
+#endif
+  long m_commandIndex = -1;
   FindReplacePane::FindReplaceData m_findData;
   static wxRegEx m_funRegEx;
   static wxRegEx m_varRegEx;
   static wxRegEx m_blankStatementRegEx;
   static wxRegEx m_sbclCompilationRegEx;
   MathParser m_parser;
-  bool m_maximaBusy;
+  bool m_maximaBusy = true;
 private:
   bool m_fourierLoaded = false;
   //! The value of maxima's logexpand variable
@@ -870,11 +870,11 @@ public:
   void OnFileMenu(wxCommandEvent &ev);
 
   virtual void MacNewFile();
-  void BecomeLogTarget();
 
   virtual void MacOpenFile(const wxString &file);
 
 private:
+  static std::vector<wxProcess *> m_wxMaximaProcesses;
 #if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
   void GenerateDebugReport(wxDebugReport::Context ctx);
 #endif
@@ -883,11 +883,7 @@ private:
   //! The name of the config file. Empty = Use the default one.
   wxString m_configFileName;
   Dirstructure m_dirstruct;
-#if defined __WXOSX__
-  bool m_allWindowsInOneProcess = true;
-#else
-  bool m_allWindowsInOneProcess = false;
-#endif
+  static bool m_allWindowsInOneProcess;
 };
 
 class MyDropTarget : public wxFileDropTarget
@@ -899,7 +895,7 @@ public:
   bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &files);
 
 private:
-  wxMaxima *m_wxmax;
+  wxMaxima *m_wxmax = NULL;
 };
 
 #endif
