@@ -42,6 +42,7 @@
 #include <wx/aui/aui.h>
 #include <wx/notifmsg.h>
 #include <wx/wrapsizer.h>
+#include "sidebars/TableOfContents.h"
 #include "sidebars/DrawSidebar.h"
 
 #include "wizards/ScrollingGenWizPanel.h"
@@ -54,7 +55,6 @@
 #include "sidebars/History.h"
 #include "sidebars/XmlInspector.h"
 #include "StatusBar.h"
-#include "sidebars/LogPane.h"
 #include "sidebars/ButtonWrapSizer.h"
 #include <list>
 
@@ -67,7 +67,7 @@ public:
   wxMaximaFrame(wxWindow *parent, int id, const wxString &title,
                 const wxPoint &pos = wxDefaultPosition,
                 const wxSize &size = wxDefaultSize,
-                long style = wxDEFAULT_FRAME_STYLE | wxSYSTEM_MENU | wxCAPTION, bool becomeLogTarget = true);
+                long style = wxDEFAULT_FRAME_STYLE | wxSYSTEM_MENU | wxCAPTION);
 
   /*! The destructor
    */
@@ -79,6 +79,7 @@ public:
     - false: Hide the toolbar
   */
   void ShowToolBar(bool show);
+  static std::size_t CountWindows();
 
   /*! Update the recent documents list
 
@@ -127,10 +128,8 @@ public:
   void StatusMaximaBusy(StatusBar::MaximaStatus status){m_StatusMaximaBusy_next = status;}
   void UpdateStatusMaximaBusy();
 
-  //! True=Maxima is currently busy.
-  StatusBar::MaximaStatus m_StatusMaximaBusy;
-
-  StatusBar::MaximaStatus m_StatusMaximaBusy_next;
+  StatusBar::MaximaStatus m_StatusMaximaBusy = StatusBar::wait_for_start;
+  StatusBar::MaximaStatus m_StatusMaximaBusy_next = StatusBar::wait_for_start;
 
   //! Set the status to "Maxima is saving"
   void StatusSaveStart();
@@ -150,69 +149,74 @@ public:
   //! Set the status to "Exporting has failed"
   void StatusExportFailed();
 
+  Configuration &GetConfiguration() {return m_configuration;}
 protected:
+  //! The panel the user can display variable contents in
+  Variablespane *m_variablesPane = NULL;
+  //! The table of contents pane
+  TableOfContents *m_tableOfContents = NULL;
   Configuration m_configuration;
   //! How many bytes did maxima send us until now?
-  long m_bytesFromMaxima = 0;
+  std::size_t m_bytesFromMaxima = 0;
   //! The process id of maxima. Is determined by ReadFirstPrompt.
-  long m_pid;
+  long m_pid = -1;
   //! The last name GetTempAutosavefileName() has returned.
   wxString m_tempfileName;
   //! Issued if a notification is closed.
   void OnNotificationClose(wxCommandEvent WXUNUSED(&event));
   //! The status bar
-  StatusBar *m_statusBar;
+  StatusBar *m_statusBar = NULL;
   //! The menu bar
-  MainMenuBar *m_MenuBar;
+  MainMenuBar *m_MenuBar = NULL;
   //! The "demo" sub-menu
-  wxMenu *m_demo_sub;
+  wxMenu *m_demo_sub = NULL;
   //! The submenus for the various "demo" sub-submenus
   std::vector<wxMenu *> m_demoSubs;
   //! The "view" menu
-  wxMenu *m_viewMenu;
+  wxMenu *m_viewMenu = NULL;
   //! The gentran menu
-  wxMenu *m_gentranMenu;
+  wxMenu *m_gentranMenu = NULL;
   //! The subst submenu
-  wxMenu *m_subst_Sub;
+  wxMenu *m_subst_Sub = NULL;
   //! The logexpand submenu
-  wxMenu * m_logexpand_Sub;
+  wxMenu * m_logexpand_Sub = NULL;
   //! The file menu.
-  wxMenu *m_FileMenu;
+  wxMenu *m_FileMenu = NULL;
   //! The edit menu.
-  wxMenu *m_EditMenu;
+  wxMenu *m_EditMenu = NULL;
   //! The cell menu.
-  wxMenu *m_CellMenu;
+  wxMenu *m_CellMenu = NULL;
   //! The zoom submenu
-  wxMenu *m_Edit_Zoom_Sub;
+  wxMenu *m_Edit_Zoom_Sub = NULL;
   //! The panes submenu
-  wxMenu *m_Maxima_Panes_Sub;
+  wxMenu *m_Maxima_Panes_Sub = NULL;
   //! The equations menu.
-  wxMenu *m_EquationsMenu;
+  wxMenu *m_EquationsMenu = NULL;
   //! The maxima menu.
-  wxMenu *m_MaximaMenu;
+  wxMenu *m_MaximaMenu = NULL;
   //! The matrix menu.
-  wxMenu *m_matrix_menu;
+  wxMenu *m_matrix_menu = NULL;
   //! The simplify menu
-  wxMenu *m_SimplifyMenu;
+  wxMenu *m_SimplifyMenu = NULL;
   //! The factorials and gamma submenu
-  wxMenu *m_Simplify_Gamma_Sub;
+  wxMenu *m_Simplify_Gamma_Sub = NULL;
   //! Contains the menu for the debugger trigger settingxc
-  wxMenu *m_debugTypeMenu;
+  wxMenu *m_debugTypeMenu = NULL;
   //! The trigonometric submenu
-  wxMenu *m_Simplify_Trig_Sub;
+  wxMenu *m_Simplify_Trig_Sub = NULL;
   //! The complex submenu
-  wxMenu *m_Simplify_Complex_Sub;
+  wxMenu *m_Simplify_Complex_Sub = NULL;
   //! The calculus menu
-  wxMenu *m_CalculusMenu;
+  wxMenu *m_CalculusMenu = NULL;
 
   //! The plot menu
-  wxMenu *m_PlotMenu;
+  wxMenu *m_PlotMenu = NULL;
   //! The list menu
-  wxMenu *m_listMenu;
+  wxMenu *m_listMenu = NULL;
   //! The numeric menu
-  wxMenu *m_NumericMenu;
+  wxMenu *m_NumericMenu = NULL;
   //! The help menu
-  wxMenu *m_HelpMenu;
+  wxMenu *m_HelpMenu = NULL;
   //! Remove an eventual temporary autosave file.
   void RemoveTempAutosavefile();
   //! Re-read the configuration.
@@ -247,10 +251,10 @@ private:
   //! The names our dockable sidebars are shown with
   std::unordered_map<int, wxString> m_sidebarCaption;
   //! How many bytes did maxima send us when we updated the statusbar?
-  long m_bytesFromMaxima_last;
+  std::size_t m_bytesFromMaxima_last = 0;
   wxTimer m_bytesReadDisplayTimer;
   //! True=We are currently saving.
-  bool m_StatusSaving;
+  bool m_StatusSaving = false;
 
   void SetupToolBar();
 
@@ -287,9 +291,9 @@ protected:
   //! The default size for the window.
   virtual wxSize DoGetBestClientSize() const;
   //! The sidebar with the draw commands
-  DrawSidebar *m_drawPane;
+  DrawSidebar *m_drawPane = NULL;
 #ifdef USE_WEBVIEW
-  HelpBrowser *m_helpPane;
+  HelpBrowser *m_helpPane = NULL;
 #endif
 
   //! Looks up which demo file belongs to a wxWindowID
@@ -301,39 +305,38 @@ protected:
 
   SymbolsSidebar *m_symbolsSidebar = NULL;
   //! The current length of the evaluation queue of commands we still need to send to maxima
-  int m_EvaluationQueueLength;
+  int m_EvaluationQueueLength = 0;
   //! Do we need to update the display showing the evaluation queue length?
-  bool m_updateEvaluationQueueLengthDisplay;
+  bool m_updateEvaluationQueueLengthDisplay = true;
   //! The number of commands left in the current of the evaluation queue item
-  int m_commandsLeftInCurrentCell;
+  int m_commandsLeftInCurrentCell = 0;
 
   //! Do we expect the 1st prompt from maxima to appear?
-  bool m_first;
+  bool m_first = true;
 
   bool ToolbarIsShown();
   //! The manager for dynamic screen layouts
-  wxAuiManager m_manager;
+  std::unique_ptr<wxAuiManager> m_manager;
 private:
   //! The worksheet itself
 protected:
   //! The worksheet
   Worksheet * const m_worksheet = NULL;
   //! The history pane
-  History * const m_history;
+  History * const m_history = NULL;
   //! A XmlInspector-like xml monitor
-  XmlInspector *m_xmlInspector;
+  XmlInspector *m_xmlInspector = NULL;
   //! true=force an update of the status bar at the next call of StatusMaximaBusy()
-  bool m_forceStatusbarUpdate;
+  bool m_forceStatusbarUpdate = false;
   //! The panel the log and debug messages will appear on
-  LogPane *m_logPane;
   RecentDocuments m_recentDocuments;
   RecentDocuments m_recentPackages;
-  wxMenu *m_recentDocumentsMenu;
-  wxMenu *m_unsavedDocumentsMenu;
-  wxMenu *m_recentPackagesMenu;
-  wxMenu *m_autoSubscriptMenu;
-  wxMenu *m_equationTypeMenuMenu;
-  wxMenu *m_roundedMatrixParensMenu;
+  wxMenu *m_recentDocumentsMenu = NULL;
+  wxMenu *m_unsavedDocumentsMenu = NULL;
+  wxMenu *m_recentPackagesMenu = NULL;
+  wxMenu *m_autoSubscriptMenu = NULL;
+  wxMenu *m_equationTypeMenuMenu = NULL;
+  wxMenu *m_roundedMatrixParensMenu = NULL;
 };
 
 #endif // WXMAXIMAFRAME_H
